import { Injectable, NgModule, InjectionToken, Inject, Component, Input, Output, EventEmitter, ViewChild } from '@angular/core';
import { BehaviorSubject } from 'rxjs/BehaviorSubject';
import { CommonModule } from '@angular/common';
import { FormBuilder, Validators, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { SlideComponent } from 'ngx-bootstrap/carousel/slide.component';
import { CarouselComponent } from 'ngx-bootstrap/carousel/carousel.component';
import { CarouselConfig } from 'ngx-bootstrap/carousel/carousel.config';
import { Http } from '@angular/http';
import 'rxjs/add/operator/map';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SimulatorState {
    constructor() {
        this.nonRelevantDataElementIds = [];
        this.endPointId = '';
        this.selectedDecisionPointId = '';
        this.selectedDecisionPointLabel = '';
        this.selectedBranchLabel = '';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DataElementValues {
    /**
     * @param {?} values
     */
    constructor(values) {
        this.values = values;
    }
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    addOrUpdate(key, value) {
        this.values[key] = value;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    get(key) {
        return this.values[key];
    }
    /**
     * @param {?} key
     * @return {?}
     */
    delete(key) {
        return this.values.delete(key);
    }
    /**
     * @return {?}
     */
    getAll() {
        return this.values;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SimulatorEngineService {
    constructor() {
        this.endOfRoadReached = false;
        this.lastConditionMetBranchLevel = 1;
        this.simulatorStateChanged = new BehaviorSubject(new SimulatorState());
        this.dataElementValues = new Map();
        this.dataElementTexts = new Map();
    }
    /**
     * @return {?}
     */
    getAllDataElementValues() {
        return this.dataElementValues;
    }
    /**
     * @return {?}
     */
    getAllDataElementTexts() {
        return this.dataElementTexts;
    }
    /**
     * @param {?} dataElementId
     * @return {?}
     */
    getDataElementValue(dataElementId) {
        return this.dataElementValues[dataElementId];
    }
    /**
     * @param {?} dataElementId
     * @return {?}
     */
    getDataElementText(dataElementId) {
        return this.dataElementTexts[dataElementId];
    }
    /**
     * @param {?} dataElementId
     * @param {?} value
     * @param {?} text
     * @return {?}
     */
    addOrUpdateDataElement(dataElementId, value, text) {
        this.dataElementValues[dataElementId] = value;
        this.dataElementTexts[dataElementId] = text;
        this.evaluateDecisionPoints();
    }
    /**
     * @param {?} decisionPoint
     * @param {?} branchingLevel
     * @param {?=} nonRelevantDataElementIds
     * @return {?}
     */
    evaluateDecisionPoint(decisionPoint, branchingLevel, nonRelevantDataElementIds = []) {
        let /** @type {?} */ currentBranchCount = 0;
        const /** @type {?} */ totalBranchesInDecisionPoint = decisionPoint.branches.length;
        for (const /** @type {?} */ branch of decisionPoint.branches) {
            currentBranchCount++;
            let /** @type {?} */ conditionMet = false;
            if (this.endOfRoadReached) {
                break;
            }
            if (branch.compositeCondition !== undefined) {
                conditionMet = branch.compositeCondition.evaluate(new DataElementValues(this.dataElementValues));
            }
            else if (branch.condition !== undefined) {
                conditionMet = branch.condition.evaluate(new DataElementValues(this.dataElementValues));
            }
            // console.log( 'Decision Point:- ' + decisionPoint.id +  ', Branch:- ' + branch.label + ', Condition Met :- ' + conditionMet);
            if (conditionMet) {
                this.lastConditionMetBranchLevel = branchingLevel;
                if (nonRelevantDataElementIds === undefined) {
                    nonRelevantDataElementIds = new Array();
                }
                if (branch.notRelevantDataElements !== undefined) {
                    for (const /** @type {?} */ nonRelevantDataElementReference of branch.notRelevantDataElements.dataElementReferences) {
                        nonRelevantDataElementIds.push(nonRelevantDataElementReference.dataElementId);
                    }
                }
                if (branch.decisionPoints !== undefined) {
                    for (const /** @type {?} */ branchDecisionPoint of branch.decisionPoints) {
                        const /** @type {?} */ newBranchingLevel = branchingLevel + 1;
                        this.evaluateDecisionPoint(branchDecisionPoint, newBranchingLevel, nonRelevantDataElementIds);
                    }
                }
                else if (branch.endPointRef !== undefined) {
                    const /** @type {?} */ simulatorState = new SimulatorState();
                    simulatorState.endPointId = branch.endPointRef.endPointId;
                    simulatorState.nonRelevantDataElementIds = nonRelevantDataElementIds;
                    simulatorState.selectedBranchLabel = branch.label;
                    simulatorState.selectedDecisionPointId = decisionPoint.id;
                    simulatorState.selectedDecisionPointLabel = decisionPoint.label;
                    this.resetValuesOfNonRelevantDataElements(nonRelevantDataElementIds);
                    this.simulatorStateChanged.next(simulatorState);
                    this.endOfRoadReached = true;
                    break;
                }
            }
            else {
                if (currentBranchCount >= totalBranchesInDecisionPoint) {
                    this.endOfRoadReached = true;
                    const /** @type {?} */ simulatorState = new SimulatorState();
                    simulatorState.nonRelevantDataElementIds = nonRelevantDataElementIds;
                    this.resetValuesOfNonRelevantDataElements(nonRelevantDataElementIds);
                    this.simulatorStateChanged.next(simulatorState);
                    return;
                }
                else {
                    continue;
                }
            }
        }
    }
    /**
     * @param {?} nonRelevantDataElementIds
     * @return {?}
     */
    resetValuesOfNonRelevantDataElements(nonRelevantDataElementIds) {
        for (const /** @type {?} */ nonRelevantDataElementId of nonRelevantDataElementIds) {
            let /** @type {?} */ defaultValue;
            for (const /** @type {?} */ dataElement of this.template.dataElements) {
                if (dataElement.id === nonRelevantDataElementId) {
                    defaultValue = dataElement.defaultValue;
                    break;
                }
            }
            this.dataElementValues[nonRelevantDataElementId] = defaultValue;
        }
    }
    /**
     * @param {?} elementId
     * @param {?} decisionPoint
     * @param {?} branchingLevel
     * @return {?}
     */
    evaluateComputedElementDecisionPoint(elementId, decisionPoint, branchingLevel) {
        let /** @type {?} */ currentBranchCount = 0;
        const /** @type {?} */ totalBranchesInDecisionPoint = decisionPoint.branches.length;
        for (const /** @type {?} */ branch of decisionPoint.branches) {
            currentBranchCount++;
            let /** @type {?} */ conditionMet = false;
            if (this.endOfRoadReached) {
                break;
            }
            if (branch.compositeCondition !== undefined) {
                conditionMet = branch.compositeCondition.evaluate(new DataElementValues(this.dataElementValues));
            }
            else if (branch.condition !== undefined) {
                conditionMet = branch.condition.evaluate(new DataElementValues(this.dataElementValues));
            }
            if (conditionMet) {
                this.lastConditionMetBranchLevel = branchingLevel;
                if (branch.decisionPoints !== undefined) {
                    for (const /** @type {?} */ branchDecisionPoint of branch.decisionPoints) {
                        const /** @type {?} */ newBranchingLevel = branchingLevel + 1;
                        this.evaluateComputedElementDecisionPoint(elementId, branchDecisionPoint, newBranchingLevel);
                    }
                }
                else if (branch.computedValue !== undefined) {
                    this.dataElementValues[elementId] = branch.computedValue.expressionText;
                    this.endOfRoadReached = true;
                    break;
                }
            }
            else {
                if (currentBranchCount >= totalBranchesInDecisionPoint) {
                    this.endOfRoadReached = true;
                    this.dataElementValues[elementId] = undefined;
                    return;
                }
                else {
                    continue;
                }
            }
        }
    }
    /**
     * @return {?}
     */
    evaluateComputedExpressions() {
        this.endOfRoadReached = false;
        for (const /** @type {?} */ element of this.template.dataElements) {
            if (element.dataElementType === 'ComputedDataElement') {
                const /** @type {?} */ computedElement = /** @type {?} */ (element);
                for (const /** @type {?} */ decisionPoint of computedElement.decisionPoints) {
                    this.evaluateComputedElementDecisionPoint(element.id, decisionPoint, 1);
                    if (this.dataElementValues[element.id] === undefined && decisionPoint.defaultBranch &&
                        decisionPoint.defaultBranch.computedValue) {
                        this.dataElementValues[element.id] = decisionPoint.defaultBranch.computedValue.expressionText;
                    }
                    this.endOfRoadReached = false;
                }
            }
        }
    }
    /**
     * @return {?}
     */
    evaluateDecisionPoints() {
        this.evaluateComputedExpressions();
        this.endOfRoadReached = false;
        for (const /** @type {?} */ decisionPoint of this.template.rules.decisionPoints) {
            if (this.evaluateDecisionPoint(decisionPoint, 1, new Array())) {
                break;
            }
        }
    }
    /**
     * @param {?} template
     * @return {?}
     */
    initialize(template) {
        this.template = template;
        for (const /** @type {?} */ dataElement of this.template.dataElements) {
            this.dataElementValues[dataElement.id] = dataElement.currentValue;
        }
    }
}
SimulatorEngineService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
SimulatorEngineService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CoreModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: CoreModule,
            providers: [SimulatorEngineService]
        };
    }
}
CoreModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: []
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Template {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Metadata {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Diagram {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ArrayCheckerService {
    constructor() { }
    /**
     * @param {?} item
     * @return {?}
     */
    isArray(item) {
        return item instanceof Array;
    }
}
ArrayCheckerService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ArrayCheckerService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DiagramService {
    /**
     * @param {?} arrayCheckerSeviceService
     */
    constructor(arrayCheckerSeviceService) {
        this.arrayCheckerSeviceService = arrayCheckerSeviceService;
    }
    /**
     * @param {?} diagramJSON
     * @return {?}
     */
    returnDiagram(diagramJSON) {
        const /** @type {?} */ diagram = new Diagram();
        if (diagramJSON.Attr) {
            diagram.displaySequence = diagramJSON.Attr.DisplaySequence;
            diagram.keyDiagram = diagramJSON.Attr.IsKeyDiagram ? diagramJSON.Attr.IsKeyDiagram : false;
        }
        else {
            diagram.displaySequence = undefined;
            diagram.keyDiagram = false;
        }
        diagram.label = diagramJSON.Label;
        diagram.location = diagramJSON.Location;
        return diagram;
    }
    /**
     * @param {?} diagramsAsJSON
     * @return {?}
     */
    returnDiagrams(diagramsAsJSON) {
        const /** @type {?} */ diagrams = new Array();
        if (diagramsAsJSON !== undefined) {
            if (this.arrayCheckerSeviceService.isArray(diagramsAsJSON)) {
                for (const /** @type {?} */ diagram of diagramsAsJSON) {
                    diagrams.push(this.returnDiagram(diagram));
                }
            }
            else {
                diagrams.push(this.returnDiagram(diagramsAsJSON));
            }
        }
        return diagrams;
    }
}
DiagramService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
DiagramService.ctorParameters = () => [
    { type: ArrayCheckerService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const CreationServiceInjectorToken = new InjectionToken('one');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DecisionPoint {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Branch {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EndPointRef {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DataElementRef {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NotRelevantDataElements {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EqualCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ value = dataElementValues.get(this.conditionType.dataElementId);
        return value === this.conditionType.comparisonValue;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ConditionType {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class GreaterThanCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ value = /** @type {?} */ (+dataElementValues.get(this.conditionType.dataElementId));
        let /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = /** @type {?} */ (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = /** @type {?} */ (+this.conditionType.comparisonValue);
        }
        return value > comparisonValue;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LessThanCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ value = /** @type {?} */ (+dataElementValues.get(this.conditionType.dataElementId));
        let /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = /** @type {?} */ (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = /** @type {?} */ (+this.conditionType.comparisonValue);
        }
        return value < comparisonValue;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class GreaterThanOrEqualsCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ value = /** @type {?} */ (+dataElementValues.get(this.conditionType.dataElementId));
        let /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = /** @type {?} */ (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = /** @type {?} */ (+this.conditionType.comparisonValue);
        }
        return value >= comparisonValue;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LessThanOrEqualsCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ value = /** @type {?} */ (+dataElementValues.get(this.conditionType.dataElementId));
        let /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = /** @type {?} */ (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = /** @type {?} */ (+this.conditionType.comparisonValue);
        }
        return value <= comparisonValue;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ContainsCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        let /** @type {?} */ returnValue = false;
        const /** @type {?} */ value = dataElementValues.get(this.conditionType.dataElementId);
        if (value !== undefined) {
            returnValue = value.indexOf(this.conditionType.comparisonValue) >= 0;
        }
        return returnValue;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AndCondition {
    constructor() {
        this.conditions = [];
        this.conditionType = 'AndCondition';
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        let /** @type {?} */ returnValue = true;
        for (let /** @type {?} */ conditionCounter = 0; conditionCounter < this.conditions.length; conditionCounter++) {
            const /** @type {?} */ condition = this.conditions[conditionCounter];
            const /** @type {?} */ executedCondition = condition.evaluate(dataElementValues);
            returnValue = (!executedCondition) ? false : (returnValue && executedCondition);
            if (!returnValue) {
                break;
            }
        }
        return returnValue;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class OrCondition {
    constructor() {
        this.conditions = [];
        this.conditionType = 'OrCondition';
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        let /** @type {?} */ returnValue = false;
        for (let /** @type {?} */ conditionCounter = 0; conditionCounter < this.conditions.length; conditionCounter++) {
            const /** @type {?} */ condition = this.conditions[conditionCounter];
            const /** @type {?} */ executedCondition = condition.evaluate(dataElementValues);
            returnValue = (returnValue || executedCondition);
            if (returnValue) {
                break;
            }
        }
        return returnValue;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NotCondition {
    constructor() {
        this.conditions = [];
        this.conditionType = 'NotCondition';
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ results = new Array();
        for (const /** @type {?} */ condition of this.conditions) {
            results.push(condition.evaluate(dataElementValues));
        }
        return !(results[0]);
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ConditionsCreationService {
    /**
     * @param {?} arrayCheckerService
     */
    constructor(arrayCheckerService) {
        this.arrayCheckerService = arrayCheckerService;
    }
    /**
     * @param {?} conditionJSON
     * @return {?}
     */
    returnConditionType(conditionJSON) {
        const /** @type {?} */ conditionType = new ConditionType();
        conditionType.comparisonValue = conditionJSON.Attr.ComparisonValue;
        conditionType.dataElementId = conditionJSON.Attr.DataElementId;
        return conditionType;
    }
    /**
     * @param {?} branchJSON
     * @return {?}
     */
    returnCondition(branchJSON) {
        let /** @type {?} */ condition;
        if (branchJSON.hasOwnProperty('EqualCondition')) {
            condition = new EqualCondition(this.returnConditionType(branchJSON.EqualCondition));
        }
        if (branchJSON.hasOwnProperty('GreaterThanCondition')) {
            condition = new GreaterThanCondition(this.returnConditionType(branchJSON.GreaterThanCondition));
        }
        if (branchJSON.hasOwnProperty('LessThanCondition')) {
            condition = new LessThanCondition(this.returnConditionType(branchJSON.LessThanCondition));
        }
        if (branchJSON.hasOwnProperty('GreaterThanOrEqualsCondition')) {
            condition = new GreaterThanOrEqualsCondition(this.returnConditionType(branchJSON.GreaterThanOrEqualsCondition));
        }
        if (branchJSON.hasOwnProperty('LessThanOrEqualsCondition')) {
            condition = new LessThanOrEqualsCondition(this.returnConditionType(branchJSON.LessThanOrEqualsCondition));
        }
        if (branchJSON.hasOwnProperty('ContainsCondition')) {
            condition = new ContainsCondition(this.returnConditionType(branchJSON.ContainsCondition));
        }
        return condition;
    }
    /**
     * @param {?} compositeElementJSON
     * @return {?}
     */
    isComposite(compositeElementJSON) {
        return compositeElementJSON.hasOwnProperty('AndCondition') ||
            compositeElementJSON.hasOwnProperty('OrCondition') ||
            compositeElementJSON.hasOwnProperty('NotCondition');
    }
    /**
     * @param {?} conditionIdentifier
     * @param {?} conditionJSON
     * @return {?}
     */
    returnConditionFromJSON(conditionIdentifier, conditionJSON) {
        let /** @type {?} */ condition;
        if (conditionIdentifier === 'EqualCondition') {
            condition = new EqualCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'GreaterThanCondition') {
            condition = new GreaterThanCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'LessThanCondition') {
            condition = new LessThanCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'GreaterThanOrEqualsCondition') {
            condition = new GreaterThanOrEqualsCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'LessThanOrEqualsCondition') {
            condition = new LessThanOrEqualsCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'ContainsCondition') {
            condition = new ContainsCondition(this.returnConditionType(conditionJSON));
        }
        return condition;
    }
    /**
     * @param {?} conditionsJSON
     * @return {?}
     */
    returnConditions(conditionsJSON) {
        let /** @type {?} */ conditions;
        const /** @type {?} */ conditionIdentifiers = ['EqualCondition', 'GreaterThanCondition', 'LessThanCondition',
            'GreaterThanOrEqualsCondition', 'LessThanOrEqualsCondition', 'ContainsCondition'];
        for (const /** @type {?} */ conditionIdentifier of conditionIdentifiers) {
            const /** @type {?} */ conditionJSON = conditionsJSON[conditionIdentifier];
            if (conditionJSON !== undefined) {
                conditions = new Array();
                if (this.arrayCheckerService.isArray(conditionJSON)) {
                    for (const /** @type {?} */ jsonValue of conditionJSON) {
                        conditions.push(this.returnConditionFromJSON(conditionIdentifier, jsonValue));
                    }
                }
                else {
                    conditions.push(this.returnConditionFromJSON(conditionIdentifier, conditionJSON));
                }
            }
        }
        return conditions;
    }
    /**
     * @param {?} compositeElementJSON
     * @return {?}
     */
    isHybrid(compositeElementJSON) {
        const /** @type {?} */ compositeExists = compositeElementJSON.hasOwnProperty('AndCondition') ||
            compositeElementJSON.hasOwnProperty('OrCondition') ||
            compositeElementJSON.hasOwnProperty('NotCondition');
        const /** @type {?} */ primitiveExists = compositeElementJSON.hasOwnProperty('EqualCondition') ||
            compositeElementJSON.hasOwnProperty('GreaterThanCondition') ||
            compositeElementJSON.hasOwnProperty('LessThanCondition') ||
            compositeElementJSON.hasOwnProperty('GreaterThanOrEqualsCondition') ||
            compositeElementJSON.hasOwnProperty('LessThanOrEqualsCondition') ||
            compositeElementJSON.hasOwnProperty('ContainsCondition');
        return compositeExists && primitiveExists;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    returnCompositeCondition(data) {
        if (!this.isComposite(data)) {
            return;
        }
        let /** @type {?} */ compositeConditionJSON;
        let /** @type {?} */ compositeCondition;
        if (data.hasOwnProperty('AndCondition')) {
            compositeConditionJSON = data.AndCondition;
            compositeCondition = new AndCondition();
        }
        else if (data.hasOwnProperty('OrCondition')) {
            compositeConditionJSON = data.OrCondition;
            compositeCondition = new OrCondition();
        }
        else if (data.hasOwnProperty('NotCondition')) {
            compositeConditionJSON = data.NotCondition;
            compositeCondition = new NotCondition();
        }
        if (!this.isComposite(compositeConditionJSON)) {
            compositeCondition.conditions = this.returnConditions(compositeConditionJSON);
        }
        else if (this.isHybrid(compositeConditionJSON)) {
            const /** @type {?} */ jsonKeys = Object.keys(compositeConditionJSON);
            for (const /** @type {?} */ jsonKey of jsonKeys) {
                const /** @type {?} */ jsonValue = compositeConditionJSON[jsonKey];
                const /** @type {?} */ jsonString = '{"' + jsonKey + '":' + JSON.stringify(jsonValue) + '}';
                const /** @type {?} */ jsonObject = JSON.parse(jsonString);
                if (this.isComposite(jsonObject)) {
                    this.returnInnerConditions(jsonObject, compositeCondition);
                }
                else {
                    if (this.arrayCheckerService.isArray(jsonValue)) {
                        for (const /** @type {?} */ arrayValue of jsonValue) {
                            compositeCondition.conditions.push(this.returnConditionFromJSON(jsonKey, arrayValue));
                        }
                    }
                    else {
                        compositeCondition.conditions.push(this.returnConditionFromJSON(jsonKey, jsonValue));
                    }
                }
            }
        }
        else {
            this.returnInnerConditions(compositeConditionJSON, compositeCondition);
        }
        return compositeCondition;
    }
    /**
     * @param {?} elementName
     * @return {?}
     */
    returnCompositeConditionFromName(elementName) {
        let /** @type {?} */ compositeCondition;
        switch (elementName) {
            case 'AndCondition':
                {
                    compositeCondition = new AndCondition();
                    break;
                }
            case 'OrCondition':
                {
                    compositeCondition = new OrCondition();
                    break;
                }
            case 'NotCondition':
                {
                    compositeCondition = new NotCondition();
                }
        }
        return compositeCondition;
    }
    /**
     * @param {?} key
     * @param {?} value
     * @param {?} compositeCondition
     * @return {?}
     */
    addConditionsToInnerConditions(key, value, compositeCondition) {
        const /** @type {?} */ condition = this.returnCompositeConditionFromName(key);
        compositeCondition.conditions.push(condition);
        if (this.isHybrid(value)) {
            const /** @type {?} */ jsonKeys = Object.keys(value);
            for (const /** @type {?} */ jsonKey of jsonKeys) {
                const /** @type {?} */ jsonValue = value[jsonKey];
                const /** @type {?} */ jsonString = '{"' + jsonKey + '":' + JSON.stringify(jsonValue) + '}';
                const /** @type {?} */ jsonObject = JSON.parse(jsonString);
                if (this.isComposite(jsonObject)) {
                    this.returnInnerConditions(jsonObject, condition);
                }
                else {
                    if (this.arrayCheckerService.isArray(jsonValue)) {
                        for (const /** @type {?} */ arrayValue of jsonValue) {
                            condition.conditions.push(this.returnConditionFromJSON(jsonKey, arrayValue));
                        }
                    }
                    else {
                        condition.conditions.push(this.returnConditionFromJSON(jsonKey, jsonValue));
                    }
                }
            }
        }
        else if (this.isComposite(value)) {
            // console.log( 'isComposite');
        }
        else {
            condition.conditions = this.returnConditions(value);
        }
    }
    /**
     * @param {?} innerConditionsJSON
     * @param {?} compositeCondition
     * @return {?}
     */
    returnInnerConditions(innerConditionsJSON, compositeCondition) {
        const /** @type {?} */ jsonKeys = Object.keys(innerConditionsJSON);
        for (const /** @type {?} */ key of jsonKeys) {
            const /** @type {?} */ values = innerConditionsJSON[key];
            if (this.arrayCheckerService.isArray(values)) {
                for (const /** @type {?} */ value of values) {
                    this.addConditionsToInnerConditions(key, value, compositeCondition);
                }
            }
            else {
                this.addConditionsToInnerConditions(key, innerConditionsJSON[key], compositeCondition);
            }
        }
    }
}
ConditionsCreationService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ConditionsCreationService.ctorParameters = () => [
    { type: ArrayCheckerService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TextExpression {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ArithmeticExpression {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ComputedValueCreationService {
    constructor() { }
    /**
     * @param {?} dataAsJSON
     * @return {?}
     */
    createComputedValue(dataAsJSON) {
        if (dataAsJSON['TextExpression'] !== undefined) {
            const /** @type {?} */ computedValue = new TextExpression();
            computedValue.expressionText = dataAsJSON.TextExpression;
            return computedValue;
        }
        if (dataAsJSON['ArithmeticExpression'] !== undefined) {
            {
                const /** @type {?} */ computedValue = new ArithmeticExpression();
                computedValue.expressionText = dataAsJSON.ArithmeticExpression;
                return computedValue;
            }
        }
    }
}
ComputedValueCreationService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ComputedValueCreationService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DecisionPointsCreationService {
    /**
     * @param {?} arrayCheckerService
     * @param {?} conditionsCreationService
     * @param {?} computedValueCreationService
     */
    constructor(arrayCheckerService, conditionsCreationService, computedValueCreationService) {
        this.arrayCheckerService = arrayCheckerService;
        this.conditionsCreationService = conditionsCreationService;
        this.computedValueCreationService = computedValueCreationService;
    }
    /**
     * @param {?} dataElementRefJSON
     * @return {?}
     */
    createRelevantDataElementReferences(dataElementRefJSON) {
        const /** @type {?} */ dataElementRef = new DataElementRef();
        dataElementRef.dataElementId = dataElementRefJSON.Attr.DataElementId;
        return dataElementRef;
    }
    /**
     * @param {?} branchJSON
     * @return {?}
     */
    returnBranch(branchJSON) {
        const /** @type {?} */ branch = new Branch();
        branch.label = branchJSON.Label;
        if (branchJSON.EndPointRef) {
            branch.endPointRef = new EndPointRef();
            branch.endPointRef.endPointId = branchJSON.EndPointRef.Attr.EndPointId;
        }
        branch.condition = this.conditionsCreationService.returnCondition(branchJSON);
        branch.computedValue = this.computedValueCreationService.createComputedValue(branchJSON);
        if (this.conditionsCreationService.isComposite(branchJSON)) {
            branch.compositeCondition = this.conditionsCreationService.returnCompositeCondition(branchJSON);
        }
        if (branchJSON.NotRelevantDataElements) {
            const /** @type {?} */ notRelevantDataElements = new NotRelevantDataElements();
            notRelevantDataElements.dataElementReferences = new Array();
            const /** @type {?} */ dataElementRefs = branchJSON.NotRelevantDataElements.DataElementRef;
            if (this.arrayCheckerService.isArray(dataElementRefs)) {
                for (const /** @type {?} */ dataElementRefJSON of dataElementRefs) {
                    notRelevantDataElements.dataElementReferences.push(this.createRelevantDataElementReferences(dataElementRefJSON));
                }
            }
            else {
                notRelevantDataElements.dataElementReferences.push(this.createRelevantDataElementReferences(dataElementRefs));
            }
            branch.notRelevantDataElements = notRelevantDataElements;
        }
        if (branchJSON.DecisionPoint) {
            branch.decisionPoints = new Array();
            this.addDecisionPoints(branchJSON.DecisionPoint, branch.decisionPoints);
        }
        return branch;
    }
    /**
     * @param {?} decsionPointAsJSON
     * @param {?} decisionPoints
     * @return {?}
     */
    addDecisionPoint(decsionPointAsJSON, decisionPoints) {
        const /** @type {?} */ decisionPoint = new DecisionPoint();
        if (decsionPointAsJSON.Attr && decsionPointAsJSON.Attr.Id) {
            decisionPoint.id = decsionPointAsJSON.Attr.Id;
        }
        decisionPoint.label = decsionPointAsJSON.Label;
        const /** @type {?} */ branchesJSON = decsionPointAsJSON.Branch;
        if (branchesJSON !== undefined) {
            decisionPoint.branches = new Array();
            if (this.arrayCheckerService.isArray(branchesJSON)) {
                for (const /** @type {?} */ branchJSON of branchesJSON) {
                    decisionPoint.branches.push(this.returnBranch(branchJSON));
                }
            }
            else {
                decisionPoint.branches.push(this.returnBranch(branchesJSON));
            }
            const /** @type {?} */ defaultBranchJSON = decsionPointAsJSON.DefaultBranch;
            if (defaultBranchJSON !== undefined) {
                decisionPoint.defaultBranch = this.createDefaultBranch(defaultBranchJSON);
            }
        }
        decisionPoints.push(decisionPoint);
    }
    /**
     * @param {?} decsionPointsAsJSON
     * @param {?} decisionPoints
     * @return {?}
     */
    addDecisionPoints(decsionPointsAsJSON, decisionPoints) {
        if (this.arrayCheckerService.isArray(decsionPointsAsJSON)) {
            for (const /** @type {?} */ decisionPoint of decsionPointsAsJSON) {
                this.addDecisionPoint(decisionPoint, decisionPoints);
            }
        }
        else {
            this.addDecisionPoint(decsionPointsAsJSON, decisionPoints);
        }
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createDecisionPoints(data) {
        const /** @type {?} */ decisionPoints = new Array();
        this.addDecisionPoints(data, decisionPoints);
        return decisionPoints;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createDefaultBranch(data) {
        const /** @type {?} */ defaultBranch = new Branch();
        defaultBranch.label = 'Default Branch';
        defaultBranch.computedValue = this.computedValueCreationService.createComputedValue(data);
        return defaultBranch;
    }
}
DecisionPointsCreationService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
DecisionPointsCreationService.ctorParameters = () => [
    { type: ArrayCheckerService, },
    { type: ConditionsCreationService, },
    { type: ComputedValueCreationService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Rules {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TemplatePartial {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TemplateManagerService {
    /**
     * @param {?} diagramService
     * @param {?} elememtcreationService
     * @param {?} arrayCheckerService
     * @param {?} decisionPointsCreationService
     */
    constructor(diagramService, elememtcreationService, arrayCheckerService, decisionPointsCreationService) {
        this.diagramService = diagramService;
        this.elememtcreationService = elememtcreationService;
        this.arrayCheckerService = arrayCheckerService;
        this.decisionPointsCreationService = decisionPointsCreationService;
        this.endPointXMLString = [];
        this.stringParser = require('string');
    }
    /**
     * @param {?} templateContent
     * @return {?}
     */
    getTemplate(templateContent) {
        const /** @type {?} */ template = new Template();
        let /** @type {?} */ templateContentAsJSON;
        templateContentAsJSON = this.parseToJson(templateContent);
        if (template === undefined) {
            throw new Error('Unable to parse the template');
        }
        template.metadata = this.getMetaData(templateContentAsJSON.Metadata);
        template.dataElements = this.getDataElements(templateContentAsJSON.DataElements);
        if (templateContentAsJSON.Rules) {
            template.rules = new Rules();
            template.rules.decisionPoints = this.decisionPointsCreationService.
                createDecisionPoints(templateContentAsJSON.Rules.DecisionPoint);
        }
        template.templatePartial = this.returnEndpoints(templateContent);
        template.endPointsString = this.endPointXMLString;
        template.xmlContent = templateContent;
        return template;
    }
    /**
     * @param {?} templatePartialJSON
     * @return {?}
     */
    getTemplatePartial(templatePartialJSON) {
        const /** @type {?} */ templatePartial = new TemplatePartial;
        templatePartial.id = templatePartialJSON.Attr.Id;
        templatePartial.sectionIfNotValue = templatePartialJSON.SectionIfValueNot;
        templatePartial.sectionIfValues = templatePartialJSON.SectionIfValue;
        return templatePartial;
    }
    /**
     * @param {?} content
     * @param {?} startToken
     * @param {?} endToken
     * @return {?}
     */
    returnEndPointContents(content, startToken, endToken) {
        const /** @type {?} */ contents = new Array();
        let /** @type {?} */ templateSearchIndexPosition = 0;
        while (true) {
            const /** @type {?} */ contentStartPosition = content.indexOf(startToken, templateSearchIndexPosition);
            const /** @type {?} */ contentEndPosition = content.indexOf(endToken, templateSearchIndexPosition);
            if (contentStartPosition >= 0 && contentEndPosition >= 0) {
                const /** @type {?} */ endPosition = contentEndPosition + endToken.length;
                const /** @type {?} */ contentData = content.substring(contentStartPosition, endPosition);
                contents.push(contentData);
                templateSearchIndexPosition = endPosition + 1;
            }
            else {
                break;
            }
        }
        return contents;
    }
    /**
     * @param {?} templatePartialArray
     * @return {?}
     */
    returnTemplatePartials(templatePartialArray) {
        const /** @type {?} */ templatePartials = new Array();
        for (const /** @type {?} */ arrayItem of templatePartialArray) {
            const /** @type {?} */ templatePartial = new TemplatePartial();
            const /** @type {?} */ templatePartialAsJSON = this.parseToJson(arrayItem);
            templatePartial.id = templatePartialAsJSON.Attr.Id;
        }
        return templatePartials;
    }
    /**
     * @param {?} xmlData
     * @return {?}
     */
    returnEndpoints(xmlData) {
        const /** @type {?} */ endPointStartToken = '<EndPoints>';
        const /** @type {?} */ endPointEndToken = '</EndPoints>';
        const /** @type {?} */ endPointStartTokenPosition = xmlData.indexOf(endPointStartToken);
        const /** @type {?} */ endPointEndTokenPosition = xmlData.indexOf(endPointEndToken);
        if (endPointStartTokenPosition >= 0 && endPointEndTokenPosition >= 0) {
            const /** @type {?} */ contentStartPosition = (endPointStartTokenPosition + endPointStartToken.length);
            const /** @type {?} */ endPointContent = xmlData.substring(contentStartPosition, endPointEndTokenPosition);
            if (endPointContent.length > 0) {
                const /** @type {?} */ templatePartials = this.returnEndPointContents(endPointContent, '<TemplatePartial', '</TemplatePartial>');
                this.endPointXMLString = this.returnEndPointContents(endPointContent, '<EndPoint', '</EndPoint>');
                return templatePartials;
            }
        }
    }
    /**
     * @param {?} xmlData
     * @return {?}
     */
    parseToJson(xmlData) {
        let /** @type {?} */ jsonResult;
        const /** @type {?} */ parseString = require('xml2js').parseString;
        parseString(xmlData, { explicitRoot: false, explicitArray: false, attrkey: 'Attr' }, function (err, result) {
            jsonResult = result;
        });
        return jsonResult;
    }
    /**
     * @param {?} metadataJSON
     * @return {?}
     */
    getMetaData(metadataJSON) {
        const /** @type {?} */ metadata = new Metadata();
        metadata.label = metadataJSON.Label;
        metadata.id = metadataJSON.ID;
        metadata.schemaVersion = metadataJSON.SchemaVersion;
        metadata.ruleVersion = metadataJSON.RuleVersion;
        const /** @type {?} */ diagramsAsJSON = metadataJSON.Info.Diagrams.Diagram;
        metadata.diagrams = this.diagramService.returnDiagrams(diagramsAsJSON);
        return metadata;
    }
    /**
     * @param {?} elementType
     * @param {?} dataElementsJSON
     * @return {?}
     */
    returnDataElement(elementType, dataElementsJSON) {
        const /** @type {?} */ dataElements = new Array();
        let /** @type {?} */ dataElementCreationServiceInstance;
        for (const /** @type {?} */ dataElementCreationService of this.elememtcreationService) {
            if (dataElementCreationService.elementType === elementType) {
                dataElementCreationServiceInstance = dataElementCreationService;
                break;
            }
        }
        if (dataElementCreationServiceInstance !== undefined && dataElementsJSON !== undefined) {
            if (this.arrayCheckerService.isArray(dataElementsJSON)) {
                for (const /** @type {?} */ dataElementJSON of dataElementsJSON) {
                    const /** @type {?} */ dataElement = dataElementCreationServiceInstance.createElement(dataElementJSON);
                    dataElements.push(dataElement);
                }
            }
            else {
                const /** @type {?} */ dataElement = dataElementCreationServiceInstance.createElement(dataElementsJSON);
                dataElements.push(dataElement);
            }
        }
        return dataElements;
    }
    /**
     * @param {?} dataElementsJSON
     * @return {?}
     */
    getDataElements(dataElementsJSON) {
        let /** @type {?} */ dataElements = new Array();
        dataElements = dataElements.concat(this.returnDataElement('ChoiceDataElement', dataElementsJSON.ChoiceDataElement));
        dataElements = dataElements.concat(this.returnDataElement('MultiChoiceDataElement', dataElementsJSON.MultiChoiceDataElement));
        dataElements = dataElements.concat(this.returnDataElement('NumericDataElement', dataElementsJSON.NumericDataElement));
        dataElements = dataElements.concat(this.returnDataElement('GlobalValue', dataElementsJSON.GlobalValue));
        dataElements = dataElements.concat(this.returnDataElement('ComputedDataElement', dataElementsJSON.ComputedDataElement));
        dataElements = dataElements.concat(this.returnDataElement('IntegerDataElement', dataElementsJSON.IntegerDataElement));
        return dataElements;
    }
}
TemplateManagerService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
TemplateManagerService.ctorParameters = () => [
    { type: DiagramService, },
    { type: Array, decorators: [{ type: Inject, args: [CreationServiceInjectorToken,] },] },
    { type: ArrayCheckerService, },
    { type: DecisionPointsCreationService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AllTextReport {
}
/** @enum {number} */
const ReportTextPosition = {
    Top: 0,
    Right: 1,
};
ReportTextPosition[ReportTextPosition.Top] = "Top";
ReportTextPosition[ReportTextPosition.Right] = "Right";

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const $ = require('jquery');
class AcrAssistSimulatorComponent {
    /**
     * @param {?} templateManagerService
     * @param {?} simulatorEngineService
     */
    constructor(templateManagerService, simulatorEngineService) {
        this.templateManagerService = templateManagerService;
        this.simulatorEngineService = simulatorEngineService;
        this.inputValues = [];
        this.returnExecutionHistory = new EventEmitter();
        this.returnDefaultElements = new EventEmitter();
        this.position = ReportTextPosition;
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this.reloadUI();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.isReset = true;
        this.isEmptyContent = this.templateContent === undefined || this.templateContent.length === 0 && this.inputValues.length === 0 &&
            this.inputData === undefined;
        if (this.isEmptyContent) {
            return;
        }
        if (this.inputData !== undefined) {
            if (this.inputData.length > 0) {
                this.inputValues = JSON.parse(this.inputData);
            }
        }
        if (this.imageUpload !== undefined) {
            this.imageUpload.nativeElement.value = '';
        }
        this.template = this.templateManagerService.getTemplate(this.templateContent);
        this.simulatorEngineService.initialize(this.template);
        if (this.inputValues.length !== 0) {
            for (const /** @type {?} */ dataeElement of this.template.dataElements) {
                const /** @type {?} */ inputValue = this.inputValues.filter(x => x.dataElementId === dataeElement.id);
                if (inputValue !== undefined && inputValue.length > 0) {
                    dataeElement.currentValue = inputValue[0].dataElementValue;
                }
            }
        }
        this.dataElements = this.template.dataElements;
        this.keyDiagrams = new Array();
        for (let /** @type {?} */ index = 0; index < this.template.metadata.diagrams.length; index++) {
            const /** @type {?} */ element = new Diagram();
            element.label = this.template.metadata.diagrams[index].label;
            element.location = this.imagePath + '/' + this.template.metadata.diagrams[index].location;
            element.keyDiagram = this.template.metadata.diagrams[index].keyDiagram;
            this.keyDiagrams.push(element);
        }
        this.resultText = undefined;
    }
    /**
     * @return {?}
     */
    resetElements() {
        this.template = this.templateManagerService.getTemplate(this.templateContent);
        this.simulatorEngineService.initialize(this.template);
        this.dataElements = this.template.dataElements;
        this.resultText = undefined;
        this.returnDefaultElements.emit();
    }
    /**
     * @param {?} textReport
     * @return {?}
     */
    recieveReportText(textReport) {
        this.resultText = textReport;
    }
    /**
     * @param {?} finalExecutionHistory
     * @return {?}
     */
    recievedExecutionHistory(finalExecutionHistory) {
        this.returnExecutionHistory.emit(finalExecutionHistory);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    changeListener(event) {
        this.keyDiagrams = new Array();
        for (const /** @type {?} */ image in event.target.files) {
            if (event.target.files.hasOwnProperty(image)) {
                const /** @type {?} */ reader = new FileReader();
                const /** @type {?} */ diagram = new Diagram();
                diagram.label = event.target.files[image].name;
                diagram.keyDiagram = image === '0' ? true : false;
                const /** @type {?} */ imageType = event.target.files[image].imageType;
                const /** @type {?} */ fileStream = event.target.files[image];
                reader.onload = (event1) => {
                    diagram.location = reader.result;
                };
                reader.readAsDataURL(event.target.files[image]);
                reader.onloadend = (event1) => {
                    this.keyDiagrams.push(diagram);
                    this.reloadUI();
                };
            }
        }
    }
    /**
     * @return {?}
     */
    collapseKeyDiagram() {
        if ($('#icon_keydiagram').hasClass('fa fa-minus')) {
            $('#icon_keydiagram').removeClass('fa fa-minus');
            $('#icon_keydiagram').addClass('fa fa-plus');
            $('#body_keydiagram').css({
                'display': 'none'
            });
        }
        else {
            $('#icon_keydiagram').removeClass('fa fa-plus');
            $('#icon_keydiagram').addClass('fa fa-minus');
            $('#body_keydiagram').removeAttr('style');
        }
    }
    /**
     * @return {?}
     */
    collapseReportText() {
        if ($('#icon_reporttext').hasClass('fa fa-minus')) {
            $('#icon_reporttext').removeClass('fa fa-minus');
            $('#icon_reporttext').addClass('fa fa-plus');
            $('#body_reporttext').css({
                'display': 'none'
            });
        }
        else {
            $('#icon_reporttext').removeClass('fa fa-plus');
            $('#icon_reporttext').addClass('fa fa-minus');
            $('#body_reporttext').removeAttr('style');
        }
    }
    /**
     * @return {?}
     */
    reloadUI() {
        setTimeout(_ => {
            init_keyImagesUI();
        });
    }
}
AcrAssistSimulatorComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-simulator',
                template: `<ng-container *ngIf="!isEmptyContent">


  <div *ngIf="reportTextPosition === position.Top">
    <div class="col-sm-12 col-md-12 col-lg-12">
      <div id="div-simulator-block">
        <div class="box box-primary box-solid margin-b-0">
          <div class="box-body">
            <ng-container *ngIf="resultText !== undefined">
              <div id="div-simulator-results-block">
                <div class="box box-primary">
                  <div class="box-header with-border">
                    <h3 class="box-title">Report Text</h3>
                    <div class="box-tools pull-right">
                      <button type="button" class="btn btn-box-tool btn-report-text" (click)="collapseReportText()">
                        <i id="icon_reporttext" class="fa fa-minus"></i>
                      </button>
                    </div>
                  </div>
                  <div id="body_reporttext" class="box-body report-text">
                    <dl>
                      <acr-assist-report-text [reportText]="resultText"></acr-assist-report-text>
                    </dl>
                  </div>
                </div>
              </div>
            </ng-container>
            <div id="div-simulator-form" class="padding-r-10 div-simulator-form-height">
              <div>
                <form class="form-horizontal">
                  <acr-assist-data-element [dataElements]="dataElements" [templatePartial]="template.templatePartial" [endPointXMLString]="template.endPointsString"
                    [imagePath]="imagePath" [xmlContent]="template.xmlContent" (returnReportText)='recieveReportText($event)'
                    [inputValues]="inputValues" [isReset]="isReset" (returnExecutionHistory)='recievedExecutionHistory($event)'></acr-assist-data-element>
                </form>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
  <div *ngIf="reportTextPosition === position.Right">
    <div class="col-sm-6 col-md-6 col-lg-6">
      <div id="div-simulator-block">
        <div class="box box-primary box-solid margin-b-0">
          <div class="box-body">
            <div id="div-simulator-form" class="padding-r-10 div-simulator-form-height">
              <form class="form-horizontal">
                <acr-assist-data-element [dataElements]="dataElements" [templatePartial]="template.templatePartial" [endPointXMLString]="template.endPointsString"
                  [imagePath]="imagePath" [xmlContent]="template.xmlContent" (returnReportText)='recieveReportText($event)'
                  [inputValues]="inputValues" [isReset]="isReset" (returnExecutionHistory)='recievedExecutionHistory($event)'></acr-assist-data-element>
              </form>
            </div>
          </div>
        </div>
      </div>
    </div>
    <div class="col-sm-6 col-md-6 col-lg-6">
      <ng-container *ngIf="resultText !== undefined">
        <div id="div-simulator-results-block">
          <div class="box box-primary">
            <div class="box-header with-border">
              <h3 class="box-title">Report Text</h3>
              <div class="box-tools pull-right">
                <button type="button" class="btn btn-box-tool btn-report-text" (click)="collapseReportText()">
                  <i id="icon_reporttext" class="fa fa-minus"></i>
                </button>
              </div>
            </div>
            <div id="body_reporttext" class="box-body report-text">
              <dl>
                <acr-assist-report-text [reportText]="resultText"></acr-assist-report-text>
              </dl>
            </div>
          </div>
        </div>
      </ng-container>
    </div>
    <div class="col-xs-6 col-sm-6 col-md-12 col-lg-6" id="div-decissionTree-Block" *ngIf="showKeyDiagram === true">
      <div class="box box-primary margin-b-0">
        <div class="box-header with-border">
          <h3 class="box-title">Key Diagrams</h3>
          <input #imageUpload id="diagramUpload" class="hidden" type="file" accept="image/*" multiple (change)="changeListener($event)">
          <label for="diagramUpload" class="btn btn-sm bg-olive margin" style="margin:10px;" title="Choose Diagrams">Choose a Diagram</label>
          <div class="box-tools pull-right">
            <button type="button" class="btn btn-box-tool" data-widget="collapse" (click)="collapseKeyDiagram()">
              <i id="icon_keydiagram" class="fa fa-minus"></i>
            </button>
          </div>
        </div>
        <div id="body_keydiagram" class="box-body">
          <div id="carousel-example-generic" class="carousel slide" data-interval="false" data-ride="carousel">
            <div class="carousel-inner">
              <ng-container *ngFor="let diagram of keyDiagrams; let i = index">
                <div class="item" [ngClass]="{'active': diagram.keyDiagram}">
                  <img class="img-responsive img-decissionTree" src="{{ diagram.location }}" alt="{{ diagram.label }}">
                </div>
              </ng-container>
            </div>
            <a class="left carousel-control" href="#carousel-example-generic" data-slide="prev">
              <span class="fa fa-angle-left"></span>
            </a>
            <a class="right carousel-control" href="#carousel-example-generic" data-slide="next">
              <span class="fa fa-angle-right"></span>
            </a>
          </div>
        </div>
      </div>
    </div>
  </div>
</ng-container>
`,
                styles: [``, `.required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}`]
            },] },
];
/** @nocollapse */
AcrAssistSimulatorComponent.ctorParameters = () => [
    { type: TemplateManagerService, },
    { type: SimulatorEngineService, },
];
AcrAssistSimulatorComponent.propDecorators = {
    "templateContent": [{ type: Input },],
    "imagePath": [{ type: Input },],
    "showKeyDiagram": [{ type: Input },],
    "reportTextPosition": [{ type: Input },],
    "inputValues": [{ type: Input },],
    "inputData": [{ type: Input },],
    "returnExecutionHistory": [{ type: Output },],
    "returnDefaultElements": [{ type: Output },],
    "imageUpload": [{ type: ViewChild, args: ['imageUpload',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @abstract
 */
class DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     */
    constructor(diagramService) {
        this.diagramService = diagramService;
    }
    /**
     * @param {?} diagramJSON
     * @return {?}
     */
    returnDiagram(diagramJSON) {
        const /** @type {?} */ metadataDiagram = new Diagram();
        metadataDiagram.displaySequence = diagramJSON.Attr.DisplaySequence;
        metadataDiagram.keyDiagram = diagramJSON.Attr.IsKeyDiagram ? diagramJSON.Attr.IsKeyDiagram : false;
        metadataDiagram.label = diagramJSON.Label;
        metadataDiagram.location = diagramJSON.Location;
        return metadataDiagram;
    }
    /**
     * @param {?} data
     * @param {?} dataElement
     * @return {?}
     */
    populateBasicData(data, dataElement) {
        dataElement.dataElementType = this.elementType;
        dataElement.displaySequence = data.Attr.DisplaySequence;
        dataElement.id = data.Attr.Id;
        dataElement.isRequired = data.Attr.IsRequired === 'true' ? true : false;
        dataElement.label = data.Label;
        dataElement.hint = data.Hint;
        dataElement.cdeId = data.Attr.CdeId;
        if (data.Diagrams) {
            dataElement.diagrams = this.diagramService.returnDiagrams(data.Diagrams.Diagram);
        }
        dataElement.currentValue = undefined;
        dataElement.defaultValue = undefined;
    }
}
DataElementCreationBaseService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
DataElementCreationBaseService.ctorParameters = () => [
    { type: DiagramService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BaseDataElement {
    constructor() {
        this.isVisible = true;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ChoiceDataElement extends BaseDataElement {
    constructor() {
        super(...arguments);
        this.allowFreetext = false;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Choice {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ImageElements {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ImageMap extends ImageElements {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Area {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AreaMap {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ChoiceDataElementCreationService extends DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     * @param {?} arrayCheckerService
     */
    constructor(diagramService, arrayCheckerService) {
        super(diagramService);
        this.arrayCheckerService = arrayCheckerService;
        this.elementType = 'ChoiceDataElement';
    }
    /**
     * @param {?} choiceItem
     * @return {?}
     */
    returnChoice(choiceItem) {
        const /** @type {?} */ choice = new Choice();
        choice.label = choiceItem.Label;
        choice.value = choiceItem.Value;
        choice.hint = choiceItem.Hint;
        choice.reportText = choiceItem.ReportText;
        choice.default = false;
        if (choiceItem.Attr && choiceItem.Attr.IsDefault) {
            choice.default = choiceItem.Attr.IsDefault;
        }
        return choice;
    }
    /**
     * @param {?} areaJSON
     * @return {?}
     */
    returnArea(areaJSON) {
        const /** @type {?} */ area = new Area();
        area.choiceValue = areaJSON.Attr.ChoiceValue;
        area.coords = areaJSON.Attr.Coords;
        area.shape = areaJSON.Attr.Shape;
        return area;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createElement(data) {
        const /** @type {?} */ dataElement = new ChoiceDataElement();
        super.populateBasicData(data, dataElement);
        dataElement.allowFreetext = data.Attr.AllowFreetext ? data.Attr.AllowFreetext : false;
        const /** @type {?} */ choiceItems = data.ChoiceInfo.Choice;
        let /** @type {?} */ defaultValue;
        if (choiceItems !== undefined) {
            dataElement.choiceInfo = new Array();
            if (this.arrayCheckerService.isArray(choiceItems)) {
                for (const /** @type {?} */ choiceItem of choiceItems) {
                    const /** @type {?} */ choice = this.returnChoice(choiceItem);
                    if (choice.default) {
                        defaultValue = choice.value;
                    }
                    dataElement.choiceInfo.push(choice);
                }
            }
            else {
                const /** @type {?} */ choice = this.returnChoice(choiceItems);
                if (choice.default) {
                    defaultValue = choice.value;
                }
                dataElement.choiceInfo.push(choice);
            }
        }
        dataElement.defaultValue = defaultValue;
        dataElement.currentValue = defaultValue;
        const /** @type {?} */ imageMap = data.ImageMap;
        if (imageMap !== undefined) {
            dataElement.imageMap = new ImageMap();
            dataElement.imageMap.location = imageMap.Location;
            const /** @type {?} */ areaMaps = imageMap.Map.Area;
            if (areaMaps !== undefined) {
                dataElement.imageMap.map = new AreaMap();
                dataElement.imageMap.map.areas = new Array();
                if (this.arrayCheckerService.isArray(areaMaps)) {
                    for (const /** @type {?} */ areaMap of areaMaps) {
                        dataElement.imageMap.map.areas.push(this.returnArea(areaMap));
                    }
                }
                else {
                    dataElement.imageMap.map.areas.push(this.returnArea(areaMaps));
                }
            }
        }
        return dataElement;
    }
}
ChoiceDataElementCreationService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ChoiceDataElementCreationService.ctorParameters = () => [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class MultipleChoiceDataElementCreationService extends ChoiceDataElementCreationService {
    /**
     * @param {?} diagramService
     * @param {?} arrayCheckerService
     */
    constructor(diagramService, arrayCheckerService) {
        super(diagramService, arrayCheckerService);
        this.elementType = 'MultiChoiceDataElement';
    }
}
MultipleChoiceDataElementCreationService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
MultipleChoiceDataElementCreationService.ctorParameters = () => [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NumericDataElement extends BaseDataElement {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NumericDataElementCreationService extends DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     */
    constructor(diagramService) {
        super(diagramService);
        this.elementType = 'NumericDataElement';
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createElement(data) {
        const /** @type {?} */ dataElement = new NumericDataElement();
        super.populateBasicData(data, dataElement);
        dataElement.minimum = data.Minimum;
        dataElement.maximum = data.Maximum;
        return dataElement;
    }
}
NumericDataElementCreationService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
NumericDataElementCreationService.ctorParameters = () => [
    { type: DiagramService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IntegerDataElement extends BaseDataElement {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class IntegerDataElementCreationService extends DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     */
    constructor(diagramService) {
        super(diagramService);
        this.elementType = 'IntegerDataElement';
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createElement(data) {
        const /** @type {?} */ dataElement = new IntegerDataElement();
        super.populateBasicData(data, dataElement);
        dataElement.minimum = data.Minimum;
        dataElement.maximum = data.Maximum;
        return dataElement;
    }
}
IntegerDataElementCreationService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
IntegerDataElementCreationService.ctorParameters = () => [
    { type: DiagramService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const $$1 = require('jquery');
class AssistDataElementComponent {
    /**
     * @param {?} simulatorEngineService
     */
    constructor(simulatorEngineService) {
        this.simulatorEngineService = simulatorEngineService;
        this.Endpoints = [];
        this.returnReportText = new EventEmitter();
        this.returnExecutionHistory = new EventEmitter();
        this.comparisonValues = [];
        this.selectedChoiceValues = [];
        this.executedResultIds = [];
        this.executedResultHistories = [];
        this.inputValues = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.simulatorEngineService.simulatorStateChanged.subscribe((message) => {
            this.simulatorState = /** @type {?} */ (message);
            this.dataElementValues = this.simulatorEngineService.getAllDataElementValues();
            for (const /** @type {?} */ dataElement of this.dataElements) {
                if (this.simulatorState.nonRelevantDataElementIds && this.simulatorState.nonRelevantDataElementIds.length > 0) {
                    if (this.simulatorState.nonRelevantDataElementIds.indexOf(dataElement.id) >= 0) {
                        dataElement.isVisible = false;
                    }
                    else {
                        dataElement.isVisible = true;
                    }
                }
                else {
                    dataElement.isVisible = true;
                }
                dataElement.currentValue = (dataElement.currentValue !== undefined) ? dataElement.currentValue : this.dataElementValues[dataElement.id];
            }
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateReportText(this.simulatorState.endPointId);
            }
            else {
                this.returnReportText.emit(undefined);
            }
        });
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.dataElements = this.dataElements.filter(x => x.displaySequence != null).sort(function (DE_1, DE_2) { return DE_1.displaySequence - DE_2.displaySequence; });
        this.executedResultIds = [];
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    choiceSelected($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.selectedChoiceValues[$event.receivedElement.elementId + 'SelectedValue'] = $event.receivedElement.selectedText;
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedValue, $event.receivedElement.selectedText);
            const /** @type {?} */ executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    numericSelected($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedValue, $event.receivedElement.selectedValue);
            const /** @type {?} */ executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    multiSelected($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.comparisonValues[$event.receivedElement.elementId + 'ComparisonValue'] = $event.receivedElement.selectedComparisonValues;
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedComparisonValues, $event.receivedElement.selectedValues);
            const /** @type {?} */ executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    }
    /**
     * @param {?} inputValues
     * @param {?} isReset
     * @return {?}
     */
    load(inputValues, isReset) {
        if (inputValues !== undefined) {
            if (isReset) {
                $$1('select').prop('selectedIndex', 0);
            }
            this.returnReportText.emit(undefined);
            for (const /** @type {?} */ inputValue of inputValues) {
                if (inputValue !== undefined) {
                    for (const /** @type {?} */ dataElement of this.dataElements) {
                        if (dataElement.id === inputValue.dataElementId) {
                            switch (dataElement.dataElementType) {
                                case 'ChoiceDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        if (!isReset) {
                                            $$1('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).prop('checked', true);
                                            this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                        }
                                        else {
                                            $$1('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).prop('checked', false);
                                            // $('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).trigger('click');
                                            this.isReset = true;
                                        }
                                    }
                                    break;
                                case 'IntegerDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        if (!isReset) {
                                            $$1('#' + inputValue.dataElementId).val(inputValue.dataElementValue);
                                            this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                            $$1('#' + inputValue.dataElementId).trigger('change');
                                        }
                                        else {
                                            $$1('#' + inputValue.dataElementId).val('');
                                            $$1('#' + inputValue.dataElementId).trigger('change');
                                        }
                                        const /** @type {?} */ customEvent = document.createEvent('Event');
                                        customEvent.initEvent('change', true, true);
                                        $$1('#' + inputValue.dataElementId)[0].dispatchEvent(customEvent);
                                    }
                                    break;
                                case 'NumericDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        if (!isReset) {
                                            $$1('#' + inputValue.dataElementId).val(inputValue.dataElementValue);
                                            this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                            $$1('#' + inputValue.dataElementId).trigger('keyup');
                                        }
                                        else {
                                            $$1('#' + inputValue.dataElementId).val('');
                                            $$1('#' + inputValue.dataElementId).trigger('keyup');
                                        }
                                        const /** @type {?} */ customEvent = document.createEvent('Event');
                                        customEvent.initEvent('change', true, true);
                                        $$1('#' + inputValue.dataElementId)[0].dispatchEvent(customEvent);
                                    }
                                    break;
                                case 'MultiChoiceDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        const /** @type {?} */ customEvent = document.createEvent('Event');
                                        customEvent.initEvent('change', true, true);
                                        if (inputValue.dataElementValue.length !== undefined && inputValue.dataElementValue.length > 0) {
                                            if (!isReset) {
                                                if (Array.isArray(inputValue.dataElementValue)) {
                                                    for (const /** @type {?} */ element in inputValue.dataElementValue) {
                                                        $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element]).prop('checked', true);
                                                        $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element])[0].dispatchEvent(customEvent);
                                                    }
                                                }
                                                else {
                                                    $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue).prop('checked', true);
                                                    $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue)[0].dispatchEvent(customEvent);
                                                }
                                            }
                                            else {
                                                if (Array.isArray(inputValue.dataElementValue)) {
                                                    for (const /** @type {?} */ element in inputValue.dataElementValue) {
                                                        $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element]).prop('checked', false);
                                                        customEvent.initEvent('change', true, true);
                                                        $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element])[0].dispatchEvent(customEvent);
                                                    }
                                                }
                                                else {
                                                    $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue).prop('checked', false);
                                                    $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue)[0].dispatchEvent(customEvent);
                                                }
                                            }
                                        }
                                    }
                                    break;
                            }
                        }
                    }
                }
            }
        }
        else {
            throw console.error('Invalid values');
        }
    }
    /**
     * @param {?} endpointId
     * @return {?}
     */
    generateReportText(endpointId) {
        const /** @type {?} */ endpointContent = this.returnEndPointContents(this.xmlContent, '<EndPoint Id="' + endpointId + '">', '</EndPoint>');
        this.parseXml(endpointId, endpointContent);
    }
    /**
     * @return {?}
     */
    generateExecutionHistory() {
        this.executedResultHistories = [];
        let /** @type {?} */ isNonRelevant;
        isNonRelevant = false;
        for (const /** @type {?} */ resultId in this.executedResultIds) {
            for (const /** @type {?} */ nonRelevantDataElement of this.simulatorState.nonRelevantDataElementIds) {
                if (nonRelevantDataElement === resultId) {
                    isNonRelevant = true;
                    break;
                }
                else {
                    isNonRelevant = false;
                }
            }
            if (!isNonRelevant) {
                for (const /** @type {?} */ label in this.executedResultIds[resultId]) {
                    const /** @type {?} */ executedResultHistory = new ExecutedResultHistory();
                    executedResultHistory.resultCondition = label;
                    executedResultHistory.resultValue = this.executedResultIds[resultId][label];
                    this.executedResultHistories.push(executedResultHistory);
                }
            }
        }
        const /** @type {?} */ finalExecution = new FinalExecutedHistory();
        if (this.executedResultHistories.length > 0) {
            finalExecution.executionHistories = this.executedResultHistories;
            finalExecution.resultText = this.mainReportTextObj;
        }
        this.returnExecutionHistory.emit(finalExecution);
    }
    /**
     * @param {?} content
     * @param {?} startToken
     * @param {?} endToken
     * @return {?}
     */
    returnEndPointContents(content, startToken, endToken) {
        let /** @type {?} */ contents;
        let /** @type {?} */ templateSearchIndexPosition = 0;
        while (true) {
            const /** @type {?} */ contentStartPosition = content.indexOf(startToken, templateSearchIndexPosition);
            const /** @type {?} */ contentEndPosition = content.indexOf(endToken, templateSearchIndexPosition);
            if (contentStartPosition >= 0 && contentEndPosition >= 0) {
                const /** @type {?} */ endPosition = contentEndPosition + endToken.length;
                const /** @type {?} */ contentData = content.substring(contentStartPosition, endPosition);
                contents = contentData;
                templateSearchIndexPosition = endPosition + 1;
            }
            else {
                break;
            }
        }
        return contents;
    }
    /**
     * @param {?} endPointId
     * @param {?} endpointContent
     * @return {?}
     */
    parseXml(endPointId, endpointContent) {
        let /** @type {?} */ canInsertText;
        let /** @type {?} */ isSectionIf;
        let /** @type {?} */ selectedElements;
        let /** @type {?} */ executeSectionIfNot;
        let /** @type {?} */ hasSectionNot;
        let /** @type {?} */ executeTemplate;
        let /** @type {?} */ isImpression;
        let /** @type {?} */ isNewTemplate;
        let /** @type {?} */ hasInsertPartial;
        let /** @type {?} */ isMainText;
        const /** @type {?} */ allReportText = [];
        const /** @type {?} */ endpoints = this.Endpoints;
        let /** @type {?} */ templatePartialsText;
        let /** @type {?} */ selectedComparisonValues;
        let /** @type {?} */ findingsText;
        let /** @type {?} */ impressionText;
        let /** @type {?} */ selectedSection;
        let /** @type {?} */ selectedChoiceTexts;
        let /** @type {?} */ textExpressionValue;
        selectedElements = this.simulatorEngineService.getAllDataElementValues();
        templatePartialsText = this.templatePartial;
        selectedComparisonValues = this.comparisonValues;
        selectedChoiceTexts = this.simulatorEngineService.getAllDataElementTexts();
        executeSectionIfNot = false;
        hasInsertPartial = false;
        findingsText = '';
        impressionText = '';
        let /** @type {?} */ isReportText;
        let /** @type {?} */ reportTextContent = '';
        const /** @type {?} */ endpointSax = require('sax'), /** @type {?} */
        strict = true, /** @type {?} */
        normalize = true, /** @type {?} */
        // set to false for html-mode
        trim = true, /** @type {?} */
        reportTextParser = endpointSax.parser(strict, trim);
        reportTextParser.onerror = function (e) {
            // an error happened.
            reportTextParser.resume();
        };
        reportTextParser.ontext = function (t) {
            if (t.length > 1) {
                t = t.trim();
            }
            let /** @type {?} */ isTextInserted;
            isTextInserted = false;
            if (executeTemplate) {
                if (!isImpression) {
                    if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                        findingsText = findingsText + t;
                    }
                    else if (canInsertText && isNewTemplate && hasInsertPartial && !isSectionIf) {
                        findingsText = findingsText + t;
                    }
                    else if (canInsertText && !isImpression) {
                        findingsText = findingsText + t;
                    }
                }
                else {
                    if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                        impressionText = impressionText + t;
                    }
                    else if (canInsertText && !hasSectionNot && isImpression) {
                        impressionText = impressionText + t;
                    }
                    else if (canInsertText && isNewTemplate) {
                        impressionText = impressionText + t;
                    }
                }
                if (isReportText && !isTextInserted && isMainText && canInsertText) {
                    reportTextContent = reportTextContent + t;
                }
            }
        };
        reportTextParser.onopentag = function (node) {
            switch (node.name) {
                case 'Label':
                    canInsertText = false;
                    isReportText = false;
                    isMainText = false;
                    break;
                case 'ReportText':
                    if (executeTemplate) {
                        isReportText = true;
                        canInsertText = true;
                        selectedSection = node.attributes.SectionId;
                        impressionText = '';
                        if (node.attributes.SectionId === 'findings' && executeTemplate) {
                            isImpression = false;
                        }
                        else if (node.attributes.SectionId === 'impression' && executeTemplate) {
                            isImpression = true;
                        }
                    }
                    isSectionIf = false;
                    // isMainText = true;
                    break;
                case 'InsertPartial':
                    if (executeTemplate) {
                        generatePartialView(node.attributes.PartialId, isImpression);
                        executeTemplate = true;
                        canInsertText = true;
                        if (isReportText) {
                            hasInsertPartial = true;
                        }
                        else {
                            hasInsertPartial = false;
                        }
                    }
                    else {
                        canInsertText = false;
                    }
                    isReportText = false;
                    isMainText = false;
                    break;
                case 'SectionIfValueNot':
                    if (executeTemplate) {
                        if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                            for (const /** @type {?} */ comaprisonValue of selectedElements[node.attributes.DataElementId]) {
                                if (comaprisonValue !== node.attributes.ComparisonValue &&
                                    comaprisonValue !== undefined && !isSectionIf) {
                                    canInsertText = true;
                                    executeSectionIfNot = true;
                                    break;
                                }
                                else {
                                    canInsertText = false;
                                    executeSectionIfNot = false;
                                }
                            }
                        }
                        else if (selectedElements[node.attributes.DataElementId] !== node.attributes.ComparisonValue &&
                            selectedElements[node.attributes.DataElementId] !== '--Select--' &&
                            selectedElements[node.attributes.DataElementId] !== undefined &&
                            selectedElements[node.attributes.DataElementId] !== null) {
                            canInsertText = true;
                            executeSectionIfNot = true;
                        }
                        else {
                            canInsertText = false;
                            executeSectionIfNot = false;
                        }
                    }
                    hasSectionNot = true;
                    isMainText = false;
                    break;
                case 'SectionIf':
                    if (selectedElements[node.attributes.DataElementId] !== undefined && selectedElements[node.attributes.DataElementId].length > 0 && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                        isSectionIf = true;
                        canInsertText = true;
                    }
                    else {
                        isSectionIf = false;
                        canInsertText = false;
                    }
                    break;
                case 'SectionIfValue':
                    if (executeTemplate) {
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                for (const /** @type {?} */ comaprisonValue of selectedElements[node.attributes.DataElementId]) {
                                    if (comaprisonValue === node.attributes.ComparisonValue &&
                                        comaprisonValue !== undefined) {
                                        isSectionIf = true;
                                        if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                            findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                        }
                                        canInsertText = true;
                                        break;
                                    }
                                    else {
                                        isSectionIf = false;
                                        canInsertText = false;
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] === node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== undefined) {
                                isSectionIf = true;
                                if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                    findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                }
                                canInsertText = true;
                            }
                            else {
                                canInsertText = false;
                            }
                        }
                        break;
                    }
                    isMainText = false;
                    break;
                case 'InsertValue':
                    if (executeTemplate) {
                        isReportText = false;
                        const /** @type {?} */ choiceText = selectedChoiceTexts[node.attributes.DataElementId];
                        if (node.attributes.Id === 'findings' || canInsertText) {
                            if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot) {
                                if (isImpression) {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        impressionText = impressionText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                                else {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        findingsText = findingsText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot) {
                                if (isImpression) {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        impressionText = impressionText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                                else {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        findingsText = findingsText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                            }
                            if (isImpression) {
                                canInsertText = true;
                            }
                        }
                        isMainText = false;
                        break;
                    }
            }
            executeTemplate = true;
            isNewTemplate = true;
        };
        reportTextParser.onclosetag = function (node) {
            switch (node) {
                case 'SectionIfValueNot':
                    executeSectionIfNot = false;
                    hasSectionNot = false;
                    if (isSectionIf) {
                        canInsertText = true;
                    }
                    break;
                case 'TemplatePartial':
                    isNewTemplate = false;
                    canInsertText = false;
                    executeTemplate = false;
                    break;
                case 'ReportText':
                    // isImpression = false;
                    if (!hasInsertPartial && !isImpression) {
                        const /** @type {?} */ reportTextObj = new AllReportText();
                        reportTextObj.sectionId = 'findings';
                        reportTextObj.reportText = findingsText;
                        allReportText[reportTextObj.sectionId] = reportTextObj;
                    }
                    if (impressionText !== '' && impressionText !== undefined) {
                        const /** @type {?} */ reportTextObj = new AllReportText();
                        reportTextObj.sectionId = selectedSection;
                        reportTextObj.reportText = impressionText;
                        allReportText[reportTextObj.sectionId] = reportTextObj;
                    }
                    hasInsertPartial = false;
                    break;
                case 'SectionIf':
                    isSectionIf = false;
                    canInsertText = true;
                    break;
                case 'InsertPartial':
                    canInsertText = true;
                    break;
                case 'InsertValue':
                    if ((hasSectionNot && executeSectionIfNot || !hasSectionNot)) {
                        canInsertText = true;
                    }
                    break;
                case 'SectionIfValue':
                    canInsertText = true;
                    break;
            }
        };
        reportTextParser.onend = function () {
            // parser stream is done, and ready to have more stuff written to it.
            // if (impressionText !== '' && impressionText !== undefined) {
            // const reportTextObj: AllReportText = new AllReportText();
            // reportTextObj.sectionId = selectedSection;
            // reportTextObj.reportText = impressionText;
            // allReportText[reportTextObj.sectionId] = reportTextObj;
            // }
        };
        reportTextParser.write(endpointContent).onend();
        /**
         * @param {?} textExpression
         * @return {?}
         */
        function getTextExpressionValue(textExpression) {
            if (textExpression.indexOf('{') === 0 && (textExpression.indexOf('}') > 1)) {
                const /** @type {?} */ subString = textExpression.substr(textExpression.indexOf('{') + 1, textExpression.indexOf('}') - 1);
                getTextExpressionValue(selectedElements[subString]);
            }
            else {
                textExpressionValue = textExpression;
            }
        }
        /**
         * @param {?} partialViewId
         * @param {?} isImpressionTemplate
         * @return {?}
         */
        function generatePartialView(partialViewId, isImpressionTemplate) {
            // this.templateIds = [];
            const /** @type {?} */ sax = require('sax'), /** @type {?} */
            parser = sax.parser(strict, trim);
            parser.onerror = function (e) {
                // an error happened.
                // parser.resume();
            };
            parser.ontext = function (t) {
                if (executeTemplate) {
                    if (!isImpressionTemplate) {
                        if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                            findingsText = findingsText + t;
                        }
                        else if (canInsertText && !hasSectionNot && isImpression) {
                            findingsText = findingsText + t;
                        }
                        else if (canInsertText && isNewTemplate) {
                            findingsText = findingsText + t;
                        }
                    }
                    else {
                        if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                            impressionText = impressionText + t;
                        }
                        else if (canInsertText && !hasSectionNot && isImpression) {
                            impressionText = impressionText + t;
                        }
                        else if (canInsertText && isNewTemplate) {
                            impressionText = impressionText + t;
                        }
                    }
                }
            };
            parser.onopentag = function (node) {
                switch (node.name) {
                    case 'Label':
                        canInsertText = false;
                        break;
                    case 'EndPoint':
                        if (node.attributes.Id !== '') {
                            canInsertText = true;
                            isImpression = true;
                        }
                        else {
                            canInsertText = false;
                            isImpression = false;
                        }
                        break;
                    case 'InsertPartial':
                        canInsertText = false;
                        break;
                    case 'ReportText':
                        canInsertText = true;
                        break;
                    case 'TemplatePartial':
                        hasSectionNot = false;
                        executeSectionIfNot = false;
                        if (node.attributes.Id === partialViewId) {
                            executeTemplate = true;
                            canInsertText = true;
                            isNewTemplate = true;
                            break;
                        }
                        else {
                            isNewTemplate = false;
                            executeTemplate = false;
                        }
                        break;
                    case 'SectionIfValueNot':
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                for (const /** @type {?} */ comaprisonValue of selectedComparisonValues[node.attributes.DataElementId + 'ComparisonValue']) {
                                    if (comaprisonValue !== node.attributes.ComparisonValue &&
                                        comaprisonValue !== undefined && !isSectionIf) {
                                        canInsertText = true;
                                        executeSectionIfNot = true;
                                        break;
                                    }
                                    else {
                                        canInsertText = false;
                                        executeSectionIfNot = false;
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] !== node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== '--Select--' &&
                                selectedElements[node.attributes.DataElementId] !== undefined &&
                                selectedElements[node.attributes.DataElementId] !== null) {
                                canInsertText = true;
                                executeSectionIfNot = true;
                            }
                            else {
                                canInsertText = false;
                                executeSectionIfNot = false;
                            }
                        }
                        hasSectionNot = true;
                        break;
                    case 'SectionIf':
                        if (selectedElements[node.attributes.DataElementId] !== undefined && selectedElements[node.attributes.DataElementId].length > 0 && (!hasSectionNot || (hasSectionNot && executeSectionIfNot))
                            && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                            isSectionIf = true;
                            canInsertText = true;
                        }
                        else {
                            isSectionIf = false;
                            canInsertText = false;
                        }
                        break;
                    case 'SectionIfValue':
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                for (const /** @type {?} */ comaprisonValue of selectedComparisonValues[node.attributes.DataElementId + 'ComparisonValue']) {
                                    if (comaprisonValue === node.attributes.ComparisonValue &&
                                        comaprisonValue !== undefined) {
                                        isSectionIf = true;
                                        if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                            findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                        }
                                        canInsertText = true;
                                        break;
                                    }
                                    else {
                                        isSectionIf = false;
                                        canInsertText = false;
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] === node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== undefined) {
                                isSectionIf = true;
                                if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                    findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                }
                                canInsertText = true;
                            }
                            else {
                                canInsertText = false;
                            }
                        }
                        break;
                    case 'InsertValue':
                        if (executeTemplate) {
                            const /** @type {?} */ choiceText = selectedChoiceTexts[node.attributes.DataElementId];
                            if (node.attributes.Id === 'findings' || canInsertText) {
                                if (isImpression) {
                                    canInsertText = true;
                                    if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                        else {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                    else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                        else {
                                            if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                                impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                            }
                                        }
                                    }
                                }
                                else {
                                    if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                    else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                }
                            }
                            break;
                        }
                }
            };
            parser.onclosetag = function (node) {
                switch (node) {
                    case 'SectionIfValueNot':
                        executeSectionIfNot = false;
                        hasSectionNot = false;
                        if (isSectionIf) {
                            canInsertText = true;
                        }
                        break;
                    case 'TemplatePartial':
                        isNewTemplate = true;
                        canInsertText = false;
                        executeTemplate = true;
                        break;
                    case 'InsertPartial':
                        canInsertText = true;
                        break;
                    case 'SectionIf' || 'SectionIfValue':
                        isSectionIf = false;
                        break;
                }
            };
            parser.onend = function () {
                // parser stream is done, and ready to have more stuff written to it.
                const /** @type {?} */ reportTextObj = new AllReportText();
                reportTextObj.sectionId = 'findings';
                reportTextObj.reportText = findingsText;
                allReportText[reportTextObj.sectionId] = reportTextObj;
            };
            parser.write(templatePartialsText).onend();
        }
        this.mainReportTextObj = new MainReportText();
        this.mainReportTextObj.reportTextMainContent = reportTextContent;
        this.mainReportTextObj.allReportText = allReportText;
        this.returnReportText.emit(this.mainReportTextObj);
    }
}
AssistDataElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-data-element',
                template: `<ng-container *ngFor="let DataElement of dataElements">
  <ng-container *ngIf="(DataElement.dataElementType == 'ChoiceDataElement' || DataElement.dataElementType == 'NumericDataElement' || DataElement.dataElementType == 'IntegerDataElement' || DataElement.dataElementType == 'MultiChoiceDataElement') ">
    <ng-container *ngIf="DataElement.isVisible">
      <div id="div_{{DataElement.id}}">
        <ng-container *ngIf="DataElement.dataElementType == 'ChoiceDataElement'">
          <acr-assist-choice-element [choiceDataElement]='DataElement' [imagePath]='imagePath' (returnChoiceElement)='choiceSelected($event)'></acr-assist-choice-element>
        </ng-container>
        <ng-container *ngIf="DataElement.dataElementType == 'MultiChoiceDataElement'">
          <acr-assist-multi-choice-element [multiChoiceElement]='DataElement' [imagePath]='imagePath' (returnMultiChoice)='multiSelected($event)'></acr-assist-multi-choice-element>
        </ng-container>
        <ng-container *ngIf="DataElement.dataElementType == 'NumericDataElement' || DataElement.dataElementType == 'IntegerDataElement'">
          <acr-assist-numeric-element [numericDataElement]='DataElement' [imagePath]='imagePath' (returnNumericElement)='numericSelected($event)'></acr-assist-numeric-element>
        </ng-container>
      </div>
    </ng-container>
  </ng-container>
</ng-container>
`,
                styles: [``, `.required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}`]
            },] },
];
/** @nocollapse */
AssistDataElementComponent.ctorParameters = () => [
    { type: SimulatorEngineService, },
];
AssistDataElementComponent.propDecorators = {
    "dataElements": [{ type: Input },],
    "imagePath": [{ type: Input },],
    "Endpoints": [{ type: Input },],
    "templatePartial": [{ type: Input },],
    "endPointXMLString": [{ type: Input },],
    "xmlContent": [{ type: Input },],
    "returnReportText": [{ type: Output },],
    "returnExecutionHistory": [{ type: Output },],
    "isReset": [{ type: Input },],
    "inputValues": [{ type: Input },],
};
class ChoiceElement {
}
class NumericElement {
}
class MultiChoiceElement {
}

class MainReportText {
}
class AllReportText {
}
class ExecutedResultHistory {
}
class FinalExecutedHistory {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class HintDiagramComponent {
    constructor() {
        this.activeSlideIndex = 0;
    }
    /**
     * @return {?}
     */
    resetCarouselIndex() {
        this.activeSlideIndex = 0;
    }
}
HintDiagramComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-hint-diagram',
                template: `<ng-container *ngIf="DataElement !== undefined">
  <button type="button" class="btn btn-default btn-xs" data-toggle="modal" attr.data-target="#{{'diag_'+DataElement.id}}" (click)="resetCarouselIndex()">
    <span class="glyphicon glyphicon-picture" aria-hidden="true" data-toggle="tooltip" data-placement="right" title="Hint Diagrams"></span>
  </button>
  <div class="modal inmodal fade" id="{{'diag_'+DataElement.id}}" tabindex="-1" role="dialog" aria-hidden="true">
    <div class="modal-dialog modal-lg">
      <div class="modal-content">
        <div class="modal-header">
          <button type="button" class="close" data-dismiss="modal">
            <span aria-hidden="true">&times;</span>
            <span class="sr-only">Close</span>
          </button>
          <h4 class="modal-title float-left">{{DataElement.label}}</h4>
        </div>
        <div class="modal-body">
          <ng-container>
            <carousel [(activeSlide)]="activeSlideIndex" interval="false">
              <ng-container *ngFor="let diag of DataElement.diagrams ">
                <slide>
                  <img src="{{imagePath}}/{{diag.location}}" alt="Image Not Available!!!">
                </slide>
              </ng-container>
            </carousel>
          </ng-container>
        </div>
        <div class="modal-footer">
          <button type="button" class="btn btn-primary" data-dismiss="modal">Close</button>
        </div>
      </div>
    </div>
  </div>
</ng-container>
`,
                styles: [``, `.required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}`]
            },] },
];
/** @nocollapse */
HintDiagramComponent.propDecorators = {
    "DataElement": [{ type: Input },],
    "imagePath": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class GlobalValue extends BaseDataElement {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class GlobalValueCreationService extends DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     */
    constructor(diagramService) {
        super(diagramService);
        this.elementType = 'GlobalValue';
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createElement(data) {
        const /** @type {?} */ dataElement = new GlobalValue();
        dataElement.id = data.Attr.Id;
        dataElement.currentValue = data._;
        dataElement.dataElementType = 'GlobalValue';
        return dataElement;
    }
}
GlobalValueCreationService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
GlobalValueCreationService.ctorParameters = () => [
    { type: DiagramService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SelectedCondition {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const $$2 = require('jquery');
class AssistNumericElementComponent {
    /**
     * @param {?} formBuilder
     * @param {?} simulatorEngineService
     */
    constructor(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnNumericElement = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.createNumericElementForm();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        if (this.numericDataElement.currentValue !== undefined && this.numericDataElement.currentValue !== 0) {
            this.simulatorEngineService.addOrUpdateDataElement(this.numericDataElement.id, this.numericDataElement.currentValue, this.numericDataElement.currentValue);
            const /** @type {?} */ customEvent = document.createEvent('Event');
            // customEvent.initEvent('change', true, true);
            // $('#' + this.numericDataElement.id)[0].dispatchEvent(customEvent);
            this.numberValue = this.numericDataElement.currentValue;
            this.loadedNumericValue(this.numericDataElement.id, this.numericDataElement.currentValue, this.numericDataElement.label);
        }
    }
    /**
     * @param {?} id
     * @param {?} value
     * @param {?} selectedCondition
     * @return {?}
     */
    loadedNumericValue(id, value, selectedCondition) {
        const /** @type {?} */ choiceElement = new NumericElement();
        choiceElement.elementId = id;
        choiceElement.selectedValue = value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = value;
        this.returnNumericElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @param {?} element
     * @param {?} selectedCondition
     * @return {?}
     */
    choiceSelected(element, selectedCondition) {
        const /** @type {?} */ choiceElement = new NumericElement();
        choiceElement.elementId = element.id;
        choiceElement.selectedValue = element.value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = element.id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.value;
        this.returnNumericElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @return {?}
     */
    createNumericElementForm() {
        this.numericElementForm = this.formBuilder.group({
            numericElement: ['', Validators.compose([Validators.required, Validators.min(+this.numericDataElement.minimum)])],
        });
    }
    /**
     * @param {?} numericKey
     * @return {?}
     */
    specificValueInsideRange(numericKey) {
        return (group) => {
            const /** @type {?} */ numericControl = group.controls[numericKey];
            if ((numericControl.value === 'undefined' || numericControl.value === '') && this.numericDataElement.isRequired) {
                return numericControl.setErrors({ notEquivalent: true });
            }
            else {
                return numericControl.setErrors(null);
            }
        };
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onlyNumberKey(event) {
        return (event.charCode === 8 || event.charCode === 0) ? null : event.charCode >= 48 && event.charCode <= 57;
    }
}
AssistNumericElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-numeric-element',
                template: `<form [formGroup]="numericElementForm" novalidate>
  <div class="form-group">
    <div class="col-sm-5 text-right">
      <label class="control-label">
        {{numericDataElement.label}}
      </label>
      <ng-container *ngIf="numericDataElement.hint !== '' && numericDataElement.hint !== undefined">
        <i class="fa fa-info-circle text-primary" title="{{numericDataElement.hint}}"></i>
      </ng-container>
      <ng-container *ngIf="numericDataElement.diagrams != undefined ">
        <acr-hint-diagram [DataElement]="numericDataElement" [imagePath]="imagePath"></acr-hint-diagram>
      </ng-container>
      <ng-container *ngIf="this.numericDataElement.isRequired">
        <span *ngIf="numericElementForm.controls['numericElement'].invalid">
          <span *ngIf="numericElementForm.controls['numericElement'].errors.required" class="required-field" title="Required Field">
            *
          </span>
        </span>
      </ng-container>
      <span *ngIf="numericElementForm.controls['numericElement'].invalid && numericElementForm.controls['numericElement'].errors.min"
        class="required-field" title=" Minimum value is {{numericDataElement.minimum}}">
        *
      </span>
    </div>
    <ng-container *ngIf="numericDataElement.dataElementType === 'NumericDataElement'">
      <div class="col-sm-7">
        <input [(ngModel)]="numberValue" id="{{numericDataElement.id}}" type="number" class="form-control" formControlName="numericElement"
          (keypress)="onlyNumberKey($event)" onpaste="return false;" (input)="choiceSelected($event.target, numericDataElement.label)"
          min="{{numericDataElement.minimum}}" required>
      </div>
    </ng-container>
    <ng-container *ngIf="numericDataElement.dataElementType === 'IntegerDataElement'">
      <div class="col-sm-7">
        <input [(ngModel)]="numberValue" id="{{numericDataElement.id}}" type="number" class="form-control" formControlName="numericElement"
          (keypress)="onlyNumberKey($event)" onpaste="return false;" (input)="choiceSelected($event.target, numericDataElement.label)"
          min="{{numericDataElement.minimum}}" required>
      </div>
    </ng-container>
  </div>
</form>
`,
                styles: [``, `.required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}`]
            },] },
];
/** @nocollapse */
AssistNumericElementComponent.ctorParameters = () => [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
];
AssistNumericElementComponent.propDecorators = {
    "numericDataElement": [{ type: Input },],
    "imagePath": [{ type: Input },],
    "returnNumericElement": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const $$3 = require('jquery');
class AssistChoiceElementComponent {
    /**
     * @param {?} formBuilder
     * @param {?} simulatorEngineService
     */
    constructor(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnChoiceElement = new EventEmitter();
        this.choiceChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.createChoiceElementForm();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        $$3('#div_' + this.choiceDataElement.id + '_other').hide();
        if (this.choiceDataElement.currentValue !== undefined) {
            $$3('#' + this.choiceDataElement.currentValue + '_' + this.choiceDataElement.id).prop('checked', true);
            this.choiceValue = this.choiceDataElement.currentValue;
            for (const /** @type {?} */ choice in this.choiceDataElement.choiceInfo) {
                if (this.choiceDataElement.choiceInfo[choice].value === this.choiceDataElement.currentValue) {
                    if (this.choiceDataElement.choiceInfo[choice].reportText !== undefined) {
                        this.selectedChoiceReportText = this.choiceDataElement.choiceInfo[choice].reportText;
                    }
                    else {
                        this.selectedChoiceReportLabel = this.choiceDataElement.choiceInfo[choice].label;
                    }
                }
            }
            if (this.choiceDataElement.choiceInfo.length <= 5) {
                this.updateChoiceValue(this.choiceDataElement.id, this.choiceDataElement.label, (this.selectedChoiceReportText !== undefined) ? this.selectedChoiceReportText : this.selectedChoiceReportLabel, this.choiceDataElement.currentValue);
            }
            else {
                this.updateDropdownChoiceSelected(this.choiceDataElement.id, this.selectedChoiceReportLabel, this.choiceDataElement.currentValue, this.choiceDataElement.label);
            }
        }
    }
    /**
     * @param {?} elementId
     * @param {?} selectedElement
     * @param {?} selectedText
     * @param {?} selectedValue
     * @return {?}
     */
    updateChoiceValue(elementId, selectedElement, selectedText, selectedValue) {
        const /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = selectedValue;
        choiceElement.selectedText = selectedText;
        this.showOrHideFreeText(elementId, choiceElement.selectedValue);
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedElement;
        this.selectedCondition.selectedValue = selectedText;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @param {?} elementId
     * @param {?} elementLabel
     * @param {?} elementValue
     * @param {?} selectedCondition
     * @return {?}
     */
    updateDropdownChoiceSelected(elementId, elementLabel, elementValue, selectedCondition) {
        const /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = elementValue;
        choiceElement.selectedText = elementLabel;
        if (this.choiceValue === 'undefined' || this.choiceValue === undefined || this.choiceValue === '') {
            choiceElement.selectedText = '';
            choiceElement.selectedValue = '';
        }
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = elementLabel;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @param {?} elementId
     * @param {?} selectedElement
     * @param {?} selectedText
     * @param {?} selectedValue
     * @return {?}
     */
    choiceSelected(elementId, selectedElement, selectedText, selectedValue) {
        const /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = selectedValue;
        choiceElement.selectedText = selectedText;
        this.showOrHideFreeText(elementId, choiceElement.selectedValue);
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedElement;
        this.selectedCondition.selectedValue = selectedText;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @param {?} element
     * @param {?} selectedCondition
     * @return {?}
     */
    dropdownChoiceSelected(element, selectedCondition) {
        const /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = element.id;
        choiceElement.selectedValue = (element.selectedOptions[0].label === 'Other, please specify…') ? 'freetext' : element.value;
        choiceElement.selectedText = element.selectedOptions[0].label;
        this.showOrHideFreeText(element.id, choiceElement.selectedValue);
        if (this.choiceValue === 'undefined' || this.choiceValue === undefined || this.choiceValue === '') {
            choiceElement.selectedText = '';
            choiceElement.selectedValue = '';
        }
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = element.id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.selectedOptions[0].label;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @return {?}
     */
    createChoiceElementForm() {
        this.choiceElementForm = this.formBuilder.group({
            checkBox: ['', Validators.required],
        }, {
            validator: this.specificValueInsideRange('checkBox')
        });
    }
    /**
     * @param {?} elementId
     * @param {?} selectedValue
     * @return {?}
     */
    showOrHideFreeText(elementId, selectedValue) {
        if (selectedValue === 'freetext') {
            $$3('#div_' + elementId + '_other').show();
        }
        else {
            $$3('#div_' + elementId + '_other').hide();
            $$3('#txt_other_' + elementId).val('');
        }
    }
    /**
     * @param {?} element
     * @param {?} elementId
     * @param {?} selectedCondition
     * @return {?}
     */
    updateFreeText(element, elementId, selectedCondition) {
        const /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = (element.value === 'Other') ? 'freetext' : element.value;
        choiceElement.selectedText = element.value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.value;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @param {?} checkBoxKey
     * @return {?}
     */
    specificValueInsideRange(checkBoxKey) {
        return (group) => {
            const /** @type {?} */ choiceControl = group.controls[checkBoxKey];
            if ((choiceControl.value === 'undefined' || choiceControl.value === '' || this.choiceValue === undefined || this.choiceValue === '')) {
                return choiceControl.setErrors({ notEquivalent: true });
            }
            else {
                return choiceControl.setErrors(null);
            }
        };
    }
}
AssistChoiceElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-choice-element',
                template: `<form [formGroup]="choiceElementForm" novalidate>
  <div class="form-group">
    <div class="col-sm-5 text-right">
      <label class="control-label">
        {{choiceDataElement.label}}
      </label>
      <ng-container *ngIf="choiceDataElement.hint !== '' && choiceDataElement.hint !== undefined">
        <i>
          <span class="fa fa-info-circle text-primary" data-toggle="tooltip" data-placement="right" title="{{choiceDataElement.hint}}"></span>
        </i>
      </ng-container>
      <ng-container *ngIf="choiceDataElement.diagrams != undefined ">
        <acr-hint-diagram [DataElement]="choiceDataElement" [imagePath]="imagePath"></acr-hint-diagram>
      </ng-container>
      <span *ngIf="choiceElementForm.controls['checkBox'].invalid  && this.choiceDataElement.isRequired" class="required-field"
        title="Required Field">*</span>
    </div>
    <div class="col-sm-7 text-left content-padding">
      <ng-container *ngIf="choiceDataElement.choiceInfo.length <= 2">
        <ng-container *ngIf="imagePath != undefined">
          <ng-container *ngIf="choiceDataElement.imageMap == undefined">
            <ng-container *ngFor="let choice of choiceDataElement.choiceInfo">
              <div class="radio" style="float:left; margin-right:15px;">
                <label>
                  <input [(ngModel)]="choiceValue" id="{{choice.value}}_{{choiceDataElement.id}}" type="radio" formControlName="checkBox" value="{{choice.value}}"
                    (change)="choiceSelected(choiceDataElement.id, choiceDataElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, choice.value)"> {{choice.label}}
                </label>
              </div>
            </ng-container>
            <ng-container *ngIf="choiceDataElement.allowFreetext">
              <div class="radio" style="float:left; margin-right:15px;">
                <label>
                  <input id="other_{{choiceDataElement.id}}" type="radio" formControlName="checkBox" value="freetext" (change)="choiceSelected(choiceDataElement.id, choiceDataElement.label, 'Other', 'freetext')"> Other, please specify…</label>
              </div>
              <div id='div_{{choiceDataElement.id}}_other'>
                <input id="txt_other_{{choiceDataElement.id}}" class="form-control" type="text" formControlName="checkBox" value="other"
                  class="form-control" (keyup)='updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)'
                  placeholder="Please specify '{{choiceDataElement.label}}'">
              </div>
            </ng-container>
          </ng-container>
          <ng-container *ngIf="choiceDataElement.imageMap != undefined">
            <div class="row">
              <div class="col-xs-6 col-sm-2">
                <ng-container *ngFor="let choice of choiceDataElement.choiceInfo">
                  <div class="radio" style="float:left; margin-right:15px;">
                    <label>
                      <input [(ngModel)]="choiceValue" id="{{choice.value}}_{{choiceDataElement.id}}" type="radio" formControlName="checkBox" value="{{choice.value}}"
                        (change)="choiceSelected(choiceDataElement.id, choiceDataElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, choice.value)"> {{choice.label}}
                    </label>
                  </div>
                </ng-container>
                <ng-container *ngIf="choiceDataElement.allowFreetext">
                  <div class="radio" style="float:left; margin-right:15px;">
                    <label>
                      <input id="other_{{choiceDataElement.id}}" type="radio" formControlName="checkBox" value="other" (change)="choiceSelected(choiceDataElement.id, choiceDataElement.label, 'Other', 'freetext')"> Other, please specify…</label>
                  </div>
                  <div id='div_{{choiceDataElement.id}}_other'>
                    <input id="txt_other_{{choiceDataElement.id}}" class="form-control" type="text" formControlName="checkBox" value="other"
                      class="form-control" (keyup)='updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)'
                      placeholder="Please specify '{{choiceDataElement.label}}'">
                  </div>
                </ng-container>
              </div>
              <div class="col-xs-6 col-sm-2">
                <label class="control-label">OR</label>
              </div>
              <acr-image-map [DataElement]="choiceDataElement" [imagePath]="imagePath"></acr-image-map>
            </div>
          </ng-container>
        </ng-container>
      </ng-container>
      <ng-container *ngIf="choiceDataElement.choiceInfo.length > 2">
        <select [(ngModel)]="choiceValue" id="{{choiceDataElement.id}}" (change)="dropdownChoiceSelected($event.target, choiceDataElement.label)"
          formControlName="checkBox" class="form-control">
          <option [value]="Select" [selected]="true">--Select--</option>
          <option *ngFor="let choice of choiceDataElement.choiceInfo" [value]="choice.value" [selected]="choice.value === choiceDataElement.currentValue">{{choice.label}}</option>
          <option *ngIf="choiceDataElement.allowFreetext" [value]="freetext" [selected]='freetext'>Other, please specify…</option>
        </select>
        <div id='div_{{choiceDataElement.id}}_other'>
          <input id="txt_other_{{choiceDataElement.id}}" class="form-control" type="text" formControlName="checkBox" value="other"
            placeholder="Please specify '{{choiceDataElement.label}}'" (keyup)='updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)'>
        </div>
        <ng-container *ngIf="choiceDataElement.imageMap != undefined  && imagePath != undefined">
          <div class="row padding-top-10">
            <div class="col-xs-6 col-sm-2">
              <label class="control-label">OR</label>
            </div>
            <acr-image-map [DataElement]="choiceDataElement" [imagePath]="imagePath"></acr-image-map>
          </div>
        </ng-container>
      </ng-container>
    </div>
  </div>
</form>

`,
                styles: [``, `.required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}`]
            },] },
];
/** @nocollapse */
AssistChoiceElementComponent.ctorParameters = () => [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
];
AssistChoiceElementComponent.propDecorators = {
    "choiceDataElement": [{ type: Input },],
    "imagePath": [{ type: Input },],
    "returnChoiceElement": [{ type: Output },],
    "choiceChange": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const $$4 = require('jquery');
class AssistMultiChoiceElementComponent {
    /**
     * @param {?} formBuilder
     * @param {?} simulatorEngineService
     */
    constructor(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnMultiChoice = new EventEmitter();
        this.multiElements = [];
        this.multiChoiceValues = [];
        this.multiChoiceComaprisonValues = [];
        this.choiceValue = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.createMultiChoiceElementForm();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        console.log(this.multiChoiceElement.currentValue);
        if (this.multiChoiceElement.currentValue !== undefined) {
            for (const /** @type {?} */ choice in this.multiChoiceElement.choiceInfo) {
                if (Array.isArray(this.multiChoiceElement.currentValue)) {
                    for (const /** @type {?} */ currValue of this.multiChoiceElement.currentValue) {
                        // this.choiceValue = this.multiChoiceElement.currentValue;
                        if (currValue === this.multiChoiceElement.choiceInfo[choice].value && this.multiChoiceElement.choiceInfo[choice].value !== undefined) {
                            console.log('Values Matched' + currValue);
                            this.choiceValue = this.multiChoiceElement.currentValue;
                            const /** @type {?} */ customEvent = document.createEvent('Event');
                            $$4('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue[choice]).prop('checked', true);
                            customEvent.initEvent('change', true, true);
                            this.selctValue = currValue;
                            this.selectedMultiChoice(this.multiChoiceElement.id, this.multiChoiceElement.label, currValue, this.multiChoiceElement.choiceInfo[choice].label);
                            break;
                        }
                    }
                }
                else {
                    if (this.multiChoiceElement.currentValue === this.multiChoiceElement.choiceInfo[choice].value && this.multiChoiceElement.choiceInfo[choice].value !== undefined) {
                        // this.checked = true;
                        this.choiceValue = this.multiChoiceElement.currentValue;
                        const /** @type {?} */ customEvent = document.createEvent('Event');
                        $$4('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue).prop('checked', true);
                        customEvent.initEvent('change', true, true);
                        this.selectedMultiChoice(this.multiChoiceElement.id, this.multiChoiceElement.label, this.multiChoiceElement.currentValue, this.multiChoiceElement.choiceInfo[choice].label);
                    }
                }
                if (this.selctValue === this.multiChoiceElement.choiceInfo[choice].value) {
                    this.checked = this.multiChoiceElement.choiceInfo[choice].value;
                }
                else {
                    this.checked = undefined;
                }
            }
        }
    }
    /**
     * @param {?} elementId
     * @param {?} selectedCondition
     * @param {?} choiceValue
     * @param {?} choiceLabel
     * @return {?}
     */
    selectedMultiChoice(elementId, selectedCondition, choiceValue, choiceLabel) {
        const /** @type {?} */ multiElement = new MultiChoiceElement();
        if ($$4('#' + elementId + '_' + choiceValue).is(':checked')) {
            this.multiChoiceValues.push(choiceLabel);
            this.multiChoiceComaprisonValues.push(choiceValue);
            this.checked = choiceValue;
            if (this.selctValue === choiceValue) {
                this.checked = choiceValue;
            }
            else {
                this.checked = undefined;
            }
        }
        else {
            const /** @type {?} */ index = this.multiChoiceValues.indexOf(choiceLabel);
            this.checked = undefined;
            const /** @type {?} */ comparisonIndex = this.multiChoiceComaprisonValues.indexOf(choiceValue);
            if (index > -1) {
                this.multiChoiceValues.splice(index, 1);
            }
            if (comparisonIndex > -1) {
                this.multiChoiceComaprisonValues.splice(comparisonIndex, 1);
            }
        }
        multiElement.elementId = elementId;
        multiElement.selectedValues = this.multiChoiceValues;
        multiElement.selectedComparisonValues = this.multiChoiceComaprisonValues;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = this.multiChoiceValues;
        this.returnMultiChoice.emit({ receivedElement: multiElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @param {?} elementId
     * @param {?} selectedCondition
     * @param {?} value
     * @param {?} event
     * @return {?}
     */
    updateMultiChoice(elementId, selectedCondition, value, event) {
        const /** @type {?} */ multiElement = new MultiChoiceElement();
        if (event.currentTarget.checked) {
            this.multiChoiceValues.push(value);
            this.multiChoiceComaprisonValues.push(event.currentTarget.value);
            this.checked = event.currentTarget.value;
            if (this.selctValue === event.currentTarget.value) {
                this.checked = event.currentTarget.value;
            }
            else {
                this.checked = undefined;
            }
        }
        else {
            const /** @type {?} */ index = this.multiChoiceValues.indexOf(value);
            this.checked = undefined;
            const /** @type {?} */ comparisonIndex = this.multiChoiceComaprisonValues.indexOf(event.currentTarget.value);
            if (index > -1) {
                this.multiChoiceValues.splice(index, 1);
            }
            if (comparisonIndex > -1) {
                this.multiChoiceComaprisonValues.splice(comparisonIndex, 1);
            }
        }
        multiElement.elementId = elementId;
        multiElement.selectedValues = this.multiChoiceValues;
        multiElement.selectedComparisonValues = this.multiChoiceComaprisonValues;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = this.multiChoiceValues;
        this.returnMultiChoice.emit({ receivedElement: multiElement, selectedCondition: this.selectedCondition });
        // this.returnMultiChoice.emit(multiElement);
    }
    /**
     * @return {?}
     */
    createMultiChoiceElementForm() {
        this.multiChoiceElementForm = this.formBuilder.group({
            multiCheckBox: ['', Validators.required],
        }, {
            validator: this.specificValueInsideRange('multiCheckBox')
        });
    }
    /**
     * @param {?} checkBoxKey
     * @return {?}
     */
    specificValueInsideRange(checkBoxKey) {
        return (group) => {
            const /** @type {?} */ choiceControl = group.controls[checkBoxKey];
            if (this.multiChoiceElement.isRequired) {
                return choiceControl.setErrors({ notEquivalent: true });
            }
            else {
                return choiceControl.setErrors(null);
            }
        };
    }
}
AssistMultiChoiceElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-multi-choice-element',
                template: `<form [formGroup]="multiChoiceElementForm" novalidate>
  <div class="form-group">
    <div class="col-sm-5 text-right">
      <label class="control-label">{{multiChoiceElement.label}}
      </label>
      <ng-container *ngIf="multiChoiceElement.hint !== '' && multiChoiceElement.hint !== undefined">
        <i class="fa fa-info-circle text-primary" title="{{multiChoiceElement.hint}}"></i>
      </ng-container>
      <ng-container *ngIf="multiChoiceElement.diagrams != undefined ">
        <acr-hint-diagram [DataElement]="multiChoiceElement" [imagePath]="imagePath"></acr-hint-diagram>
      </ng-container>
      <span *ngIf="multiChoiceElementForm.controls['multiCheckBox'].invalid && !multiChoiceValues.length" class="required-field"
        title="Required Field">
        *
      </span>
    </div>
    <div class="col-sm-7">
      <div *ngFor="let choice of multiChoiceElement.choiceInfo" class="checkbox" title="{{choice.hint}}">
        <label>
          <input type="checkbox" [(ngModel)]="checked" id="{{multiChoiceElement.id}}_{{choice.value}}" [checked]="false" formControlName="multiCheckBox" value="{{choice.value}}"
            (change)="updateMultiChoice(multiChoiceElement.id, multiChoiceElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, $event)"> {{choice.label}}
        </label>
      </div>
    </div>
  </div>
</form>
`,
                styles: [``, `.required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}`]
            },] },
];
/** @nocollapse */
AssistMultiChoiceElementComponent.ctorParameters = () => [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
];
AssistMultiChoiceElementComponent.propDecorators = {
    "multiChoiceElement": [{ type: Input },],
    "imagePath": [{ type: Input },],
    "returnMultiChoice": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ImageMapComponent {
    constructor() {
        this.$ = require('jquery');
        this.DataElements = {};
        this.FormValues = {};
        this.imageExist = true;
        this.SelectionValue = '';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.DataElement === undefined) {
            return;
        }
        this.displayValue('');
    }
    /**
     * @param {?} mouseX
     * @param {?} mouseY
     * @param {?} Coordinates
     * @return {?}
     */
    isInRectangle(mouseX, mouseY, Coordinates) {
        const /** @type {?} */ COArray = Coordinates.split(',');
        if (COArray[0] < mouseX
            && (COArray[0] + COArray[2]) > mouseX
            && COArray[1] < mouseY
            && (COArray[1] + COArray[3]) > mouseY) {
            return true;
        }
        return false;
    }
    /**
     * @param {?} mouseX
     * @param {?} mouseY
     * @param {?} Coordinates
     * @return {?}
     */
    isInCircle(mouseX, mouseY, Coordinates) {
        const /** @type {?} */ COArray = Coordinates.split(',');
        if (Math.sqrt(Math.pow((mouseX - COArray[0]), 2) + Math.pow((mouseY - COArray[1]), 2)) < COArray[2]) {
            return true;
        }
        else {
            return false;
        }
    }
    /**
     * @param {?} x
     * @param {?} y
     * @param {?} Coordinates
     * @return {?}
     */
    isInPolygon(x, y, Coordinates) {
        const /** @type {?} */ COArray = Coordinates.split(',');
        const /** @type {?} */ vs = [];
        for (let /** @type {?} */ i = 0; i < COArray.length; i++) {
            const /** @type {?} */ point = [];
            point.push(COArray[i]);
            point.push(COArray[i + 1]);
            i += 1;
            vs.push(point);
        }
        let /** @type {?} */ inside = false;
        for (let /** @type {?} */ i = 0, /** @type {?} */ j = vs.length - 1; i < vs.length; j = i++) {
            const /** @type {?} */ xi = vs[i][0], /** @type {?} */ yi = vs[i][1];
            const /** @type {?} */ xj = vs[j][0], /** @type {?} */ yj = vs[j][1];
            const /** @type {?} */ intersect = ((yi > y) !== (yj > y))
                && (x < (xj - xi) * (y - yi) / (yj - yi) + xi);
            if (intersect) {
                inside = !inside;
            }
        }
        return inside;
    }
    /**
     * @param {?} e
     * @param {?} dataElement
     * @return {?}
     */
    imageClick(e, dataElement) {
        const /** @type {?} */ O_height = dataElement.ImageProp.height;
        const /** @type {?} */ O_width = dataElement.ImageProp.width;
        const /** @type {?} */ $elem = this.$(e.target);
        const /** @type {?} */ N_height = $elem.height();
        const /** @type {?} */ N_width = $elem.width();
        const /** @type {?} */ offset = $elem.offset();
        const /** @type {?} */ offset_t = offset.top - this.$(window).scrollTop();
        const /** @type {?} */ offset_l = offset.left - this.$(window).scrollLeft();
        const /** @type {?} */ x = e.clientX - offset_l;
        const /** @type {?} */ y = e.clientY - offset_t;
        for (const /** @type {?} */ opt of dataElement.ImageOptions) {
            if (opt.Shape === 'rect') {
                if (this.isInRectangle(x, y, opt.Coordinates)) {
                    this.FormValues[dataElement.ID] = opt.Value;
                    break;
                }
            }
            else if (opt.Shape === 'circle') {
                if (this.isInCircle(x, y, opt.Coordinates)) {
                    this.FormValues[dataElement.ID] = opt.Value;
                    break;
                }
            }
            else if (opt.Shape === 'poly') {
                if (this.isInPolygon(x, y, opt.Coordinates)) {
                    this.FormValues[dataElement.ID] = opt.Value;
                    break;
                }
            }
        }
    }
    /**
     * @param {?} val
     * @return {?}
     */
    setValue(val) {
        for (const /** @type {?} */ optValue of this.DataElement.choiceInfo) {
            if (this.DataElement.choiceInfo.length <= 5 && this.DataElement.choiceInfo.length > 0) {
                if (optValue.value === val) {
                    this.$('#' + val + '_' + this.DataElement.id).prop('checked', true);
                    const /** @type {?} */ customEvent = document.createEvent('Event');
                    customEvent.initEvent('change', true, true);
                    this.$('#' + val + '_' + this.DataElement.id)[0].dispatchEvent(customEvent);
                }
                else {
                    this.$('#' + optValue.value + '_' + this.DataElement.id).prop('checked', false);
                }
            }
            else {
                if (optValue.value === val) {
                    this.$('#' + this.DataElement.id).val(optValue.value);
                    const /** @type {?} */ customEvent = document.createEvent('Event');
                    customEvent.initEvent('change', true, true);
                    this.$('#' + this.DataElement.id)[0].dispatchEvent(customEvent);
                    break;
                }
            }
        }
        this.DataElement.currentValue = val;
        // this.FormValues[this.DataElement.id] = val;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    displayValue(val) {
        if (val === '') {
            this.SelectionValue = 'Image Map Diagram';
        }
        else {
            this.SelectionValue = 'Selected Value : ' + val;
        }
    }
}
ImageMapComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-image-map',
                template: `<div class="col-sm-8">
    <label class="control-label" style="font-weight:400;">Not sure? try out this image </label>
  <button type="button" class="btn btn-default" data-toggle="modal" attr.data-target="#{{'imgMap_Modal_'+DataElement.id}}">
    <span class="glyphicon glyphicon-picture" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Image Map"></span>
  </button>
</div>
<ng-container *ngIf="imagePath != undefined">
  <div class="modal inmodal fade" id="{{'imgMap_Modal_'+DataElement.id}}" tabindex="-1" role="dialog" aria-hidden="true">
    <div class="modal-dialog modal-lg">
      <div class="modal-content">
        <div class="modal-header">
          <button type="button" class="close" data-dismiss="modal">
            <span aria-hidden="true">&times;</span>
            <span class="sr-only">Close</span>
          </button>
          <h4 class="modal-title"> {{SelectionValue}}</h4>
        </div>
        <div class="modal-body">
          <div class="row">
            <div class="col-md-12">
              <ng-container *ngIf="imageExist == true">
                <img class="ImgOption danger" alt="No Image Available!!!" data-dismiss="modal" attr.id="{{'imgMap_Img_'+DataElement.id}}"
                  (click)="imageClick($event,DataElement);" attr.data-elementID="{{DataElement.id}}" attr.usemap="#{{'imgMap_'+DataElement.id}}"
                  src="{{imagePath}}/{{DataElement.imageMap.location}}">
                <map name="{{'imgMap_'+DataElement.id}}">
                  <ng-container *ngFor="let imgOpt of DataElement.imageMap.map.areas">
                    <area attr.shape="{{imgOpt.shape}}" attr.imgID="{{'imgMap_Img_'+DataElement.id}}" attr.coords="{{imgOpt.coords}}" attr.alt="{{imgOpt.choiceValue}}"
                      (mouseover)='displayValue(imgOpt.choiceValue);' (mouseout)='displayValue("");' (click)="setValue(imgOpt.choiceValue);"
                      data-dismiss="modal">
                  </ng-container>
                </map>
              </ng-container>
              <ng-container *ngIf="imageExist == false">
                <div class="">
                  No Image Map Available...
                </div>
              </ng-container>
            </div>
          </div>
        </div>
        <div class="modal-footer">
          <button type="button" class="btn btn-primary" data-dismiss="modal">Close</button>
        </div>
      </div>
    </div>
  </div>
</ng-container>
`,
                styles: [``, `.required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}`]
            },] },
];
/** @nocollapse */
ImageMapComponent.propDecorators = {
    "DataElement": [{ type: Input },],
    "DataElements": [{ type: Input },],
    "FormValues": [{ type: Input },],
    "imagePath": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ComputedDataElement extends BaseDataElement {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ComputedDataElementCreationService extends DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     * @param {?} arrayCheckerService
     * @param {?} computedValueCreationService
     * @param {?} decisionPointsCreationService
     */
    constructor(diagramService, arrayCheckerService, computedValueCreationService, decisionPointsCreationService) {
        super(diagramService);
        this.arrayCheckerService = arrayCheckerService;
        this.computedValueCreationService = computedValueCreationService;
        this.decisionPointsCreationService = decisionPointsCreationService;
        this.elementType = 'ComputedDataElement';
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createElement(data) {
        const /** @type {?} */ dataElement = new ComputedDataElement();
        super.populateBasicData(data, dataElement);
        dataElement.computeValue = this.computedValueCreationService.createComputedValue(data);
        if (data.DecisionPoint) {
            dataElement.decisionPoints = this.decisionPointsCreationService.createDecisionPoints(data.DecisionPoint);
        }
        return dataElement;
    }
}
ComputedDataElementCreationService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ComputedDataElementCreationService.ctorParameters = () => [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
    { type: ComputedValueCreationService, },
    { type: DecisionPointsCreationService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const $$5 = require('jquery');
class AssistReportTextComponent {
    constructor() {
        this.allReportTexts = [];
        this.sections = [];
        setInterval(() => {
        }, 1000);
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.mainReportTexts = new MainReportText();
        this.onSelect(this.selectedSectionId);
    }
    /**
     * @param {?} sectionId
     * @return {?}
     */
    onSelect(sectionId) {
        this.selectedSectionId = sectionId;
        this.sections = [];
        this.selectedSection = null;
        for (const /** @type {?} */ section in this.reportText.allReportText) {
            if (this.reportText.allReportText[section].reportText !== '') {
                this.sections.push(section);
            }
        }
        if (sectionId === 'undefined' || sectionId === undefined || sectionId === 'All') {
            this.allTextReport = [];
            for (const /** @type {?} */ section in this.reportText.allReportText) {
                if (this.reportText.allReportText[section].reportText !== '') {
                    const /** @type {?} */ textReport = new AllTextReport();
                    textReport.heading = section;
                    textReport.content = this.removeEmptyLine(this.reportText.allReportText[section].reportText);
                    this.allTextReport.push(textReport);
                }
            }
            this.selectedSectionId = 'All';
        }
        for (const /** @type {?} */ section in this.reportText.allReportText) {
            if (this.reportText.allReportText[section].sectionId === sectionId) {
                this.selectedSection = this.reportText.allReportText[section].reportText;
                this.selectedSection = this.reportText.reportTextMainContent + ((this.selectedSection !== undefined && this.selectedSection !== '') ? this.removeEmptyLine(this.selectedSection) : '');
                break;
            }
        }
        this.mainReportTexts = new MainReportText();
        this.allReportTexts = [];
        for (const /** @type {?} */ section in this.reportText.allReportText) {
            const /** @type {?} */ allreportText = new AllReportText();
            allreportText.reportText = this.removeEmptyLine(this.reportText.allReportText[section].reportText);
            allreportText.sectionId = this.reportText.allReportText[section].sectionId;
            this.allReportTexts.push(allreportText);
        }
        this.mainReportTexts.allReportText = this.allReportTexts;
        this.mainReportTexts.reportTextMainContent = this.reportText.reportTextMainContent;
    }
    /**
     * @param {?} inputText
     * @return {?}
     */
    removeEmptyLine(inputText) {
        if (inputText.trim().length !== 0) {
            const /** @type {?} */ lines = inputText.split('\n');
            const /** @type {?} */ uniquelines = [];
            lines.forEach(function (line, i) {
                if (line.trim().length !== 0) {
                    uniquelines.push(line);
                }
            });
            return uniquelines.join('\n');
        }
    }
}
AssistReportTextComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-report-text',
                template: `<ng-container *ngFor="let textReport of allTextReport; let lastitem = last">
  <dt class="text-capitalize">{{textReport.heading}}</dt>
  <dd>
    <p class="white-space-line" [innerHTML]="textReport.content"></p>
  </dd>
  <hr *ngIf="!lastitem">
</ng-container>
`,
                styles: [``, `.required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}`]
            },] },
];
/** @nocollapse */
AssistReportTextComponent.ctorParameters = () => [];
AssistReportTextComponent.propDecorators = {
    "reportText": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const components = [AcrAssistSimulatorComponent, AssistDataElementComponent, HintDiagramComponent, SlideComponent, CarouselComponent,
    AssistNumericElementComponent, AssistChoiceElementComponent, AssistMultiChoiceElementComponent,
    ImageMapComponent, AssistReportTextComponent];
class AcrAssistSimulatorModule {
}
AcrAssistSimulatorModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    CoreModule,
                    FormsModule,
                    ReactiveFormsModule
                ],
                declarations: components,
                providers: [TemplateManagerService,
                    DiagramService,
                    CarouselConfig,
                    ArrayCheckerService,
                    ConditionsCreationService,
                    DecisionPointsCreationService,
                    ComputedValueCreationService,
                    SimulatorEngineService,
                    { provide: CreationServiceInjectorToken, useClass: ChoiceDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: MultipleChoiceDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: NumericDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: IntegerDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: GlobalValueCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: ComputedDataElementCreationService, multi: true }
                ],
                exports: components
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @record
 * @template T
 */

/**
 * @template T
 */
class Dictionary {
    constructor() {
        this.items = {};
        this.count = 0;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    ContainsKey(key) {
        return this.items.hasOwnProperty(key);
    }
    /**
     * @return {?}
     */
    Count() {
        return this.count;
    }
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    Add(key, value) {
        if (!this.items.hasOwnProperty(key)) {
            this.count++;
        }
        this.items[key] = value;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    Remove(key) {
        const /** @type {?} */ val = this.items[key];
        delete this.items[key];
        this.count--;
        return val;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    Item(key) {
        return this.items[key];
    }
    /**
     * @return {?}
     */
    Keys() {
        const /** @type {?} */ keySet = [];
        for (const /** @type {?} */ prop in this.items) {
            if (this.items.hasOwnProperty(prop)) {
                keySet.push(prop);
            }
        }
        return keySet;
    }
    /**
     * @return {?}
     */
    Values() {
        const /** @type {?} */ values = [];
        for (const /** @type {?} */ prop in this.items) {
            if (this.items.hasOwnProperty(prop)) {
                values.push(this.items[prop]);
            }
        }
        return values;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class GlobalsService {
    /**
     * @param {?} http
     */
    constructor(http) {
        this.http = http;
        this.defaultModule = 'assets/XMLFIles/hello_assist/Hello_Assist.xml';
        this.XMLList = new Dictionary();
    }
    /**
     * @return {?}
     */
    getDefaultModulePath() {
        return this.http.get(this.defaultModule).map(res => res.text());
    }
}
GlobalsService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
GlobalsService.ctorParameters = () => [
    { type: Http, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const $$6 = require('jquery');
class ViewUploadLoaderComponent {
    /**
     * @param {?} globalsService
     */
    constructor(globalsService) {
        this.onFileSelected = new EventEmitter();
        this.globalsService = globalsService;
    }
    /**
     * @param {?} fileDetails
     * @return {?}
     */
    onFileContentRead(fileDetails) {
        this.selectedXML = fileDetails;
        if (this.globalsService.XMLList.ContainsKey(fileDetails.fileLabel)) {
            this.globalsService.XMLList.Remove(fileDetails.fileLabel);
        }
        this.globalsService.XMLList.Add(fileDetails.fileLabel, fileDetails);
        this.onFileSelected.emit(fileDetails);
    }
    /**
     * @param {?} fileDetails
     * @return {?}
     */
    onFileClick(fileDetails) {
        this.selectedXML = fileDetails;
        this.onFileSelected.emit(fileDetails);
        $$6('#xmlOnlyMsg').hide();
    }
}
ViewUploadLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-view-upload-loader',
                template: `<ul class="sidebar-menu" data-widget="tree">
  <li class="header">Want to try your assist module?</li>
  <li class="text-center">
    <acr-file-upload-loader (onFileContentRead)="onFileContentRead($event)"></acr-file-upload-loader>
  </li>
  <li [ngClass]="{'active':(selectedXML != 'undefined' && selectedXML.fileLabel == file.fileLabel)}" *ngFor="let file of globalsService.XMLList.Values().reverse()"
     class="treeview">
    <a href="#" (click)="onFileClick(file)">
      <i class="fa fa-book"></i>
      <span>{{file.fileLabel}}</span>
    </a>
  </li>
</ul>
`,
                styles: [``]
            },] },
];
/** @nocollapse */
ViewUploadLoaderComponent.ctorParameters = () => [
    { type: GlobalsService, },
];
ViewUploadLoaderComponent.propDecorators = {
    "onFileSelected": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FileDetails {
    /**
     * @param {?} fileLabel
     * @param {?} fileName
     * @param {?} fileContents
     */
    constructor(fileLabel, fileName, fileContents) {
        this.fileLabel = fileLabel;
        this.fileName = fileName;
        this.fileContents = fileContents;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const $$7 = require('jquery');
class FileUploadLoaderComponent {
    /**
     * @param {?} configService
     */
    constructor(configService) {
        this.configService = configService;
        this.onFileContentRead = new EventEmitter();
        this.fileReader = new FileReader();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.hideMessage();
        this.showDefaultModule();
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    changeListener($event) {
        let /** @type {?} */ fileName;
        fileName = $event.target.value;
        if (fileName.includes('.xml') || fileName.includes('.Xml') || fileName.includes('.XML') ||
            fileName.includes('.zip') || fileName.includes('.Zip') || fileName.includes('.ZIP')) {
            this.hideMessage();
            this.readThis($event.target);
        }
        else {
            if (fileName !== '' && fileName !== undefined) {
                $$7('#xmlOnlyMsg').show();
            }
        }
    }
    /**
     * @return {?}
     */
    hideMessage() {
        $$7('#xmlOnlyMsg').hide();
    }
    /**
     * @param {?} inputValue
     * @return {?}
     */
    readThis(inputValue) {
        this.readFile = inputValue.files[0];
        const /** @type {?} */ self = this;
        const /** @type {?} */ extensionStartPosition = self.readFile.name.lastIndexOf('.');
        this.fileReader.onloadend = (e) => {
            self.onFileContentRead.emit(new FileDetails(self.readFile.name.substring(0, extensionStartPosition), self.readFile.name, this.fileReader.result));
        };
        this.fileReader.readAsText(this.readFile);
    }
    /**
     * @return {?}
     */
    showDefaultModule() {
        this.configService.getDefaultModulePath()
            .subscribe(data => {
            const /** @type {?} */ self = this;
            self.onFileContentRead.emit(new FileDetails('Hello Assist', 'Hello_Assist.xml', data));
        });
    }
}
FileUploadLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-file-upload-loader',
                template: `<input id="xmlFileUpload" class="hidden" type="file" accept=".xml" (change)="changeListener($event)" (click)="hideMessage()">
<label for="xmlFileUpload" class="btn bg-olive margin" style="margin:10px;" title="Choose a Module">Choose a Module</label>
<br>
<div id="xmlOnlyMsg" class="xml-only-msg"> Only XML files are supported !!!</div>
`,
                styles: [``]
            },] },
];
/** @nocollapse */
FileUploadLoaderComponent.ctorParameters = () => [
    { type: GlobalsService, },
];
FileUploadLoaderComponent.propDecorators = {
    "onFileContentRead": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const components$1 = [FileUploadLoaderComponent, ViewUploadLoaderComponent];
class SimulatorLoaderModule {
}
SimulatorLoaderModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [components$1],
                providers: [GlobalsService],
                exports: [components$1]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { AcrAssistSimulatorModule, SimulatorLoaderModule, AcrAssistSimulatorComponent as ɵc, AssistChoiceElementComponent as ɵo, AssistDataElementComponent as ɵl, AssistMultiChoiceElementComponent as ɵp, AssistNumericElementComponent as ɵn, HintDiagramComponent as ɵm, ImageMapComponent as ɵq, AssistReportTextComponent as ɵr, CreationServiceInjectorToken as ɵe, ArrayCheckerService as ɵg, ChoiceDataElementCreationService as ɵs, ComputedDataElementCreationService as ɵx, ComputedValueCreationService as ɵk, ConditionsCreationService as ɵj, DataElementCreationBaseService as ɵh, DecisionPointsCreationService as ɵi, DiagramService as ɵf, GlobalValueCreationService as ɵw, IntegerDataElementCreationService as ɵv, MultipleChoiceDataElementCreationService as ɵt, NumericDataElementCreationService as ɵu, TemplateManagerService as ɵd, CoreModule as ɵa, SimulatorEngineService as ɵb, FileUploadLoaderComponent as ɵy, GlobalsService as ɵz, ViewUploadLoaderComponent as ɵba };
//# sourceMappingURL=acr-assist-simulator-module.js.map
