import { __values, __extends, __spread } from 'tslib';
import { Injectable, NgModule, InjectionToken, Inject, Component, Input, Output, EventEmitter, ViewChild } from '@angular/core';
import { BehaviorSubject } from 'rxjs/BehaviorSubject';
import { CommonModule } from '@angular/common';
import { FormBuilder, Validators, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { SlideComponent } from 'ngx-bootstrap/carousel/slide.component';
import { CarouselComponent } from 'ngx-bootstrap/carousel/carousel.component';
import { CarouselConfig } from 'ngx-bootstrap/carousel/carousel.config';
import { Http } from '@angular/http';
import 'rxjs/add/operator/map';

var SimulatorState = /** @class */ (function () {
    function SimulatorState() {
        this.nonRelevantDataElementIds = [];
        this.endPointId = '';
        this.selectedDecisionPointId = '';
        this.selectedDecisionPointLabel = '';
        this.selectedBranchLabel = '';
    }
    return SimulatorState;
}());
var DataElementValues = /** @class */ (function () {
    function DataElementValues(values) {
        this.values = values;
    }
    DataElementValues.prototype.addOrUpdate = function (key, value) {
        this.values[key] = value;
    };
    DataElementValues.prototype.get = function (key) {
        return this.values[key];
    };
    DataElementValues.prototype.delete = function (key) {
        return this.values.delete(key);
    };
    DataElementValues.prototype.getAll = function () {
        return this.values;
    };
    return DataElementValues;
}());
var SimulatorEngineService = /** @class */ (function () {
    function SimulatorEngineService() {
        this.endOfRoadReached = false;
        this.lastConditionMetBranchLevel = 1;
        this.simulatorStateChanged = new BehaviorSubject(new SimulatorState());
        this.dataElementValues = new Map();
        this.dataElementTexts = new Map();
    }
    SimulatorEngineService.prototype.getAllDataElementValues = function () {
        return this.dataElementValues;
    };
    SimulatorEngineService.prototype.getAllDataElementTexts = function () {
        return this.dataElementTexts;
    };
    SimulatorEngineService.prototype.getDataElementValue = function (dataElementId) {
        return this.dataElementValues[dataElementId];
    };
    SimulatorEngineService.prototype.getDataElementText = function (dataElementId) {
        return this.dataElementTexts[dataElementId];
    };
    SimulatorEngineService.prototype.addOrUpdateDataElement = function (dataElementId, value, text) {
        this.dataElementValues[dataElementId] = value;
        this.dataElementTexts[dataElementId] = text;
        this.evaluateDecisionPoints();
    };
    SimulatorEngineService.prototype.evaluateDecisionPoint = function (decisionPoint, branchingLevel, nonRelevantDataElementIds) {
        if (nonRelevantDataElementIds === void 0) { nonRelevantDataElementIds = []; }
        var currentBranchCount = 0;
        var totalBranchesInDecisionPoint = decisionPoint.branches.length;
        try {
            for (var _a = __values(decisionPoint.branches), _b = _a.next(); !_b.done; _b = _a.next()) {
                var branch = _b.value;
                currentBranchCount++;
                var conditionMet = false;
                if (this.endOfRoadReached) {
                    break;
                }
                if (branch.compositeCondition !== undefined) {
                    conditionMet = branch.compositeCondition.evaluate(new DataElementValues(this.dataElementValues));
                }
                else if (branch.condition !== undefined) {
                    conditionMet = branch.condition.evaluate(new DataElementValues(this.dataElementValues));
                }
                if (conditionMet) {
                    this.lastConditionMetBranchLevel = branchingLevel;
                    if (nonRelevantDataElementIds === undefined) {
                        nonRelevantDataElementIds = new Array();
                    }
                    if (branch.notRelevantDataElements !== undefined) {
                        try {
                            for (var _c = __values(branch.notRelevantDataElements.dataElementReferences), _d = _c.next(); !_d.done; _d = _c.next()) {
                                var nonRelevantDataElementReference = _d.value;
                                nonRelevantDataElementIds.push(nonRelevantDataElementReference.dataElementId);
                            }
                        }
                        catch (e_1_1) { e_1 = { error: e_1_1 }; }
                        finally {
                            try {
                                if (_d && !_d.done && (_e = _c.return)) _e.call(_c);
                            }
                            finally { if (e_1) throw e_1.error; }
                        }
                    }
                    if (branch.decisionPoints !== undefined) {
                        try {
                            for (var _f = __values(branch.decisionPoints), _g = _f.next(); !_g.done; _g = _f.next()) {
                                var branchDecisionPoint = _g.value;
                                var newBranchingLevel = branchingLevel + 1;
                                this.evaluateDecisionPoint(branchDecisionPoint, newBranchingLevel, nonRelevantDataElementIds);
                            }
                        }
                        catch (e_2_1) { e_2 = { error: e_2_1 }; }
                        finally {
                            try {
                                if (_g && !_g.done && (_h = _f.return)) _h.call(_f);
                            }
                            finally { if (e_2) throw e_2.error; }
                        }
                    }
                    else if (branch.endPointRef !== undefined) {
                        var simulatorState = new SimulatorState();
                        simulatorState.endPointId = branch.endPointRef.endPointId;
                        simulatorState.nonRelevantDataElementIds = nonRelevantDataElementIds;
                        simulatorState.selectedBranchLabel = branch.label;
                        simulatorState.selectedDecisionPointId = decisionPoint.id;
                        simulatorState.selectedDecisionPointLabel = decisionPoint.label;
                        this.resetValuesOfNonRelevantDataElements(nonRelevantDataElementIds);
                        this.simulatorStateChanged.next(simulatorState);
                        this.endOfRoadReached = true;
                        break;
                    }
                }
                else {
                    if (currentBranchCount >= totalBranchesInDecisionPoint) {
                        this.endOfRoadReached = true;
                        var simulatorState = new SimulatorState();
                        simulatorState.nonRelevantDataElementIds = nonRelevantDataElementIds;
                        this.resetValuesOfNonRelevantDataElements(nonRelevantDataElementIds);
                        this.simulatorStateChanged.next(simulatorState);
                        return;
                    }
                    else {
                        continue;
                    }
                }
            }
        }
        catch (e_3_1) { e_3 = { error: e_3_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_j = _a.return)) _j.call(_a);
            }
            finally { if (e_3) throw e_3.error; }
        }
        var e_3, _j, e_1, _e, e_2, _h;
    };
    SimulatorEngineService.prototype.resetValuesOfNonRelevantDataElements = function (nonRelevantDataElementIds) {
        try {
            for (var nonRelevantDataElementIds_1 = __values(nonRelevantDataElementIds), nonRelevantDataElementIds_1_1 = nonRelevantDataElementIds_1.next(); !nonRelevantDataElementIds_1_1.done; nonRelevantDataElementIds_1_1 = nonRelevantDataElementIds_1.next()) {
                var nonRelevantDataElementId = nonRelevantDataElementIds_1_1.value;
                var defaultValue = void 0;
                try {
                    for (var _a = __values(this.template.dataElements), _b = _a.next(); !_b.done; _b = _a.next()) {
                        var dataElement = _b.value;
                        if (dataElement.id === nonRelevantDataElementId) {
                            defaultValue = dataElement.defaultValue;
                            break;
                        }
                    }
                }
                catch (e_4_1) { e_4 = { error: e_4_1 }; }
                finally {
                    try {
                        if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                    }
                    finally { if (e_4) throw e_4.error; }
                }
                this.dataElementValues[nonRelevantDataElementId] = defaultValue;
            }
        }
        catch (e_5_1) { e_5 = { error: e_5_1 }; }
        finally {
            try {
                if (nonRelevantDataElementIds_1_1 && !nonRelevantDataElementIds_1_1.done && (_d = nonRelevantDataElementIds_1.return)) _d.call(nonRelevantDataElementIds_1);
            }
            finally { if (e_5) throw e_5.error; }
        }
        var e_5, _d, e_4, _c;
    };
    SimulatorEngineService.prototype.evaluateComputedElementDecisionPoint = function (elementId, decisionPoint, branchingLevel) {
        var currentBranchCount = 0;
        var totalBranchesInDecisionPoint = decisionPoint.branches.length;
        try {
            for (var _a = __values(decisionPoint.branches), _b = _a.next(); !_b.done; _b = _a.next()) {
                var branch = _b.value;
                currentBranchCount++;
                var conditionMet = false;
                if (this.endOfRoadReached) {
                    break;
                }
                if (branch.compositeCondition !== undefined) {
                    conditionMet = branch.compositeCondition.evaluate(new DataElementValues(this.dataElementValues));
                }
                else if (branch.condition !== undefined) {
                    conditionMet = branch.condition.evaluate(new DataElementValues(this.dataElementValues));
                }
                if (conditionMet) {
                    this.lastConditionMetBranchLevel = branchingLevel;
                    if (branch.decisionPoints !== undefined) {
                        try {
                            for (var _c = __values(branch.decisionPoints), _d = _c.next(); !_d.done; _d = _c.next()) {
                                var branchDecisionPoint = _d.value;
                                var newBranchingLevel = branchingLevel + 1;
                                this.evaluateComputedElementDecisionPoint(elementId, branchDecisionPoint, newBranchingLevel);
                            }
                        }
                        catch (e_6_1) { e_6 = { error: e_6_1 }; }
                        finally {
                            try {
                                if (_d && !_d.done && (_e = _c.return)) _e.call(_c);
                            }
                            finally { if (e_6) throw e_6.error; }
                        }
                    }
                    else if (branch.computedValue !== undefined) {
                        this.dataElementValues[elementId] = branch.computedValue.expressionText;
                        this.endOfRoadReached = true;
                        break;
                    }
                }
                else {
                    if (currentBranchCount >= totalBranchesInDecisionPoint) {
                        this.endOfRoadReached = true;
                        this.dataElementValues[elementId] = undefined;
                        return;
                    }
                    else {
                        continue;
                    }
                }
            }
        }
        catch (e_7_1) { e_7 = { error: e_7_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_f = _a.return)) _f.call(_a);
            }
            finally { if (e_7) throw e_7.error; }
        }
        var e_7, _f, e_6, _e;
    };
    SimulatorEngineService.prototype.evaluateComputedExpressions = function () {
        this.endOfRoadReached = false;
        try {
            for (var _a = __values(this.template.dataElements), _b = _a.next(); !_b.done; _b = _a.next()) {
                var element = _b.value;
                if (element.dataElementType === 'ComputedDataElement') {
                    var computedElement = (element);
                    try {
                        for (var _c = __values(computedElement.decisionPoints), _d = _c.next(); !_d.done; _d = _c.next()) {
                            var decisionPoint = _d.value;
                            this.evaluateComputedElementDecisionPoint(element.id, decisionPoint, 1);
                            if (this.dataElementValues[element.id] === undefined && decisionPoint.defaultBranch &&
                                decisionPoint.defaultBranch.computedValue) {
                                this.dataElementValues[element.id] = decisionPoint.defaultBranch.computedValue.expressionText;
                            }
                            this.endOfRoadReached = false;
                        }
                    }
                    catch (e_8_1) { e_8 = { error: e_8_1 }; }
                    finally {
                        try {
                            if (_d && !_d.done && (_e = _c.return)) _e.call(_c);
                        }
                        finally { if (e_8) throw e_8.error; }
                    }
                }
            }
        }
        catch (e_9_1) { e_9 = { error: e_9_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_f = _a.return)) _f.call(_a);
            }
            finally { if (e_9) throw e_9.error; }
        }
        var e_9, _f, e_8, _e;
    };
    SimulatorEngineService.prototype.evaluateDecisionPoints = function () {
        this.evaluateComputedExpressions();
        this.endOfRoadReached = false;
        try {
            for (var _a = __values(this.template.rules.decisionPoints), _b = _a.next(); !_b.done; _b = _a.next()) {
                var decisionPoint = _b.value;
                if (this.evaluateDecisionPoint(decisionPoint, 1, new Array())) {
                    break;
                }
            }
        }
        catch (e_10_1) { e_10 = { error: e_10_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_10) throw e_10.error; }
        }
        var e_10, _c;
    };
    SimulatorEngineService.prototype.initialize = function (template) {
        this.template = template;
        try {
            for (var _a = __values(this.template.dataElements), _b = _a.next(); !_b.done; _b = _a.next()) {
                var dataElement = _b.value;
                this.dataElementValues[dataElement.id] = dataElement.currentValue;
            }
        }
        catch (e_11_1) { e_11 = { error: e_11_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_11) throw e_11.error; }
        }
        var e_11, _c;
    };
    return SimulatorEngineService;
}());
SimulatorEngineService.decorators = [
    { type: Injectable },
];
SimulatorEngineService.ctorParameters = function () { return []; };
var CoreModule = /** @class */ (function () {
    function CoreModule() {
    }
    CoreModule.forRoot = function () {
        return {
            ngModule: CoreModule,
            providers: [SimulatorEngineService]
        };
    };
    return CoreModule;
}());
CoreModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: []
            },] },
];
var Template = /** @class */ (function () {
    function Template() {
    }
    return Template;
}());
var Metadata = /** @class */ (function () {
    function Metadata() {
    }
    return Metadata;
}());
var Diagram = /** @class */ (function () {
    function Diagram() {
    }
    return Diagram;
}());
var ArrayCheckerService = /** @class */ (function () {
    function ArrayCheckerService() {
    }
    ArrayCheckerService.prototype.isArray = function (item) {
        return item instanceof Array;
    };
    return ArrayCheckerService;
}());
ArrayCheckerService.decorators = [
    { type: Injectable },
];
ArrayCheckerService.ctorParameters = function () { return []; };
var DiagramService = /** @class */ (function () {
    function DiagramService(arrayCheckerSeviceService) {
        this.arrayCheckerSeviceService = arrayCheckerSeviceService;
    }
    DiagramService.prototype.returnDiagram = function (diagramJSON) {
        var diagram = new Diagram();
        if (diagramJSON.Attr) {
            diagram.displaySequence = diagramJSON.Attr.DisplaySequence;
            diagram.keyDiagram = diagramJSON.Attr.IsKeyDiagram ? diagramJSON.Attr.IsKeyDiagram : false;
        }
        else {
            diagram.displaySequence = undefined;
            diagram.keyDiagram = false;
        }
        diagram.label = diagramJSON.Label;
        diagram.location = diagramJSON.Location;
        return diagram;
    };
    DiagramService.prototype.returnDiagrams = function (diagramsAsJSON) {
        var diagrams = new Array();
        if (diagramsAsJSON !== undefined) {
            if (this.arrayCheckerSeviceService.isArray(diagramsAsJSON)) {
                try {
                    for (var diagramsAsJSON_1 = __values(diagramsAsJSON), diagramsAsJSON_1_1 = diagramsAsJSON_1.next(); !diagramsAsJSON_1_1.done; diagramsAsJSON_1_1 = diagramsAsJSON_1.next()) {
                        var diagram = diagramsAsJSON_1_1.value;
                        diagrams.push(this.returnDiagram(diagram));
                    }
                }
                catch (e_12_1) { e_12 = { error: e_12_1 }; }
                finally {
                    try {
                        if (diagramsAsJSON_1_1 && !diagramsAsJSON_1_1.done && (_a = diagramsAsJSON_1.return)) _a.call(diagramsAsJSON_1);
                    }
                    finally { if (e_12) throw e_12.error; }
                }
            }
            else {
                diagrams.push(this.returnDiagram(diagramsAsJSON));
            }
        }
        return diagrams;
        var e_12, _a;
    };
    return DiagramService;
}());
DiagramService.decorators = [
    { type: Injectable },
];
DiagramService.ctorParameters = function () { return [
    { type: ArrayCheckerService, },
]; };
var CreationServiceInjectorToken = new InjectionToken('one');
var DecisionPoint = /** @class */ (function () {
    function DecisionPoint() {
    }
    return DecisionPoint;
}());
var Branch = /** @class */ (function () {
    function Branch() {
    }
    return Branch;
}());
var EndPointRef = /** @class */ (function () {
    function EndPointRef() {
    }
    return EndPointRef;
}());
var DataElementRef = /** @class */ (function () {
    function DataElementRef() {
    }
    return DataElementRef;
}());
var NotRelevantDataElements = /** @class */ (function () {
    function NotRelevantDataElements() {
    }
    return NotRelevantDataElements;
}());
var EqualCondition = /** @class */ (function () {
    function EqualCondition(conditionType) {
        this.conditionType = conditionType;
    }
    EqualCondition.prototype.evaluate = function (dataElementValues) {
        var value = dataElementValues.get(this.conditionType.dataElementId);
        return value === this.conditionType.comparisonValue;
    };
    return EqualCondition;
}());
var ConditionType = /** @class */ (function () {
    function ConditionType() {
    }
    return ConditionType;
}());
var GreaterThanCondition = /** @class */ (function () {
    function GreaterThanCondition(conditionType) {
        this.conditionType = conditionType;
    }
    GreaterThanCondition.prototype.evaluate = function (dataElementValues) {
        var value = (+dataElementValues.get(this.conditionType.dataElementId));
        var comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value > comparisonValue;
    };
    return GreaterThanCondition;
}());
var LessThanCondition = /** @class */ (function () {
    function LessThanCondition(conditionType) {
        this.conditionType = conditionType;
    }
    LessThanCondition.prototype.evaluate = function (dataElementValues) {
        var value = (+dataElementValues.get(this.conditionType.dataElementId));
        var comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value < comparisonValue;
    };
    return LessThanCondition;
}());
var GreaterThanOrEqualsCondition = /** @class */ (function () {
    function GreaterThanOrEqualsCondition(conditionType) {
        this.conditionType = conditionType;
    }
    GreaterThanOrEqualsCondition.prototype.evaluate = function (dataElementValues) {
        var value = (+dataElementValues.get(this.conditionType.dataElementId));
        var comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value >= comparisonValue;
    };
    return GreaterThanOrEqualsCondition;
}());
var LessThanOrEqualsCondition = /** @class */ (function () {
    function LessThanOrEqualsCondition(conditionType) {
        this.conditionType = conditionType;
    }
    LessThanOrEqualsCondition.prototype.evaluate = function (dataElementValues) {
        var value = (+dataElementValues.get(this.conditionType.dataElementId));
        var comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value <= comparisonValue;
    };
    return LessThanOrEqualsCondition;
}());
var ContainsCondition = /** @class */ (function () {
    function ContainsCondition(conditionType) {
        this.conditionType = conditionType;
    }
    ContainsCondition.prototype.evaluate = function (dataElementValues) {
        var returnValue = false;
        var value = dataElementValues.get(this.conditionType.dataElementId);
        if (value !== undefined) {
            returnValue = value.indexOf(this.conditionType.comparisonValue) >= 0;
        }
        return returnValue;
    };
    return ContainsCondition;
}());
var AndCondition = /** @class */ (function () {
    function AndCondition() {
        this.conditions = [];
        this.conditionType = 'AndCondition';
    }
    AndCondition.prototype.evaluate = function (dataElementValues) {
        var returnValue = true;
        for (var conditionCounter = 0; conditionCounter < this.conditions.length; conditionCounter++) {
            var condition = this.conditions[conditionCounter];
            var executedCondition = condition.evaluate(dataElementValues);
            returnValue = (!executedCondition) ? false : (returnValue && executedCondition);
            if (!returnValue) {
                break;
            }
        }
        return returnValue;
    };
    return AndCondition;
}());
var OrCondition = /** @class */ (function () {
    function OrCondition() {
        this.conditions = [];
        this.conditionType = 'OrCondition';
    }
    OrCondition.prototype.evaluate = function (dataElementValues) {
        var returnValue = false;
        for (var conditionCounter = 0; conditionCounter < this.conditions.length; conditionCounter++) {
            var condition = this.conditions[conditionCounter];
            var executedCondition = condition.evaluate(dataElementValues);
            returnValue = (returnValue || executedCondition);
            if (returnValue) {
                break;
            }
        }
        return returnValue;
    };
    return OrCondition;
}());
var NotCondition = /** @class */ (function () {
    function NotCondition() {
        this.conditions = [];
        this.conditionType = 'NotCondition';
    }
    NotCondition.prototype.evaluate = function (dataElementValues) {
        var results = new Array();
        try {
            for (var _a = __values(this.conditions), _b = _a.next(); !_b.done; _b = _a.next()) {
                var condition = _b.value;
                results.push(condition.evaluate(dataElementValues));
            }
        }
        catch (e_13_1) { e_13 = { error: e_13_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_13) throw e_13.error; }
        }
        return !(results[0]);
        var e_13, _c;
    };
    return NotCondition;
}());
var ConditionsCreationService = /** @class */ (function () {
    function ConditionsCreationService(arrayCheckerService) {
        this.arrayCheckerService = arrayCheckerService;
    }
    ConditionsCreationService.prototype.returnConditionType = function (conditionJSON) {
        var conditionType = new ConditionType();
        conditionType.comparisonValue = conditionJSON.Attr.ComparisonValue;
        conditionType.dataElementId = conditionJSON.Attr.DataElementId;
        return conditionType;
    };
    ConditionsCreationService.prototype.returnCondition = function (branchJSON) {
        var condition;
        if (branchJSON.hasOwnProperty('EqualCondition')) {
            condition = new EqualCondition(this.returnConditionType(branchJSON.EqualCondition));
        }
        if (branchJSON.hasOwnProperty('GreaterThanCondition')) {
            condition = new GreaterThanCondition(this.returnConditionType(branchJSON.GreaterThanCondition));
        }
        if (branchJSON.hasOwnProperty('LessThanCondition')) {
            condition = new LessThanCondition(this.returnConditionType(branchJSON.LessThanCondition));
        }
        if (branchJSON.hasOwnProperty('GreaterThanOrEqualsCondition')) {
            condition = new GreaterThanOrEqualsCondition(this.returnConditionType(branchJSON.GreaterThanOrEqualsCondition));
        }
        if (branchJSON.hasOwnProperty('LessThanOrEqualsCondition')) {
            condition = new LessThanOrEqualsCondition(this.returnConditionType(branchJSON.LessThanOrEqualsCondition));
        }
        if (branchJSON.hasOwnProperty('ContainsCondition')) {
            condition = new ContainsCondition(this.returnConditionType(branchJSON.ContainsCondition));
        }
        return condition;
    };
    ConditionsCreationService.prototype.isComposite = function (compositeElementJSON) {
        return compositeElementJSON.hasOwnProperty('AndCondition') ||
            compositeElementJSON.hasOwnProperty('OrCondition') ||
            compositeElementJSON.hasOwnProperty('NotCondition');
    };
    ConditionsCreationService.prototype.returnConditionFromJSON = function (conditionIdentifier, conditionJSON) {
        var condition;
        if (conditionIdentifier === 'EqualCondition') {
            condition = new EqualCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'GreaterThanCondition') {
            condition = new GreaterThanCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'LessThanCondition') {
            condition = new LessThanCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'GreaterThanOrEqualsCondition') {
            condition = new GreaterThanOrEqualsCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'LessThanOrEqualsCondition') {
            condition = new LessThanOrEqualsCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'ContainsCondition') {
            condition = new ContainsCondition(this.returnConditionType(conditionJSON));
        }
        return condition;
    };
    ConditionsCreationService.prototype.returnConditions = function (conditionsJSON) {
        var conditions;
        var conditionIdentifiers = ['EqualCondition', 'GreaterThanCondition', 'LessThanCondition',
            'GreaterThanOrEqualsCondition', 'LessThanOrEqualsCondition', 'ContainsCondition'];
        try {
            for (var conditionIdentifiers_1 = __values(conditionIdentifiers), conditionIdentifiers_1_1 = conditionIdentifiers_1.next(); !conditionIdentifiers_1_1.done; conditionIdentifiers_1_1 = conditionIdentifiers_1.next()) {
                var conditionIdentifier = conditionIdentifiers_1_1.value;
                var conditionJSON = conditionsJSON[conditionIdentifier];
                if (conditionJSON !== undefined) {
                    conditions = new Array();
                    if (this.arrayCheckerService.isArray(conditionJSON)) {
                        try {
                            for (var conditionJSON_1 = __values(conditionJSON), conditionJSON_1_1 = conditionJSON_1.next(); !conditionJSON_1_1.done; conditionJSON_1_1 = conditionJSON_1.next()) {
                                var jsonValue = conditionJSON_1_1.value;
                                conditions.push(this.returnConditionFromJSON(conditionIdentifier, jsonValue));
                            }
                        }
                        catch (e_14_1) { e_14 = { error: e_14_1 }; }
                        finally {
                            try {
                                if (conditionJSON_1_1 && !conditionJSON_1_1.done && (_a = conditionJSON_1.return)) _a.call(conditionJSON_1);
                            }
                            finally { if (e_14) throw e_14.error; }
                        }
                    }
                    else {
                        conditions.push(this.returnConditionFromJSON(conditionIdentifier, conditionJSON));
                    }
                }
            }
        }
        catch (e_15_1) { e_15 = { error: e_15_1 }; }
        finally {
            try {
                if (conditionIdentifiers_1_1 && !conditionIdentifiers_1_1.done && (_b = conditionIdentifiers_1.return)) _b.call(conditionIdentifiers_1);
            }
            finally { if (e_15) throw e_15.error; }
        }
        return conditions;
        var e_15, _b, e_14, _a;
    };
    ConditionsCreationService.prototype.isHybrid = function (compositeElementJSON) {
        var compositeExists = compositeElementJSON.hasOwnProperty('AndCondition') ||
            compositeElementJSON.hasOwnProperty('OrCondition') ||
            compositeElementJSON.hasOwnProperty('NotCondition');
        var primitiveExists = compositeElementJSON.hasOwnProperty('EqualCondition') ||
            compositeElementJSON.hasOwnProperty('GreaterThanCondition') ||
            compositeElementJSON.hasOwnProperty('LessThanCondition') ||
            compositeElementJSON.hasOwnProperty('GreaterThanOrEqualsCondition') ||
            compositeElementJSON.hasOwnProperty('LessThanOrEqualsCondition') ||
            compositeElementJSON.hasOwnProperty('ContainsCondition');
        return compositeExists && primitiveExists;
    };
    ConditionsCreationService.prototype.returnCompositeCondition = function (data) {
        if (!this.isComposite(data)) {
            return;
        }
        var compositeConditionJSON;
        var compositeCondition;
        if (data.hasOwnProperty('AndCondition')) {
            compositeConditionJSON = data.AndCondition;
            compositeCondition = new AndCondition();
        }
        else if (data.hasOwnProperty('OrCondition')) {
            compositeConditionJSON = data.OrCondition;
            compositeCondition = new OrCondition();
        }
        else if (data.hasOwnProperty('NotCondition')) {
            compositeConditionJSON = data.NotCondition;
            compositeCondition = new NotCondition();
        }
        if (!this.isComposite(compositeConditionJSON)) {
            compositeCondition.conditions = this.returnConditions(compositeConditionJSON);
        }
        else if (this.isHybrid(compositeConditionJSON)) {
            var jsonKeys = Object.keys(compositeConditionJSON);
            try {
                for (var jsonKeys_1 = __values(jsonKeys), jsonKeys_1_1 = jsonKeys_1.next(); !jsonKeys_1_1.done; jsonKeys_1_1 = jsonKeys_1.next()) {
                    var jsonKey = jsonKeys_1_1.value;
                    var jsonValue = compositeConditionJSON[jsonKey];
                    var jsonString = '{"' + jsonKey + '":' + JSON.stringify(jsonValue) + '}';
                    var jsonObject = JSON.parse(jsonString);
                    if (this.isComposite(jsonObject)) {
                        this.returnInnerConditions(jsonObject, compositeCondition);
                    }
                    else {
                        if (this.arrayCheckerService.isArray(jsonValue)) {
                            try {
                                for (var jsonValue_1 = __values(jsonValue), jsonValue_1_1 = jsonValue_1.next(); !jsonValue_1_1.done; jsonValue_1_1 = jsonValue_1.next()) {
                                    var arrayValue = jsonValue_1_1.value;
                                    compositeCondition.conditions.push(this.returnConditionFromJSON(jsonKey, arrayValue));
                                }
                            }
                            catch (e_16_1) { e_16 = { error: e_16_1 }; }
                            finally {
                                try {
                                    if (jsonValue_1_1 && !jsonValue_1_1.done && (_a = jsonValue_1.return)) _a.call(jsonValue_1);
                                }
                                finally { if (e_16) throw e_16.error; }
                            }
                        }
                        else {
                            compositeCondition.conditions.push(this.returnConditionFromJSON(jsonKey, jsonValue));
                        }
                    }
                }
            }
            catch (e_17_1) { e_17 = { error: e_17_1 }; }
            finally {
                try {
                    if (jsonKeys_1_1 && !jsonKeys_1_1.done && (_b = jsonKeys_1.return)) _b.call(jsonKeys_1);
                }
                finally { if (e_17) throw e_17.error; }
            }
        }
        else {
            this.returnInnerConditions(compositeConditionJSON, compositeCondition);
        }
        return compositeCondition;
        var e_17, _b, e_16, _a;
    };
    ConditionsCreationService.prototype.returnCompositeConditionFromName = function (elementName) {
        var compositeCondition;
        switch (elementName) {
            case 'AndCondition':
                {
                    compositeCondition = new AndCondition();
                    break;
                }
            case 'OrCondition':
                {
                    compositeCondition = new OrCondition();
                    break;
                }
            case 'NotCondition':
                {
                    compositeCondition = new NotCondition();
                }
        }
        return compositeCondition;
    };
    ConditionsCreationService.prototype.addConditionsToInnerConditions = function (key, value, compositeCondition) {
        var condition = this.returnCompositeConditionFromName(key);
        compositeCondition.conditions.push(condition);
        if (this.isHybrid(value)) {
            var jsonKeys = Object.keys(value);
            try {
                for (var jsonKeys_2 = __values(jsonKeys), jsonKeys_2_1 = jsonKeys_2.next(); !jsonKeys_2_1.done; jsonKeys_2_1 = jsonKeys_2.next()) {
                    var jsonKey = jsonKeys_2_1.value;
                    var jsonValue = value[jsonKey];
                    var jsonString = '{"' + jsonKey + '":' + JSON.stringify(jsonValue) + '}';
                    var jsonObject = JSON.parse(jsonString);
                    if (this.isComposite(jsonObject)) {
                        this.returnInnerConditions(jsonObject, condition);
                    }
                    else {
                        if (this.arrayCheckerService.isArray(jsonValue)) {
                            try {
                                for (var jsonValue_2 = __values(jsonValue), jsonValue_2_1 = jsonValue_2.next(); !jsonValue_2_1.done; jsonValue_2_1 = jsonValue_2.next()) {
                                    var arrayValue = jsonValue_2_1.value;
                                    condition.conditions.push(this.returnConditionFromJSON(jsonKey, arrayValue));
                                }
                            }
                            catch (e_18_1) { e_18 = { error: e_18_1 }; }
                            finally {
                                try {
                                    if (jsonValue_2_1 && !jsonValue_2_1.done && (_a = jsonValue_2.return)) _a.call(jsonValue_2);
                                }
                                finally { if (e_18) throw e_18.error; }
                            }
                        }
                        else {
                            condition.conditions.push(this.returnConditionFromJSON(jsonKey, jsonValue));
                        }
                    }
                }
            }
            catch (e_19_1) { e_19 = { error: e_19_1 }; }
            finally {
                try {
                    if (jsonKeys_2_1 && !jsonKeys_2_1.done && (_b = jsonKeys_2.return)) _b.call(jsonKeys_2);
                }
                finally { if (e_19) throw e_19.error; }
            }
        }
        else if (this.isComposite(value)) {
        }
        else {
            condition.conditions = this.returnConditions(value);
        }
        var e_19, _b, e_18, _a;
    };
    ConditionsCreationService.prototype.returnInnerConditions = function (innerConditionsJSON, compositeCondition) {
        var jsonKeys = Object.keys(innerConditionsJSON);
        try {
            for (var jsonKeys_3 = __values(jsonKeys), jsonKeys_3_1 = jsonKeys_3.next(); !jsonKeys_3_1.done; jsonKeys_3_1 = jsonKeys_3.next()) {
                var key = jsonKeys_3_1.value;
                var values = innerConditionsJSON[key];
                if (this.arrayCheckerService.isArray(values)) {
                    try {
                        for (var values_1 = __values(values), values_1_1 = values_1.next(); !values_1_1.done; values_1_1 = values_1.next()) {
                            var value = values_1_1.value;
                            this.addConditionsToInnerConditions(key, value, compositeCondition);
                        }
                    }
                    catch (e_20_1) { e_20 = { error: e_20_1 }; }
                    finally {
                        try {
                            if (values_1_1 && !values_1_1.done && (_a = values_1.return)) _a.call(values_1);
                        }
                        finally { if (e_20) throw e_20.error; }
                    }
                }
                else {
                    this.addConditionsToInnerConditions(key, innerConditionsJSON[key], compositeCondition);
                }
            }
        }
        catch (e_21_1) { e_21 = { error: e_21_1 }; }
        finally {
            try {
                if (jsonKeys_3_1 && !jsonKeys_3_1.done && (_b = jsonKeys_3.return)) _b.call(jsonKeys_3);
            }
            finally { if (e_21) throw e_21.error; }
        }
        var e_21, _b, e_20, _a;
    };
    return ConditionsCreationService;
}());
ConditionsCreationService.decorators = [
    { type: Injectable },
];
ConditionsCreationService.ctorParameters = function () { return [
    { type: ArrayCheckerService, },
]; };
var TextExpression = /** @class */ (function () {
    function TextExpression() {
    }
    return TextExpression;
}());
var ArithmeticExpression = /** @class */ (function () {
    function ArithmeticExpression() {
    }
    return ArithmeticExpression;
}());
var ComputedValueCreationService = /** @class */ (function () {
    function ComputedValueCreationService() {
    }
    ComputedValueCreationService.prototype.createComputedValue = function (dataAsJSON) {
        if (dataAsJSON['TextExpression'] !== undefined) {
            var computedValue = new TextExpression();
            computedValue.expressionText = dataAsJSON.TextExpression;
            return computedValue;
        }
        if (dataAsJSON['ArithmeticExpression'] !== undefined) {
            {
                var computedValue = new ArithmeticExpression();
                computedValue.expressionText = dataAsJSON.ArithmeticExpression;
                return computedValue;
            }
        }
    };
    return ComputedValueCreationService;
}());
ComputedValueCreationService.decorators = [
    { type: Injectable },
];
ComputedValueCreationService.ctorParameters = function () { return []; };
var DecisionPointsCreationService = /** @class */ (function () {
    function DecisionPointsCreationService(arrayCheckerService, conditionsCreationService, computedValueCreationService) {
        this.arrayCheckerService = arrayCheckerService;
        this.conditionsCreationService = conditionsCreationService;
        this.computedValueCreationService = computedValueCreationService;
    }
    DecisionPointsCreationService.prototype.createRelevantDataElementReferences = function (dataElementRefJSON) {
        var dataElementRef = new DataElementRef();
        dataElementRef.dataElementId = dataElementRefJSON.Attr.DataElementId;
        return dataElementRef;
    };
    DecisionPointsCreationService.prototype.returnBranch = function (branchJSON) {
        var branch = new Branch();
        branch.label = branchJSON.Label;
        if (branchJSON.EndPointRef) {
            branch.endPointRef = new EndPointRef();
            branch.endPointRef.endPointId = branchJSON.EndPointRef.Attr.EndPointId;
        }
        branch.condition = this.conditionsCreationService.returnCondition(branchJSON);
        branch.computedValue = this.computedValueCreationService.createComputedValue(branchJSON);
        if (this.conditionsCreationService.isComposite(branchJSON)) {
            branch.compositeCondition = this.conditionsCreationService.returnCompositeCondition(branchJSON);
        }
        if (branchJSON.NotRelevantDataElements) {
            var notRelevantDataElements = new NotRelevantDataElements();
            notRelevantDataElements.dataElementReferences = new Array();
            var dataElementRefs = branchJSON.NotRelevantDataElements.DataElementRef;
            if (this.arrayCheckerService.isArray(dataElementRefs)) {
                try {
                    for (var dataElementRefs_1 = __values(dataElementRefs), dataElementRefs_1_1 = dataElementRefs_1.next(); !dataElementRefs_1_1.done; dataElementRefs_1_1 = dataElementRefs_1.next()) {
                        var dataElementRefJSON = dataElementRefs_1_1.value;
                        notRelevantDataElements.dataElementReferences.push(this.createRelevantDataElementReferences(dataElementRefJSON));
                    }
                }
                catch (e_22_1) { e_22 = { error: e_22_1 }; }
                finally {
                    try {
                        if (dataElementRefs_1_1 && !dataElementRefs_1_1.done && (_a = dataElementRefs_1.return)) _a.call(dataElementRefs_1);
                    }
                    finally { if (e_22) throw e_22.error; }
                }
            }
            else {
                notRelevantDataElements.dataElementReferences.push(this.createRelevantDataElementReferences(dataElementRefs));
            }
            branch.notRelevantDataElements = notRelevantDataElements;
        }
        if (branchJSON.DecisionPoint) {
            branch.decisionPoints = new Array();
            this.addDecisionPoints(branchJSON.DecisionPoint, branch.decisionPoints);
        }
        return branch;
        var e_22, _a;
    };
    DecisionPointsCreationService.prototype.addDecisionPoint = function (decsionPointAsJSON, decisionPoints) {
        var decisionPoint = new DecisionPoint();
        if (decsionPointAsJSON.Attr && decsionPointAsJSON.Attr.Id) {
            decisionPoint.id = decsionPointAsJSON.Attr.Id;
        }
        decisionPoint.label = decsionPointAsJSON.Label;
        var branchesJSON = decsionPointAsJSON.Branch;
        if (branchesJSON !== undefined) {
            decisionPoint.branches = new Array();
            if (this.arrayCheckerService.isArray(branchesJSON)) {
                try {
                    for (var branchesJSON_1 = __values(branchesJSON), branchesJSON_1_1 = branchesJSON_1.next(); !branchesJSON_1_1.done; branchesJSON_1_1 = branchesJSON_1.next()) {
                        var branchJSON = branchesJSON_1_1.value;
                        decisionPoint.branches.push(this.returnBranch(branchJSON));
                    }
                }
                catch (e_23_1) { e_23 = { error: e_23_1 }; }
                finally {
                    try {
                        if (branchesJSON_1_1 && !branchesJSON_1_1.done && (_a = branchesJSON_1.return)) _a.call(branchesJSON_1);
                    }
                    finally { if (e_23) throw e_23.error; }
                }
            }
            else {
                decisionPoint.branches.push(this.returnBranch(branchesJSON));
            }
            var defaultBranchJSON = decsionPointAsJSON.DefaultBranch;
            if (defaultBranchJSON !== undefined) {
                decisionPoint.defaultBranch = this.createDefaultBranch(defaultBranchJSON);
            }
        }
        decisionPoints.push(decisionPoint);
        var e_23, _a;
    };
    DecisionPointsCreationService.prototype.addDecisionPoints = function (decsionPointsAsJSON, decisionPoints) {
        if (this.arrayCheckerService.isArray(decsionPointsAsJSON)) {
            try {
                for (var decsionPointsAsJSON_1 = __values(decsionPointsAsJSON), decsionPointsAsJSON_1_1 = decsionPointsAsJSON_1.next(); !decsionPointsAsJSON_1_1.done; decsionPointsAsJSON_1_1 = decsionPointsAsJSON_1.next()) {
                    var decisionPoint = decsionPointsAsJSON_1_1.value;
                    this.addDecisionPoint(decisionPoint, decisionPoints);
                }
            }
            catch (e_24_1) { e_24 = { error: e_24_1 }; }
            finally {
                try {
                    if (decsionPointsAsJSON_1_1 && !decsionPointsAsJSON_1_1.done && (_a = decsionPointsAsJSON_1.return)) _a.call(decsionPointsAsJSON_1);
                }
                finally { if (e_24) throw e_24.error; }
            }
        }
        else {
            this.addDecisionPoint(decsionPointsAsJSON, decisionPoints);
        }
        var e_24, _a;
    };
    DecisionPointsCreationService.prototype.createDecisionPoints = function (data) {
        var decisionPoints = new Array();
        this.addDecisionPoints(data, decisionPoints);
        return decisionPoints;
    };
    DecisionPointsCreationService.prototype.createDefaultBranch = function (data) {
        var defaultBranch = new Branch();
        defaultBranch.label = 'Default Branch';
        defaultBranch.computedValue = this.computedValueCreationService.createComputedValue(data);
        return defaultBranch;
    };
    return DecisionPointsCreationService;
}());
DecisionPointsCreationService.decorators = [
    { type: Injectable },
];
DecisionPointsCreationService.ctorParameters = function () { return [
    { type: ArrayCheckerService, },
    { type: ConditionsCreationService, },
    { type: ComputedValueCreationService, },
]; };
var Rules = /** @class */ (function () {
    function Rules() {
    }
    return Rules;
}());
var TemplatePartial = /** @class */ (function () {
    function TemplatePartial() {
    }
    return TemplatePartial;
}());
var TemplateManagerService = /** @class */ (function () {
    function TemplateManagerService(diagramService, elememtcreationService, arrayCheckerService, decisionPointsCreationService) {
        this.diagramService = diagramService;
        this.elememtcreationService = elememtcreationService;
        this.arrayCheckerService = arrayCheckerService;
        this.decisionPointsCreationService = decisionPointsCreationService;
        this.endPointXMLString = [];
        this.stringParser = require('string');
    }
    TemplateManagerService.prototype.getTemplate = function (templateContent) {
        var template = new Template();
        var templateContentAsJSON;
        templateContentAsJSON = this.parseToJson(templateContent);
        if (template === undefined) {
            throw new Error('Unable to parse the template');
        }
        template.metadata = this.getMetaData(templateContentAsJSON.Metadata);
        template.dataElements = this.getDataElements(templateContentAsJSON.DataElements);
        if (templateContentAsJSON.Rules) {
            template.rules = new Rules();
            template.rules.decisionPoints = this.decisionPointsCreationService.
                createDecisionPoints(templateContentAsJSON.Rules.DecisionPoint);
        }
        template.templatePartial = this.returnEndpoints(templateContent);
        template.endPointsString = this.endPointXMLString;
        template.xmlContent = templateContent;
        return template;
    };
    TemplateManagerService.prototype.getTemplatePartial = function (templatePartialJSON) {
        var templatePartial = new TemplatePartial;
        templatePartial.id = templatePartialJSON.Attr.Id;
        templatePartial.sectionIfNotValue = templatePartialJSON.SectionIfValueNot;
        templatePartial.sectionIfValues = templatePartialJSON.SectionIfValue;
        return templatePartial;
    };
    TemplateManagerService.prototype.returnEndPointContents = function (content, startToken, endToken) {
        var contents = new Array();
        var templateSearchIndexPosition = 0;
        while (true) {
            var contentStartPosition = content.indexOf(startToken, templateSearchIndexPosition);
            var contentEndPosition = content.indexOf(endToken, templateSearchIndexPosition);
            if (contentStartPosition >= 0 && contentEndPosition >= 0) {
                var endPosition = contentEndPosition + endToken.length;
                var contentData = content.substring(contentStartPosition, endPosition);
                contents.push(contentData);
                templateSearchIndexPosition = endPosition + 1;
            }
            else {
                break;
            }
        }
        return contents;
    };
    TemplateManagerService.prototype.returnTemplatePartials = function (templatePartialArray) {
        var templatePartials = new Array();
        try {
            for (var templatePartialArray_1 = __values(templatePartialArray), templatePartialArray_1_1 = templatePartialArray_1.next(); !templatePartialArray_1_1.done; templatePartialArray_1_1 = templatePartialArray_1.next()) {
                var arrayItem = templatePartialArray_1_1.value;
                var templatePartial = new TemplatePartial();
                var templatePartialAsJSON = this.parseToJson(arrayItem);
                templatePartial.id = templatePartialAsJSON.Attr.Id;
            }
        }
        catch (e_25_1) { e_25 = { error: e_25_1 }; }
        finally {
            try {
                if (templatePartialArray_1_1 && !templatePartialArray_1_1.done && (_a = templatePartialArray_1.return)) _a.call(templatePartialArray_1);
            }
            finally { if (e_25) throw e_25.error; }
        }
        return templatePartials;
        var e_25, _a;
    };
    TemplateManagerService.prototype.returnEndpoints = function (xmlData) {
        var endPointStartToken = '<EndPoints>';
        var endPointEndToken = '</EndPoints>';
        var endPointStartTokenPosition = xmlData.indexOf(endPointStartToken);
        var endPointEndTokenPosition = xmlData.indexOf(endPointEndToken);
        if (endPointStartTokenPosition >= 0 && endPointEndTokenPosition >= 0) {
            var contentStartPosition = (endPointStartTokenPosition + endPointStartToken.length);
            var endPointContent = xmlData.substring(contentStartPosition, endPointEndTokenPosition);
            if (endPointContent.length > 0) {
                var templatePartials = this.returnEndPointContents(endPointContent, '<TemplatePartial', '</TemplatePartial>');
                this.endPointXMLString = this.returnEndPointContents(endPointContent, '<EndPoint', '</EndPoint>');
                return templatePartials;
            }
        }
    };
    TemplateManagerService.prototype.parseToJson = function (xmlData) {
        var jsonResult;
        var parseString = require('xml2js').parseString;
        parseString(xmlData, { explicitRoot: false, explicitArray: false, attrkey: 'Attr' }, function (err, result) {
            jsonResult = result;
        });
        return jsonResult;
    };
    TemplateManagerService.prototype.getMetaData = function (metadataJSON) {
        var metadata = new Metadata();
        metadata.label = metadataJSON.Label;
        metadata.id = metadataJSON.ID;
        metadata.schemaVersion = metadataJSON.SchemaVersion;
        metadata.ruleVersion = metadataJSON.RuleVersion;
        var diagramsAsJSON = metadataJSON.Info.Diagrams.Diagram;
        metadata.diagrams = this.diagramService.returnDiagrams(diagramsAsJSON);
        return metadata;
    };
    TemplateManagerService.prototype.returnDataElement = function (elementType, dataElementsJSON) {
        var dataElements = new Array();
        var dataElementCreationServiceInstance;
        try {
            for (var _a = __values(this.elememtcreationService), _b = _a.next(); !_b.done; _b = _a.next()) {
                var dataElementCreationService = _b.value;
                if (dataElementCreationService.elementType === elementType) {
                    dataElementCreationServiceInstance = dataElementCreationService;
                    break;
                }
            }
        }
        catch (e_26_1) { e_26 = { error: e_26_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_26) throw e_26.error; }
        }
        if (dataElementCreationServiceInstance !== undefined && dataElementsJSON !== undefined) {
            if (this.arrayCheckerService.isArray(dataElementsJSON)) {
                try {
                    for (var dataElementsJSON_1 = __values(dataElementsJSON), dataElementsJSON_1_1 = dataElementsJSON_1.next(); !dataElementsJSON_1_1.done; dataElementsJSON_1_1 = dataElementsJSON_1.next()) {
                        var dataElementJSON = dataElementsJSON_1_1.value;
                        var dataElement = dataElementCreationServiceInstance.createElement(dataElementJSON);
                        dataElements.push(dataElement);
                    }
                }
                catch (e_27_1) { e_27 = { error: e_27_1 }; }
                finally {
                    try {
                        if (dataElementsJSON_1_1 && !dataElementsJSON_1_1.done && (_d = dataElementsJSON_1.return)) _d.call(dataElementsJSON_1);
                    }
                    finally { if (e_27) throw e_27.error; }
                }
            }
            else {
                var dataElement = dataElementCreationServiceInstance.createElement(dataElementsJSON);
                dataElements.push(dataElement);
            }
        }
        return dataElements;
        var e_26, _c, e_27, _d;
    };
    TemplateManagerService.prototype.getDataElements = function (dataElementsJSON) {
        var dataElements = new Array();
        dataElements = dataElements.concat(this.returnDataElement('ChoiceDataElement', dataElementsJSON.ChoiceDataElement));
        dataElements = dataElements.concat(this.returnDataElement('MultiChoiceDataElement', dataElementsJSON.MultiChoiceDataElement));
        dataElements = dataElements.concat(this.returnDataElement('NumericDataElement', dataElementsJSON.NumericDataElement));
        dataElements = dataElements.concat(this.returnDataElement('GlobalValue', dataElementsJSON.GlobalValue));
        dataElements = dataElements.concat(this.returnDataElement('ComputedDataElement', dataElementsJSON.ComputedDataElement));
        dataElements = dataElements.concat(this.returnDataElement('IntegerDataElement', dataElementsJSON.IntegerDataElement));
        return dataElements;
    };
    return TemplateManagerService;
}());
TemplateManagerService.decorators = [
    { type: Injectable },
];
TemplateManagerService.ctorParameters = function () { return [
    { type: DiagramService, },
    { type: Array, decorators: [{ type: Inject, args: [CreationServiceInjectorToken,] },] },
    { type: ArrayCheckerService, },
    { type: DecisionPointsCreationService, },
]; };
var AllTextReport = /** @class */ (function () {
    function AllTextReport() {
    }
    return AllTextReport;
}());
var ReportTextPosition = {
    Top: 0,
    Right: 1,
};
ReportTextPosition[ReportTextPosition.Top] = "Top";
ReportTextPosition[ReportTextPosition.Right] = "Right";
var $ = require('jquery');
var AcrAssistSimulatorComponent = /** @class */ (function () {
    function AcrAssistSimulatorComponent(templateManagerService, simulatorEngineService) {
        this.templateManagerService = templateManagerService;
        this.simulatorEngineService = simulatorEngineService;
        this.inputValues = [];
        this.returnExecutionHistory = new EventEmitter();
        this.returnDefaultElements = new EventEmitter();
        this.position = ReportTextPosition;
    }
    AcrAssistSimulatorComponent.prototype.ngAfterContentInit = function () {
        this.reloadUI();
    };
    AcrAssistSimulatorComponent.prototype.ngOnChanges = function (changes) {
        this.isReset = true;
        this.isEmptyContent = this.templateContent === undefined || this.templateContent.length === 0 && this.inputValues.length === 0 &&
            this.inputData === undefined;
        if (this.isEmptyContent) {
            return;
        }
        if (this.inputData !== undefined) {
            if (this.inputData.length > 0) {
                this.inputValues = JSON.parse(this.inputData);
            }
        }
        if (this.imageUpload !== undefined) {
            this.imageUpload.nativeElement.value = '';
        }
        this.template = this.templateManagerService.getTemplate(this.templateContent);
        this.simulatorEngineService.initialize(this.template);
        if (this.inputValues.length !== 0) {
            var _loop_1 = function (dataeElement) {
                var inputValue = this_1.inputValues.filter(function (x) { return x.dataElementId === dataeElement.id; });
                if (inputValue !== undefined && inputValue.length > 0) {
                    dataeElement.currentValue = inputValue[0].dataElementValue;
                }
            };
            var this_1 = this;
            try {
                for (var _a = __values(this.template.dataElements), _b = _a.next(); !_b.done; _b = _a.next()) {
                    var dataeElement = _b.value;
                    _loop_1(dataeElement);
                }
            }
            catch (e_28_1) { e_28 = { error: e_28_1 }; }
            finally {
                try {
                    if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                }
                finally { if (e_28) throw e_28.error; }
            }
        }
        this.dataElements = this.template.dataElements;
        this.keyDiagrams = new Array();
        for (var index = 0; index < this.template.metadata.diagrams.length; index++) {
            var element = new Diagram();
            element.label = this.template.metadata.diagrams[index].label;
            element.location = this.imagePath + '/' + this.template.metadata.diagrams[index].location;
            element.keyDiagram = this.template.metadata.diagrams[index].keyDiagram;
            this.keyDiagrams.push(element);
        }
        this.resultText = undefined;
        var e_28, _c;
    };
    AcrAssistSimulatorComponent.prototype.resetElements = function () {
        this.template = this.templateManagerService.getTemplate(this.templateContent);
        this.simulatorEngineService.initialize(this.template);
        this.dataElements = this.template.dataElements;
        this.resultText = undefined;
        this.returnDefaultElements.emit();
    };
    AcrAssistSimulatorComponent.prototype.recieveReportText = function (textReport) {
        this.resultText = textReport;
    };
    AcrAssistSimulatorComponent.prototype.recievedExecutionHistory = function (finalExecutionHistory) {
        this.returnExecutionHistory.emit(finalExecutionHistory);
    };
    AcrAssistSimulatorComponent.prototype.changeListener = function (event) {
        var _this = this;
        this.keyDiagrams = new Array();
        var _loop_2 = function (image) {
            if (event.target.files.hasOwnProperty(image)) {
                var reader_1 = new FileReader();
                var diagram_1 = new Diagram();
                diagram_1.label = event.target.files[image].name;
                diagram_1.keyDiagram = image === '0' ? true : false;
                var imageType = event.target.files[image].imageType;
                var fileStream = event.target.files[image];
                reader_1.onload = function (event1) {
                    diagram_1.location = reader_1.result;
                };
                reader_1.readAsDataURL(event.target.files[image]);
                reader_1.onloadend = function (event1) {
                    _this.keyDiagrams.push(diagram_1);
                    _this.reloadUI();
                };
            }
        };
        for (var image in event.target.files) {
            _loop_2(image);
        }
    };
    AcrAssistSimulatorComponent.prototype.collapseKeyDiagram = function () {
        if ($('#icon_keydiagram').hasClass('fa fa-minus')) {
            $('#icon_keydiagram').removeClass('fa fa-minus');
            $('#icon_keydiagram').addClass('fa fa-plus');
            $('#body_keydiagram').css({
                'display': 'none'
            });
        }
        else {
            $('#icon_keydiagram').removeClass('fa fa-plus');
            $('#icon_keydiagram').addClass('fa fa-minus');
            $('#body_keydiagram').removeAttr('style');
        }
    };
    AcrAssistSimulatorComponent.prototype.collapseReportText = function () {
        if ($('#icon_reporttext').hasClass('fa fa-minus')) {
            $('#icon_reporttext').removeClass('fa fa-minus');
            $('#icon_reporttext').addClass('fa fa-plus');
            $('#body_reporttext').css({
                'display': 'none'
            });
        }
        else {
            $('#icon_reporttext').removeClass('fa fa-plus');
            $('#icon_reporttext').addClass('fa fa-minus');
            $('#body_reporttext').removeAttr('style');
        }
    };
    AcrAssistSimulatorComponent.prototype.reloadUI = function () {
        setTimeout(function (_) {
            init_keyImagesUI();
        });
    };
    return AcrAssistSimulatorComponent;
}());
AcrAssistSimulatorComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-simulator',
                template: "<ng-container *ngIf=\"!isEmptyContent\">\n\n\n  <div *ngIf=\"reportTextPosition === position.Top\">\n    <div class=\"col-sm-12 col-md-12 col-lg-12\">\n      <div id=\"div-simulator-block\">\n        <div class=\"box box-primary box-solid margin-b-0\">\n          <div class=\"box-body\">\n            <ng-container *ngIf=\"resultText !== undefined\">\n              <div id=\"div-simulator-results-block\">\n                <div class=\"box box-primary\">\n                  <div class=\"box-header with-border\">\n                    <h3 class=\"box-title\">Report Text</h3>\n                    <div class=\"box-tools pull-right\">\n                      <button type=\"button\" class=\"btn btn-box-tool btn-report-text\" (click)=\"collapseReportText()\">\n                        <i id=\"icon_reporttext\" class=\"fa fa-minus\"></i>\n                      </button>\n                    </div>\n                  </div>\n                  <div id=\"body_reporttext\" class=\"box-body report-text\">\n                    <dl>\n                      <acr-assist-report-text [reportText]=\"resultText\"></acr-assist-report-text>\n                    </dl>\n                  </div>\n                </div>\n              </div>\n            </ng-container>\n            <div id=\"div-simulator-form\" class=\"padding-r-10 div-simulator-form-height\">\n              <div>\n                <form class=\"form-horizontal\">\n                  <acr-assist-data-element [dataElements]=\"dataElements\" [templatePartial]=\"template.templatePartial\" [endPointXMLString]=\"template.endPointsString\"\n                    [imagePath]=\"imagePath\" [xmlContent]=\"template.xmlContent\" (returnReportText)='recieveReportText($event)'\n                    [inputValues]=\"inputValues\" [isReset]=\"isReset\" (returnExecutionHistory)='recievedExecutionHistory($event)'></acr-assist-data-element>\n                </form>\n              </div>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n  <div *ngIf=\"reportTextPosition === position.Right\">\n    <div class=\"col-sm-6 col-md-6 col-lg-6\">\n      <div id=\"div-simulator-block\">\n        <div class=\"box box-primary box-solid margin-b-0\">\n          <div class=\"box-body\">\n            <div id=\"div-simulator-form\" class=\"padding-r-10 div-simulator-form-height\">\n              <form class=\"form-horizontal\">\n                <acr-assist-data-element [dataElements]=\"dataElements\" [templatePartial]=\"template.templatePartial\" [endPointXMLString]=\"template.endPointsString\"\n                  [imagePath]=\"imagePath\" [xmlContent]=\"template.xmlContent\" (returnReportText)='recieveReportText($event)'\n                  [inputValues]=\"inputValues\" [isReset]=\"isReset\" (returnExecutionHistory)='recievedExecutionHistory($event)'></acr-assist-data-element>\n              </form>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n    <div class=\"col-sm-6 col-md-6 col-lg-6\">\n      <ng-container *ngIf=\"resultText !== undefined\">\n        <div id=\"div-simulator-results-block\">\n          <div class=\"box box-primary\">\n            <div class=\"box-header with-border\">\n              <h3 class=\"box-title\">Report Text</h3>\n              <div class=\"box-tools pull-right\">\n                <button type=\"button\" class=\"btn btn-box-tool btn-report-text\" (click)=\"collapseReportText()\">\n                  <i id=\"icon_reporttext\" class=\"fa fa-minus\"></i>\n                </button>\n              </div>\n            </div>\n            <div id=\"body_reporttext\" class=\"box-body report-text\">\n              <dl>\n                <acr-assist-report-text [reportText]=\"resultText\"></acr-assist-report-text>\n              </dl>\n            </div>\n          </div>\n        </div>\n      </ng-container>\n    </div>\n    <div class=\"col-xs-6 col-sm-6 col-md-12 col-lg-6\" id=\"div-decissionTree-Block\" *ngIf=\"showKeyDiagram === true\">\n      <div class=\"box box-primary margin-b-0\">\n        <div class=\"box-header with-border\">\n          <h3 class=\"box-title\">Key Diagrams</h3>\n          <input #imageUpload id=\"diagramUpload\" class=\"hidden\" type=\"file\" accept=\"image/*\" multiple (change)=\"changeListener($event)\">\n          <label for=\"diagramUpload\" class=\"btn btn-sm bg-olive margin\" style=\"margin:10px;\" title=\"Choose Diagrams\">Choose a Diagram</label>\n          <div class=\"box-tools pull-right\">\n            <button type=\"button\" class=\"btn btn-box-tool\" data-widget=\"collapse\" (click)=\"collapseKeyDiagram()\">\n              <i id=\"icon_keydiagram\" class=\"fa fa-minus\"></i>\n            </button>\n          </div>\n        </div>\n        <div id=\"body_keydiagram\" class=\"box-body\">\n          <div id=\"carousel-example-generic\" class=\"carousel slide\" data-interval=\"false\" data-ride=\"carousel\">\n            <div class=\"carousel-inner\">\n              <ng-container *ngFor=\"let diagram of keyDiagrams; let i = index\">\n                <div class=\"item\" [ngClass]=\"{'active': diagram.keyDiagram}\">\n                  <img class=\"img-responsive img-decissionTree\" src=\"{{ diagram.location }}\" alt=\"{{ diagram.label }}\">\n                </div>\n              </ng-container>\n            </div>\n            <a class=\"left carousel-control\" href=\"#carousel-example-generic\" data-slide=\"prev\">\n              <span class=\"fa fa-angle-left\"></span>\n            </a>\n            <a class=\"right carousel-control\" href=\"#carousel-example-generic\" data-slide=\"next\">\n              <span class=\"fa fa-angle-right\"></span>\n            </a>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n</ng-container>\n",
                styles: ["", ".required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}"]
            },] },
];
AcrAssistSimulatorComponent.ctorParameters = function () { return [
    { type: TemplateManagerService, },
    { type: SimulatorEngineService, },
]; };
AcrAssistSimulatorComponent.propDecorators = {
    "templateContent": [{ type: Input },],
    "imagePath": [{ type: Input },],
    "showKeyDiagram": [{ type: Input },],
    "reportTextPosition": [{ type: Input },],
    "inputValues": [{ type: Input },],
    "inputData": [{ type: Input },],
    "returnExecutionHistory": [{ type: Output },],
    "returnDefaultElements": [{ type: Output },],
    "imageUpload": [{ type: ViewChild, args: ['imageUpload',] },],
};
var DataElementCreationBaseService = /** @class */ (function () {
    function DataElementCreationBaseService(diagramService) {
        this.diagramService = diagramService;
    }
    DataElementCreationBaseService.prototype.returnDiagram = function (diagramJSON) {
        var metadataDiagram = new Diagram();
        metadataDiagram.displaySequence = diagramJSON.Attr.DisplaySequence;
        metadataDiagram.keyDiagram = diagramJSON.Attr.IsKeyDiagram ? diagramJSON.Attr.IsKeyDiagram : false;
        metadataDiagram.label = diagramJSON.Label;
        metadataDiagram.location = diagramJSON.Location;
        return metadataDiagram;
    };
    DataElementCreationBaseService.prototype.populateBasicData = function (data, dataElement) {
        dataElement.dataElementType = this.elementType;
        dataElement.displaySequence = data.Attr.DisplaySequence;
        dataElement.id = data.Attr.Id;
        dataElement.isRequired = data.Attr.IsRequired === 'true' ? true : false;
        dataElement.label = data.Label;
        dataElement.hint = data.Hint;
        dataElement.cdeId = data.Attr.CdeId;
        if (data.Diagrams) {
            dataElement.diagrams = this.diagramService.returnDiagrams(data.Diagrams.Diagram);
        }
        dataElement.currentValue = undefined;
        dataElement.defaultValue = undefined;
    };
    return DataElementCreationBaseService;
}());
DataElementCreationBaseService.decorators = [
    { type: Injectable },
];
DataElementCreationBaseService.ctorParameters = function () { return [
    { type: DiagramService, },
]; };
var BaseDataElement = /** @class */ (function () {
    function BaseDataElement() {
        this.isVisible = true;
    }
    return BaseDataElement;
}());
var ChoiceDataElement = /** @class */ (function (_super) {
    __extends(ChoiceDataElement, _super);
    function ChoiceDataElement() {
        var _this = _super.apply(this, __spread(arguments)) || this;
        _this.allowFreetext = false;
        return _this;
    }
    return ChoiceDataElement;
}(BaseDataElement));
var Choice = /** @class */ (function () {
    function Choice() {
    }
    return Choice;
}());
var ImageElements = /** @class */ (function () {
    function ImageElements() {
    }
    return ImageElements;
}());
var ImageMap = /** @class */ (function (_super) {
    __extends(ImageMap, _super);
    function ImageMap() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return ImageMap;
}(ImageElements));
var Area = /** @class */ (function () {
    function Area() {
    }
    return Area;
}());
var AreaMap = /** @class */ (function () {
    function AreaMap() {
    }
    return AreaMap;
}());
var ChoiceDataElementCreationService = /** @class */ (function (_super) {
    __extends(ChoiceDataElementCreationService, _super);
    function ChoiceDataElementCreationService(diagramService, arrayCheckerService) {
        var _this = _super.call(this, diagramService) || this;
        _this.arrayCheckerService = arrayCheckerService;
        _this.elementType = 'ChoiceDataElement';
        return _this;
    }
    ChoiceDataElementCreationService.prototype.returnChoice = function (choiceItem) {
        var choice = new Choice();
        choice.label = choiceItem.Label;
        choice.value = choiceItem.Value;
        choice.hint = choiceItem.Hint;
        choice.reportText = choiceItem.ReportText;
        choice.default = false;
        if (choiceItem.Attr && choiceItem.Attr.IsDefault) {
            choice.default = choiceItem.Attr.IsDefault;
        }
        return choice;
    };
    ChoiceDataElementCreationService.prototype.returnArea = function (areaJSON) {
        var area = new Area();
        area.choiceValue = areaJSON.Attr.ChoiceValue;
        area.coords = areaJSON.Attr.Coords;
        area.shape = areaJSON.Attr.Shape;
        return area;
    };
    ChoiceDataElementCreationService.prototype.createElement = function (data) {
        var dataElement = new ChoiceDataElement();
        _super.prototype.populateBasicData.call(this, data, dataElement);
        dataElement.allowFreetext = data.Attr.AllowFreetext ? data.Attr.AllowFreetext : false;
        var choiceItems = data.ChoiceInfo.Choice;
        var defaultValue;
        if (choiceItems !== undefined) {
            dataElement.choiceInfo = new Array();
            if (this.arrayCheckerService.isArray(choiceItems)) {
                try {
                    for (var choiceItems_1 = __values(choiceItems), choiceItems_1_1 = choiceItems_1.next(); !choiceItems_1_1.done; choiceItems_1_1 = choiceItems_1.next()) {
                        var choiceItem = choiceItems_1_1.value;
                        var choice = this.returnChoice(choiceItem);
                        if (choice.default) {
                            defaultValue = choice.value;
                        }
                        dataElement.choiceInfo.push(choice);
                    }
                }
                catch (e_29_1) { e_29 = { error: e_29_1 }; }
                finally {
                    try {
                        if (choiceItems_1_1 && !choiceItems_1_1.done && (_a = choiceItems_1.return)) _a.call(choiceItems_1);
                    }
                    finally { if (e_29) throw e_29.error; }
                }
            }
            else {
                var choice = this.returnChoice(choiceItems);
                if (choice.default) {
                    defaultValue = choice.value;
                }
                dataElement.choiceInfo.push(choice);
            }
        }
        dataElement.defaultValue = defaultValue;
        dataElement.currentValue = defaultValue;
        var imageMap = data.ImageMap;
        if (imageMap !== undefined) {
            dataElement.imageMap = new ImageMap();
            dataElement.imageMap.location = imageMap.Location;
            var areaMaps = imageMap.Map.Area;
            if (areaMaps !== undefined) {
                dataElement.imageMap.map = new AreaMap();
                dataElement.imageMap.map.areas = new Array();
                if (this.arrayCheckerService.isArray(areaMaps)) {
                    try {
                        for (var areaMaps_1 = __values(areaMaps), areaMaps_1_1 = areaMaps_1.next(); !areaMaps_1_1.done; areaMaps_1_1 = areaMaps_1.next()) {
                            var areaMap = areaMaps_1_1.value;
                            dataElement.imageMap.map.areas.push(this.returnArea(areaMap));
                        }
                    }
                    catch (e_30_1) { e_30 = { error: e_30_1 }; }
                    finally {
                        try {
                            if (areaMaps_1_1 && !areaMaps_1_1.done && (_b = areaMaps_1.return)) _b.call(areaMaps_1);
                        }
                        finally { if (e_30) throw e_30.error; }
                    }
                }
                else {
                    dataElement.imageMap.map.areas.push(this.returnArea(areaMaps));
                }
            }
        }
        return dataElement;
        var e_29, _a, e_30, _b;
    };
    return ChoiceDataElementCreationService;
}(DataElementCreationBaseService));
ChoiceDataElementCreationService.decorators = [
    { type: Injectable },
];
ChoiceDataElementCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
]; };
var MultipleChoiceDataElementCreationService = /** @class */ (function (_super) {
    __extends(MultipleChoiceDataElementCreationService, _super);
    function MultipleChoiceDataElementCreationService(diagramService, arrayCheckerService) {
        var _this = _super.call(this, diagramService, arrayCheckerService) || this;
        _this.elementType = 'MultiChoiceDataElement';
        return _this;
    }
    return MultipleChoiceDataElementCreationService;
}(ChoiceDataElementCreationService));
MultipleChoiceDataElementCreationService.decorators = [
    { type: Injectable },
];
MultipleChoiceDataElementCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
]; };
var NumericDataElement = /** @class */ (function (_super) {
    __extends(NumericDataElement, _super);
    function NumericDataElement() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return NumericDataElement;
}(BaseDataElement));
var NumericDataElementCreationService = /** @class */ (function (_super) {
    __extends(NumericDataElementCreationService, _super);
    function NumericDataElementCreationService(diagramService) {
        var _this = _super.call(this, diagramService) || this;
        _this.elementType = 'NumericDataElement';
        return _this;
    }
    NumericDataElementCreationService.prototype.createElement = function (data) {
        var dataElement = new NumericDataElement();
        _super.prototype.populateBasicData.call(this, data, dataElement);
        dataElement.minimum = data.Minimum;
        dataElement.maximum = data.Maximum;
        return dataElement;
    };
    return NumericDataElementCreationService;
}(DataElementCreationBaseService));
NumericDataElementCreationService.decorators = [
    { type: Injectable },
];
NumericDataElementCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
]; };
var IntegerDataElement = /** @class */ (function (_super) {
    __extends(IntegerDataElement, _super);
    function IntegerDataElement() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return IntegerDataElement;
}(BaseDataElement));
var IntegerDataElementCreationService = /** @class */ (function (_super) {
    __extends(IntegerDataElementCreationService, _super);
    function IntegerDataElementCreationService(diagramService) {
        var _this = _super.call(this, diagramService) || this;
        _this.elementType = 'IntegerDataElement';
        return _this;
    }
    IntegerDataElementCreationService.prototype.createElement = function (data) {
        var dataElement = new IntegerDataElement();
        _super.prototype.populateBasicData.call(this, data, dataElement);
        dataElement.minimum = data.Minimum;
        dataElement.maximum = data.Maximum;
        return dataElement;
    };
    return IntegerDataElementCreationService;
}(DataElementCreationBaseService));
IntegerDataElementCreationService.decorators = [
    { type: Injectable },
];
IntegerDataElementCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
]; };
var $$1 = require('jquery');
var AssistDataElementComponent = /** @class */ (function () {
    function AssistDataElementComponent(simulatorEngineService) {
        this.simulatorEngineService = simulatorEngineService;
        this.Endpoints = [];
        this.returnReportText = new EventEmitter();
        this.returnExecutionHistory = new EventEmitter();
        this.comparisonValues = [];
        this.selectedChoiceValues = [];
        this.executedResultIds = [];
        this.executedResultHistories = [];
        this.inputValues = [];
    }
    AssistDataElementComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.simulatorEngineService.simulatorStateChanged.subscribe(function (message) {
            _this.simulatorState = (message);
            _this.dataElementValues = _this.simulatorEngineService.getAllDataElementValues();
            try {
                for (var _a = __values(_this.dataElements), _b = _a.next(); !_b.done; _b = _a.next()) {
                    var dataElement = _b.value;
                    if (_this.simulatorState.nonRelevantDataElementIds && _this.simulatorState.nonRelevantDataElementIds.length > 0) {
                        if (_this.simulatorState.nonRelevantDataElementIds.indexOf(dataElement.id) >= 0) {
                            dataElement.isVisible = false;
                        }
                        else {
                            dataElement.isVisible = true;
                        }
                    }
                    else {
                        dataElement.isVisible = true;
                    }
                    dataElement.currentValue = (dataElement.currentValue !== undefined) ? dataElement.currentValue : _this.dataElementValues[dataElement.id];
                }
            }
            catch (e_31_1) { e_31 = { error: e_31_1 }; }
            finally {
                try {
                    if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                }
                finally { if (e_31) throw e_31.error; }
            }
            if (_this.simulatorState.endPointId && _this.simulatorState.endPointId.length > 0) {
                _this.generateReportText(_this.simulatorState.endPointId);
            }
            else {
                _this.returnReportText.emit(undefined);
            }
            var e_31, _c;
        });
    };
    AssistDataElementComponent.prototype.ngOnChanges = function (changes) {
        this.dataElements = this.dataElements.filter(function (x) { return x.displaySequence != null; }).sort(function (DE_1, DE_2) { return DE_1.displaySequence - DE_2.displaySequence; });
        this.executedResultIds = [];
    };
    AssistDataElementComponent.prototype.choiceSelected = function ($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.selectedChoiceValues[$event.receivedElement.elementId + 'SelectedValue'] = $event.receivedElement.selectedText;
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedValue, $event.receivedElement.selectedText);
            var executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    };
    AssistDataElementComponent.prototype.numericSelected = function ($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedValue, $event.receivedElement.selectedValue);
            var executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    };
    AssistDataElementComponent.prototype.multiSelected = function ($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.comparisonValues[$event.receivedElement.elementId + 'ComparisonValue'] = $event.receivedElement.selectedComparisonValues;
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedComparisonValues, $event.receivedElement.selectedValues);
            var executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    };
    AssistDataElementComponent.prototype.load = function (inputValues, isReset) {
        if (inputValues !== undefined) {
            if (isReset) {
                $$1('select').prop('selectedIndex', 0);
            }
            this.returnReportText.emit(undefined);
            try {
                for (var inputValues_1 = __values(inputValues), inputValues_1_1 = inputValues_1.next(); !inputValues_1_1.done; inputValues_1_1 = inputValues_1.next()) {
                    var inputValue = inputValues_1_1.value;
                    if (inputValue !== undefined) {
                        try {
                            for (var _a = __values(this.dataElements), _b = _a.next(); !_b.done; _b = _a.next()) {
                                var dataElement = _b.value;
                                if (dataElement.id === inputValue.dataElementId) {
                                    switch (dataElement.dataElementType) {
                                        case 'ChoiceDataElement':
                                            if (inputValue.dataElementValue !== undefined) {
                                                if (!isReset) {
                                                    $$1('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).prop('checked', true);
                                                    this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                                }
                                                else {
                                                    $$1('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).prop('checked', false);
                                                    this.isReset = true;
                                                }
                                            }
                                            break;
                                        case 'IntegerDataElement':
                                            if (inputValue.dataElementValue !== undefined) {
                                                if (!isReset) {
                                                    $$1('#' + inputValue.dataElementId).val(inputValue.dataElementValue);
                                                    this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                                    $$1('#' + inputValue.dataElementId).trigger('change');
                                                }
                                                else {
                                                    $$1('#' + inputValue.dataElementId).val('');
                                                    $$1('#' + inputValue.dataElementId).trigger('change');
                                                }
                                                var customEvent = document.createEvent('Event');
                                                customEvent.initEvent('change', true, true);
                                                $$1('#' + inputValue.dataElementId)[0].dispatchEvent(customEvent);
                                            }
                                            break;
                                        case 'NumericDataElement':
                                            if (inputValue.dataElementValue !== undefined) {
                                                if (!isReset) {
                                                    $$1('#' + inputValue.dataElementId).val(inputValue.dataElementValue);
                                                    this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                                    $$1('#' + inputValue.dataElementId).trigger('keyup');
                                                }
                                                else {
                                                    $$1('#' + inputValue.dataElementId).val('');
                                                    $$1('#' + inputValue.dataElementId).trigger('keyup');
                                                }
                                                var customEvent = document.createEvent('Event');
                                                customEvent.initEvent('change', true, true);
                                                $$1('#' + inputValue.dataElementId)[0].dispatchEvent(customEvent);
                                            }
                                            break;
                                        case 'MultiChoiceDataElement':
                                            if (inputValue.dataElementValue !== undefined) {
                                                var customEvent = document.createEvent('Event');
                                                customEvent.initEvent('change', true, true);
                                                if (inputValue.dataElementValue.length !== undefined && inputValue.dataElementValue.length > 0) {
                                                    if (!isReset) {
                                                        if (Array.isArray(inputValue.dataElementValue)) {
                                                            for (var element in inputValue.dataElementValue) {
                                                                $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element]).prop('checked', true);
                                                                $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element])[0].dispatchEvent(customEvent);
                                                            }
                                                        }
                                                        else {
                                                            $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue).prop('checked', true);
                                                            $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue)[0].dispatchEvent(customEvent);
                                                        }
                                                    }
                                                    else {
                                                        if (Array.isArray(inputValue.dataElementValue)) {
                                                            for (var element in inputValue.dataElementValue) {
                                                                $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element]).prop('checked', false);
                                                                customEvent.initEvent('change', true, true);
                                                                $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element])[0].dispatchEvent(customEvent);
                                                            }
                                                        }
                                                        else {
                                                            $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue).prop('checked', false);
                                                            $$1('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue)[0].dispatchEvent(customEvent);
                                                        }
                                                    }
                                                }
                                            }
                                            break;
                                    }
                                }
                            }
                        }
                        catch (e_32_1) { e_32 = { error: e_32_1 }; }
                        finally {
                            try {
                                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                            }
                            finally { if (e_32) throw e_32.error; }
                        }
                    }
                }
            }
            catch (e_33_1) { e_33 = { error: e_33_1 }; }
            finally {
                try {
                    if (inputValues_1_1 && !inputValues_1_1.done && (_d = inputValues_1.return)) _d.call(inputValues_1);
                }
                finally { if (e_33) throw e_33.error; }
            }
        }
        else {
            throw console.error('Invalid values');
        }
        var e_33, _d, e_32, _c;
    };
    AssistDataElementComponent.prototype.generateReportText = function (endpointId) {
        var endpointContent = this.returnEndPointContents(this.xmlContent, '<EndPoint Id="' + endpointId + '">', '</EndPoint>');
        this.parseXml(endpointId, endpointContent);
    };
    AssistDataElementComponent.prototype.generateExecutionHistory = function () {
        this.executedResultHistories = [];
        var isNonRelevant;
        isNonRelevant = false;
        for (var resultId in this.executedResultIds) {
            try {
                for (var _a = __values(this.simulatorState.nonRelevantDataElementIds), _b = _a.next(); !_b.done; _b = _a.next()) {
                    var nonRelevantDataElement = _b.value;
                    if (nonRelevantDataElement === resultId) {
                        isNonRelevant = true;
                        break;
                    }
                    else {
                        isNonRelevant = false;
                    }
                }
            }
            catch (e_34_1) { e_34 = { error: e_34_1 }; }
            finally {
                try {
                    if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                }
                finally { if (e_34) throw e_34.error; }
            }
            if (!isNonRelevant) {
                for (var label in this.executedResultIds[resultId]) {
                    var executedResultHistory = new ExecutedResultHistory();
                    executedResultHistory.resultCondition = label;
                    executedResultHistory.resultValue = this.executedResultIds[resultId][label];
                    this.executedResultHistories.push(executedResultHistory);
                }
            }
        }
        var finalExecution = new FinalExecutedHistory();
        if (this.executedResultHistories.length > 0) {
            finalExecution.executionHistories = this.executedResultHistories;
            finalExecution.resultText = this.mainReportTextObj;
        }
        this.returnExecutionHistory.emit(finalExecution);
        var e_34, _c;
    };
    AssistDataElementComponent.prototype.returnEndPointContents = function (content, startToken, endToken) {
        var contents;
        var templateSearchIndexPosition = 0;
        while (true) {
            var contentStartPosition = content.indexOf(startToken, templateSearchIndexPosition);
            var contentEndPosition = content.indexOf(endToken, templateSearchIndexPosition);
            if (contentStartPosition >= 0 && contentEndPosition >= 0) {
                var endPosition = contentEndPosition + endToken.length;
                var contentData = content.substring(contentStartPosition, endPosition);
                contents = contentData;
                templateSearchIndexPosition = endPosition + 1;
            }
            else {
                break;
            }
        }
        return contents;
    };
    AssistDataElementComponent.prototype.parseXml = function (endPointId, endpointContent) {
        var canInsertText;
        var isSectionIf;
        var selectedElements;
        var executeSectionIfNot;
        var hasSectionNot;
        var executeTemplate;
        var isImpression;
        var isNewTemplate;
        var hasInsertPartial;
        var isMainText;
        var allReportText = [];
        var endpoints = this.Endpoints;
        var templatePartialsText;
        var selectedComparisonValues;
        var findingsText;
        var impressionText;
        var selectedSection;
        var selectedChoiceTexts;
        var textExpressionValue;
        selectedElements = this.simulatorEngineService.getAllDataElementValues();
        templatePartialsText = this.templatePartial;
        selectedComparisonValues = this.comparisonValues;
        selectedChoiceTexts = this.simulatorEngineService.getAllDataElementTexts();
        executeSectionIfNot = false;
        hasInsertPartial = false;
        findingsText = '';
        impressionText = '';
        var isReportText;
        var reportTextContent = '';
        var endpointSax = require('sax'), strict = true, normalize = true, trim = true, reportTextParser = endpointSax.parser(strict, trim);
        reportTextParser.onerror = function (e) {
            reportTextParser.resume();
        };
        reportTextParser.ontext = function (t) {
            if (t.length > 1) {
                t = t.trim();
            }
            var isTextInserted;
            isTextInserted = false;
            if (executeTemplate) {
                if (!isImpression) {
                    if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                        findingsText = findingsText + t;
                    }
                    else if (canInsertText && isNewTemplate && hasInsertPartial && !isSectionIf) {
                        findingsText = findingsText + t;
                    }
                    else if (canInsertText && !isImpression) {
                        findingsText = findingsText + t;
                    }
                }
                else {
                    if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                        impressionText = impressionText + t;
                    }
                    else if (canInsertText && !hasSectionNot && isImpression) {
                        impressionText = impressionText + t;
                    }
                    else if (canInsertText && isNewTemplate) {
                        impressionText = impressionText + t;
                    }
                }
                if (isReportText && !isTextInserted && isMainText && canInsertText) {
                    reportTextContent = reportTextContent + t;
                }
            }
        };
        reportTextParser.onopentag = function (node) {
            switch (node.name) {
                case 'Label':
                    canInsertText = false;
                    isReportText = false;
                    isMainText = false;
                    break;
                case 'ReportText':
                    if (executeTemplate) {
                        isReportText = true;
                        canInsertText = true;
                        selectedSection = node.attributes.SectionId;
                        impressionText = '';
                        if (node.attributes.SectionId === 'findings' && executeTemplate) {
                            isImpression = false;
                        }
                        else if (node.attributes.SectionId === 'impression' && executeTemplate) {
                            isImpression = true;
                        }
                    }
                    isSectionIf = false;
                    break;
                case 'InsertPartial':
                    if (executeTemplate) {
                        generatePartialView(node.attributes.PartialId, isImpression);
                        executeTemplate = true;
                        canInsertText = true;
                        if (isReportText) {
                            hasInsertPartial = true;
                        }
                        else {
                            hasInsertPartial = false;
                        }
                    }
                    else {
                        canInsertText = false;
                    }
                    isReportText = false;
                    isMainText = false;
                    break;
                case 'SectionIfValueNot':
                    if (executeTemplate) {
                        if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                            try {
                                for (var _a = __values(selectedElements[node.attributes.DataElementId]), _b = _a.next(); !_b.done; _b = _a.next()) {
                                    var comaprisonValue = _b.value;
                                    if (comaprisonValue !== node.attributes.ComparisonValue &&
                                        comaprisonValue !== undefined && !isSectionIf) {
                                        canInsertText = true;
                                        executeSectionIfNot = true;
                                        break;
                                    }
                                    else {
                                        canInsertText = false;
                                        executeSectionIfNot = false;
                                    }
                                }
                            }
                            catch (e_35_1) { e_35 = { error: e_35_1 }; }
                            finally {
                                try {
                                    if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                                }
                                finally { if (e_35) throw e_35.error; }
                            }
                        }
                        else if (selectedElements[node.attributes.DataElementId] !== node.attributes.ComparisonValue &&
                            selectedElements[node.attributes.DataElementId] !== '--Select--' &&
                            selectedElements[node.attributes.DataElementId] !== undefined &&
                            selectedElements[node.attributes.DataElementId] !== null) {
                            canInsertText = true;
                            executeSectionIfNot = true;
                        }
                        else {
                            canInsertText = false;
                            executeSectionIfNot = false;
                        }
                    }
                    hasSectionNot = true;
                    isMainText = false;
                    break;
                case 'SectionIf':
                    if (selectedElements[node.attributes.DataElementId] !== undefined && selectedElements[node.attributes.DataElementId].length > 0 && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                        isSectionIf = true;
                        canInsertText = true;
                    }
                    else {
                        isSectionIf = false;
                        canInsertText = false;
                    }
                    break;
                case 'SectionIfValue':
                    if (executeTemplate) {
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                try {
                                    for (var _d = __values(selectedElements[node.attributes.DataElementId]), _e = _d.next(); !_e.done; _e = _d.next()) {
                                        var comaprisonValue = _e.value;
                                        if (comaprisonValue === node.attributes.ComparisonValue &&
                                            comaprisonValue !== undefined) {
                                            isSectionIf = true;
                                            if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                                findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                            }
                                            canInsertText = true;
                                            break;
                                        }
                                        else {
                                            isSectionIf = false;
                                            canInsertText = false;
                                        }
                                    }
                                }
                                catch (e_36_1) { e_36 = { error: e_36_1 }; }
                                finally {
                                    try {
                                        if (_e && !_e.done && (_f = _d.return)) _f.call(_d);
                                    }
                                    finally { if (e_36) throw e_36.error; }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] === node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== undefined) {
                                isSectionIf = true;
                                if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                    findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                }
                                canInsertText = true;
                            }
                            else {
                                canInsertText = false;
                            }
                        }
                        break;
                    }
                    isMainText = false;
                    break;
                case 'InsertValue':
                    if (executeTemplate) {
                        isReportText = false;
                        var choiceText = selectedChoiceTexts[node.attributes.DataElementId];
                        if (node.attributes.Id === 'findings' || canInsertText) {
                            if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot) {
                                if (isImpression) {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        impressionText = impressionText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                                else {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        findingsText = findingsText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot) {
                                if (isImpression) {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        impressionText = impressionText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                                else {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        findingsText = findingsText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                            }
                            if (isImpression) {
                                canInsertText = true;
                            }
                        }
                        isMainText = false;
                        break;
                    }
            }
            executeTemplate = true;
            isNewTemplate = true;
            var e_35, _c, e_36, _f;
        };
        reportTextParser.onclosetag = function (node) {
            switch (node) {
                case 'SectionIfValueNot':
                    executeSectionIfNot = false;
                    hasSectionNot = false;
                    if (isSectionIf) {
                        canInsertText = true;
                    }
                    break;
                case 'TemplatePartial':
                    isNewTemplate = false;
                    canInsertText = false;
                    executeTemplate = false;
                    break;
                case 'ReportText':
                    if (!hasInsertPartial && !isImpression) {
                        var reportTextObj = new AllReportText();
                        reportTextObj.sectionId = 'findings';
                        reportTextObj.reportText = findingsText;
                        allReportText[reportTextObj.sectionId] = reportTextObj;
                    }
                    if (impressionText !== '' && impressionText !== undefined) {
                        var reportTextObj = new AllReportText();
                        reportTextObj.sectionId = selectedSection;
                        reportTextObj.reportText = impressionText;
                        allReportText[reportTextObj.sectionId] = reportTextObj;
                    }
                    hasInsertPartial = false;
                    break;
                case 'SectionIf':
                    isSectionIf = false;
                    canInsertText = true;
                    break;
                case 'InsertPartial':
                    canInsertText = true;
                    break;
                case 'InsertValue':
                    if ((hasSectionNot && executeSectionIfNot || !hasSectionNot)) {
                        canInsertText = true;
                    }
                    break;
                case 'SectionIfValue':
                    canInsertText = true;
                    break;
            }
        };
        reportTextParser.onend = function () {
        };
        reportTextParser.write(endpointContent).onend();
        function getTextExpressionValue(textExpression) {
            if (textExpression.indexOf('{') === 0 && (textExpression.indexOf('}') > 1)) {
                var subString = textExpression.substr(textExpression.indexOf('{') + 1, textExpression.indexOf('}') - 1);
                getTextExpressionValue(selectedElements[subString]);
            }
            else {
                textExpressionValue = textExpression;
            }
        }
        function generatePartialView(partialViewId, isImpressionTemplate) {
            var sax = require('sax'), parser = sax.parser(strict, trim);
            parser.onerror = function (e) {
            };
            parser.ontext = function (t) {
                if (executeTemplate) {
                    if (!isImpressionTemplate) {
                        if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                            findingsText = findingsText + t;
                        }
                        else if (canInsertText && !hasSectionNot && isImpression) {
                            findingsText = findingsText + t;
                        }
                        else if (canInsertText && isNewTemplate) {
                            findingsText = findingsText + t;
                        }
                    }
                    else {
                        if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                            impressionText = impressionText + t;
                        }
                        else if (canInsertText && !hasSectionNot && isImpression) {
                            impressionText = impressionText + t;
                        }
                        else if (canInsertText && isNewTemplate) {
                            impressionText = impressionText + t;
                        }
                    }
                }
            };
            parser.onopentag = function (node) {
                switch (node.name) {
                    case 'Label':
                        canInsertText = false;
                        break;
                    case 'EndPoint':
                        if (node.attributes.Id !== '') {
                            canInsertText = true;
                            isImpression = true;
                        }
                        else {
                            canInsertText = false;
                            isImpression = false;
                        }
                        break;
                    case 'InsertPartial':
                        canInsertText = false;
                        break;
                    case 'ReportText':
                        canInsertText = true;
                        break;
                    case 'TemplatePartial':
                        hasSectionNot = false;
                        executeSectionIfNot = false;
                        if (node.attributes.Id === partialViewId) {
                            executeTemplate = true;
                            canInsertText = true;
                            isNewTemplate = true;
                            break;
                        }
                        else {
                            isNewTemplate = false;
                            executeTemplate = false;
                        }
                        break;
                    case 'SectionIfValueNot':
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                try {
                                    for (var _a = __values(selectedComparisonValues[node.attributes.DataElementId + 'ComparisonValue']), _b = _a.next(); !_b.done; _b = _a.next()) {
                                        var comaprisonValue = _b.value;
                                        if (comaprisonValue !== node.attributes.ComparisonValue &&
                                            comaprisonValue !== undefined && !isSectionIf) {
                                            canInsertText = true;
                                            executeSectionIfNot = true;
                                            break;
                                        }
                                        else {
                                            canInsertText = false;
                                            executeSectionIfNot = false;
                                        }
                                    }
                                }
                                catch (e_37_1) { e_37 = { error: e_37_1 }; }
                                finally {
                                    try {
                                        if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                                    }
                                    finally { if (e_37) throw e_37.error; }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] !== node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== '--Select--' &&
                                selectedElements[node.attributes.DataElementId] !== undefined &&
                                selectedElements[node.attributes.DataElementId] !== null) {
                                canInsertText = true;
                                executeSectionIfNot = true;
                            }
                            else {
                                canInsertText = false;
                                executeSectionIfNot = false;
                            }
                        }
                        hasSectionNot = true;
                        break;
                    case 'SectionIf':
                        if (selectedElements[node.attributes.DataElementId] !== undefined && selectedElements[node.attributes.DataElementId].length > 0 && (!hasSectionNot || (hasSectionNot && executeSectionIfNot))
                            && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                            isSectionIf = true;
                            canInsertText = true;
                        }
                        else {
                            isSectionIf = false;
                            canInsertText = false;
                        }
                        break;
                    case 'SectionIfValue':
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                try {
                                    for (var _d = __values(selectedComparisonValues[node.attributes.DataElementId + 'ComparisonValue']), _e = _d.next(); !_e.done; _e = _d.next()) {
                                        var comaprisonValue = _e.value;
                                        if (comaprisonValue === node.attributes.ComparisonValue &&
                                            comaprisonValue !== undefined) {
                                            isSectionIf = true;
                                            if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                                findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                            }
                                            canInsertText = true;
                                            break;
                                        }
                                        else {
                                            isSectionIf = false;
                                            canInsertText = false;
                                        }
                                    }
                                }
                                catch (e_38_1) { e_38 = { error: e_38_1 }; }
                                finally {
                                    try {
                                        if (_e && !_e.done && (_f = _d.return)) _f.call(_d);
                                    }
                                    finally { if (e_38) throw e_38.error; }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] === node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== undefined) {
                                isSectionIf = true;
                                if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                    findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                }
                                canInsertText = true;
                            }
                            else {
                                canInsertText = false;
                            }
                        }
                        break;
                    case 'InsertValue':
                        if (executeTemplate) {
                            var choiceText = selectedChoiceTexts[node.attributes.DataElementId];
                            if (node.attributes.Id === 'findings' || canInsertText) {
                                if (isImpression) {
                                    canInsertText = true;
                                    if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                        else {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                    else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                        else {
                                            if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                                impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                            }
                                        }
                                    }
                                }
                                else {
                                    if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                    else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                }
                            }
                            break;
                        }
                }
                var e_37, _c, e_38, _f;
            };
            parser.onclosetag = function (node) {
                switch (node) {
                    case 'SectionIfValueNot':
                        executeSectionIfNot = false;
                        hasSectionNot = false;
                        if (isSectionIf) {
                            canInsertText = true;
                        }
                        break;
                    case 'TemplatePartial':
                        isNewTemplate = true;
                        canInsertText = false;
                        executeTemplate = true;
                        break;
                    case 'InsertPartial':
                        canInsertText = true;
                        break;
                    case 'SectionIf' || 'SectionIfValue':
                        isSectionIf = false;
                        break;
                }
            };
            parser.onend = function () {
                var reportTextObj = new AllReportText();
                reportTextObj.sectionId = 'findings';
                reportTextObj.reportText = findingsText;
                allReportText[reportTextObj.sectionId] = reportTextObj;
            };
            parser.write(templatePartialsText).onend();
        }
        this.mainReportTextObj = new MainReportText();
        this.mainReportTextObj.reportTextMainContent = reportTextContent;
        this.mainReportTextObj.allReportText = allReportText;
        this.returnReportText.emit(this.mainReportTextObj);
    };
    return AssistDataElementComponent;
}());
AssistDataElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-data-element',
                template: "<ng-container *ngFor=\"let DataElement of dataElements\">\n  <ng-container *ngIf=\"(DataElement.dataElementType == 'ChoiceDataElement' || DataElement.dataElementType == 'NumericDataElement' || DataElement.dataElementType == 'IntegerDataElement' || DataElement.dataElementType == 'MultiChoiceDataElement') \">\n    <ng-container *ngIf=\"DataElement.isVisible\">\n      <div id=\"div_{{DataElement.id}}\">\n        <ng-container *ngIf=\"DataElement.dataElementType == 'ChoiceDataElement'\">\n          <acr-assist-choice-element [choiceDataElement]='DataElement' [imagePath]='imagePath' (returnChoiceElement)='choiceSelected($event)'></acr-assist-choice-element>\n        </ng-container>\n        <ng-container *ngIf=\"DataElement.dataElementType == 'MultiChoiceDataElement'\">\n          <acr-assist-multi-choice-element [multiChoiceElement]='DataElement' [imagePath]='imagePath' (returnMultiChoice)='multiSelected($event)'></acr-assist-multi-choice-element>\n        </ng-container>\n        <ng-container *ngIf=\"DataElement.dataElementType == 'NumericDataElement' || DataElement.dataElementType == 'IntegerDataElement'\">\n          <acr-assist-numeric-element [numericDataElement]='DataElement' [imagePath]='imagePath' (returnNumericElement)='numericSelected($event)'></acr-assist-numeric-element>\n        </ng-container>\n      </div>\n    </ng-container>\n  </ng-container>\n</ng-container>\n",
                styles: ["", ".required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}"]
            },] },
];
AssistDataElementComponent.ctorParameters = function () { return [
    { type: SimulatorEngineService, },
]; };
AssistDataElementComponent.propDecorators = {
    "dataElements": [{ type: Input },],
    "imagePath": [{ type: Input },],
    "Endpoints": [{ type: Input },],
    "templatePartial": [{ type: Input },],
    "endPointXMLString": [{ type: Input },],
    "xmlContent": [{ type: Input },],
    "returnReportText": [{ type: Output },],
    "returnExecutionHistory": [{ type: Output },],
    "isReset": [{ type: Input },],
    "inputValues": [{ type: Input },],
};
var ChoiceElement = /** @class */ (function () {
    function ChoiceElement() {
    }
    return ChoiceElement;
}());
var NumericElement = /** @class */ (function () {
    function NumericElement() {
    }
    return NumericElement;
}());
var MultiChoiceElement = /** @class */ (function () {
    function MultiChoiceElement() {
    }
    return MultiChoiceElement;
}());
var MainReportText = /** @class */ (function () {
    function MainReportText() {
    }
    return MainReportText;
}());
var AllReportText = /** @class */ (function () {
    function AllReportText() {
    }
    return AllReportText;
}());
var ExecutedResultHistory = /** @class */ (function () {
    function ExecutedResultHistory() {
    }
    return ExecutedResultHistory;
}());
var FinalExecutedHistory = /** @class */ (function () {
    function FinalExecutedHistory() {
    }
    return FinalExecutedHistory;
}());
var HintDiagramComponent = /** @class */ (function () {
    function HintDiagramComponent() {
        this.activeSlideIndex = 0;
    }
    HintDiagramComponent.prototype.resetCarouselIndex = function () {
        this.activeSlideIndex = 0;
    };
    return HintDiagramComponent;
}());
HintDiagramComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-hint-diagram',
                template: "<ng-container *ngIf=\"DataElement !== undefined\">\n  <button type=\"button\" class=\"btn btn-default btn-xs\" data-toggle=\"modal\" attr.data-target=\"#{{'diag_'+DataElement.id}}\" (click)=\"resetCarouselIndex()\">\n    <span class=\"glyphicon glyphicon-picture\" aria-hidden=\"true\" data-toggle=\"tooltip\" data-placement=\"right\" title=\"Hint Diagrams\"></span>\n  </button>\n  <div class=\"modal inmodal fade\" id=\"{{'diag_'+DataElement.id}}\" tabindex=\"-1\" role=\"dialog\" aria-hidden=\"true\">\n    <div class=\"modal-dialog modal-lg\">\n      <div class=\"modal-content\">\n        <div class=\"modal-header\">\n          <button type=\"button\" class=\"close\" data-dismiss=\"modal\">\n            <span aria-hidden=\"true\">&times;</span>\n            <span class=\"sr-only\">Close</span>\n          </button>\n          <h4 class=\"modal-title float-left\">{{DataElement.label}}</h4>\n        </div>\n        <div class=\"modal-body\">\n          <ng-container>\n            <carousel [(activeSlide)]=\"activeSlideIndex\" interval=\"false\">\n              <ng-container *ngFor=\"let diag of DataElement.diagrams \">\n                <slide>\n                  <img src=\"{{imagePath}}/{{diag.location}}\" alt=\"Image Not Available!!!\">\n                </slide>\n              </ng-container>\n            </carousel>\n          </ng-container>\n        </div>\n        <div class=\"modal-footer\">\n          <button type=\"button\" class=\"btn btn-primary\" data-dismiss=\"modal\">Close</button>\n        </div>\n      </div>\n    </div>\n  </div>\n</ng-container>\n",
                styles: ["", ".required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}"]
            },] },
];
HintDiagramComponent.propDecorators = {
    "DataElement": [{ type: Input },],
    "imagePath": [{ type: Input },],
};
var GlobalValue = /** @class */ (function (_super) {
    __extends(GlobalValue, _super);
    function GlobalValue() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return GlobalValue;
}(BaseDataElement));
var GlobalValueCreationService = /** @class */ (function (_super) {
    __extends(GlobalValueCreationService, _super);
    function GlobalValueCreationService(diagramService) {
        var _this = _super.call(this, diagramService) || this;
        _this.elementType = 'GlobalValue';
        return _this;
    }
    GlobalValueCreationService.prototype.createElement = function (data) {
        var dataElement = new GlobalValue();
        dataElement.id = data.Attr.Id;
        dataElement.currentValue = data._;
        dataElement.dataElementType = 'GlobalValue';
        return dataElement;
    };
    return GlobalValueCreationService;
}(DataElementCreationBaseService));
GlobalValueCreationService.decorators = [
    { type: Injectable },
];
GlobalValueCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
]; };
var SelectedCondition = /** @class */ (function () {
    function SelectedCondition() {
    }
    return SelectedCondition;
}());
var $$2 = require('jquery');
var AssistNumericElementComponent = /** @class */ (function () {
    function AssistNumericElementComponent(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnNumericElement = new EventEmitter();
    }
    AssistNumericElementComponent.prototype.ngOnInit = function () {
        this.createNumericElementForm();
    };
    AssistNumericElementComponent.prototype.ngAfterViewInit = function () {
        if (this.numericDataElement.currentValue !== undefined && this.numericDataElement.currentValue !== 0) {
            this.simulatorEngineService.addOrUpdateDataElement(this.numericDataElement.id, this.numericDataElement.currentValue, this.numericDataElement.currentValue);
            var customEvent = document.createEvent('Event');
            this.numberValue = this.numericDataElement.currentValue;
            this.loadedNumericValue(this.numericDataElement.id, this.numericDataElement.currentValue, this.numericDataElement.label);
        }
    };
    AssistNumericElementComponent.prototype.loadedNumericValue = function (id, value, selectedCondition) {
        var choiceElement = new NumericElement();
        choiceElement.elementId = id;
        choiceElement.selectedValue = value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = value;
        this.returnNumericElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    AssistNumericElementComponent.prototype.choiceSelected = function (element, selectedCondition) {
        var choiceElement = new NumericElement();
        choiceElement.elementId = element.id;
        choiceElement.selectedValue = element.value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = element.id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.value;
        this.returnNumericElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    AssistNumericElementComponent.prototype.createNumericElementForm = function () {
        this.numericElementForm = this.formBuilder.group({
            numericElement: ['', Validators.compose([Validators.required, Validators.min(+this.numericDataElement.minimum)])],
        });
    };
    AssistNumericElementComponent.prototype.specificValueInsideRange = function (numericKey) {
        var _this = this;
        return function (group) {
            var numericControl = group.controls[numericKey];
            if ((numericControl.value === 'undefined' || numericControl.value === '') && _this.numericDataElement.isRequired) {
                return numericControl.setErrors({ notEquivalent: true });
            }
            else {
                return numericControl.setErrors(null);
            }
        };
    };
    AssistNumericElementComponent.prototype.onlyNumberKey = function (event) {
        return (event.charCode === 8 || event.charCode === 0) ? null : event.charCode >= 48 && event.charCode <= 57;
    };
    return AssistNumericElementComponent;
}());
AssistNumericElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-numeric-element',
                template: "<form [formGroup]=\"numericElementForm\" novalidate>\n  <div class=\"form-group\">\n    <div class=\"col-sm-5 text-right\">\n      <label class=\"control-label\">\n        {{numericDataElement.label}}\n      </label>\n      <ng-container *ngIf=\"numericDataElement.hint !== '' && numericDataElement.hint !== undefined\">\n        <i class=\"fa fa-info-circle text-primary\" title=\"{{numericDataElement.hint}}\"></i>\n      </ng-container>\n      <ng-container *ngIf=\"numericDataElement.diagrams != undefined \">\n        <acr-hint-diagram [DataElement]=\"numericDataElement\" [imagePath]=\"imagePath\"></acr-hint-diagram>\n      </ng-container>\n      <ng-container *ngIf=\"this.numericDataElement.isRequired\">\n        <span *ngIf=\"numericElementForm.controls['numericElement'].invalid\">\n          <span *ngIf=\"numericElementForm.controls['numericElement'].errors.required\" class=\"required-field\" title=\"Required Field\">\n            *\n          </span>\n        </span>\n      </ng-container>\n      <span *ngIf=\"numericElementForm.controls['numericElement'].invalid && numericElementForm.controls['numericElement'].errors.min\"\n        class=\"required-field\" title=\" Minimum value is {{numericDataElement.minimum}}\">\n        *\n      </span>\n    </div>\n    <ng-container *ngIf=\"numericDataElement.dataElementType === 'NumericDataElement'\">\n      <div class=\"col-sm-7\">\n        <input [(ngModel)]=\"numberValue\" id=\"{{numericDataElement.id}}\" type=\"number\" class=\"form-control\" formControlName=\"numericElement\"\n          (keypress)=\"onlyNumberKey($event)\" onpaste=\"return false;\" (input)=\"choiceSelected($event.target, numericDataElement.label)\"\n          min=\"{{numericDataElement.minimum}}\" required>\n      </div>\n    </ng-container>\n    <ng-container *ngIf=\"numericDataElement.dataElementType === 'IntegerDataElement'\">\n      <div class=\"col-sm-7\">\n        <input [(ngModel)]=\"numberValue\" id=\"{{numericDataElement.id}}\" type=\"number\" class=\"form-control\" formControlName=\"numericElement\"\n          (keypress)=\"onlyNumberKey($event)\" onpaste=\"return false;\" (input)=\"choiceSelected($event.target, numericDataElement.label)\"\n          min=\"{{numericDataElement.minimum}}\" required>\n      </div>\n    </ng-container>\n  </div>\n</form>\n",
                styles: ["", ".required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}"]
            },] },
];
AssistNumericElementComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
]; };
AssistNumericElementComponent.propDecorators = {
    "numericDataElement": [{ type: Input },],
    "imagePath": [{ type: Input },],
    "returnNumericElement": [{ type: Output },],
};
var $$3 = require('jquery');
var AssistChoiceElementComponent = /** @class */ (function () {
    function AssistChoiceElementComponent(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnChoiceElement = new EventEmitter();
        this.choiceChange = new EventEmitter();
    }
    AssistChoiceElementComponent.prototype.ngOnInit = function () {
        this.createChoiceElementForm();
    };
    AssistChoiceElementComponent.prototype.ngAfterViewInit = function () {
        $$3('#div_' + this.choiceDataElement.id + '_other').hide();
        if (this.choiceDataElement.currentValue !== undefined) {
            $$3('#' + this.choiceDataElement.currentValue + '_' + this.choiceDataElement.id).prop('checked', true);
            this.choiceValue = this.choiceDataElement.currentValue;
            for (var choice in this.choiceDataElement.choiceInfo) {
                if (this.choiceDataElement.choiceInfo[choice].value === this.choiceDataElement.currentValue) {
                    if (this.choiceDataElement.choiceInfo[choice].reportText !== undefined) {
                        this.selectedChoiceReportText = this.choiceDataElement.choiceInfo[choice].reportText;
                    }
                    else {
                        this.selectedChoiceReportLabel = this.choiceDataElement.choiceInfo[choice].label;
                    }
                }
            }
            if (this.choiceDataElement.choiceInfo.length <= 5) {
                this.updateChoiceValue(this.choiceDataElement.id, this.choiceDataElement.label, (this.selectedChoiceReportText !== undefined) ? this.selectedChoiceReportText : this.selectedChoiceReportLabel, this.choiceDataElement.currentValue);
            }
            else {
                this.updateDropdownChoiceSelected(this.choiceDataElement.id, this.selectedChoiceReportLabel, this.choiceDataElement.currentValue, this.choiceDataElement.label);
            }
        }
    };
    AssistChoiceElementComponent.prototype.updateChoiceValue = function (elementId, selectedElement, selectedText, selectedValue) {
        var choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = selectedValue;
        choiceElement.selectedText = selectedText;
        this.showOrHideFreeText(elementId, choiceElement.selectedValue);
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedElement;
        this.selectedCondition.selectedValue = selectedText;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    AssistChoiceElementComponent.prototype.updateDropdownChoiceSelected = function (elementId, elementLabel, elementValue, selectedCondition) {
        var choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = elementValue;
        choiceElement.selectedText = elementLabel;
        if (this.choiceValue === 'undefined' || this.choiceValue === undefined || this.choiceValue === '') {
            choiceElement.selectedText = '';
            choiceElement.selectedValue = '';
        }
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = elementLabel;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    AssistChoiceElementComponent.prototype.choiceSelected = function (elementId, selectedElement, selectedText, selectedValue) {
        var choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = selectedValue;
        choiceElement.selectedText = selectedText;
        this.showOrHideFreeText(elementId, choiceElement.selectedValue);
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedElement;
        this.selectedCondition.selectedValue = selectedText;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    AssistChoiceElementComponent.prototype.dropdownChoiceSelected = function (element, selectedCondition) {
        var choiceElement = new ChoiceElement();
        choiceElement.elementId = element.id;
        choiceElement.selectedValue = (element.selectedOptions[0].label === 'Other, please specify…') ? 'freetext' : element.value;
        choiceElement.selectedText = element.selectedOptions[0].label;
        this.showOrHideFreeText(element.id, choiceElement.selectedValue);
        if (this.choiceValue === 'undefined' || this.choiceValue === undefined || this.choiceValue === '') {
            choiceElement.selectedText = '';
            choiceElement.selectedValue = '';
        }
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = element.id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.selectedOptions[0].label;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    AssistChoiceElementComponent.prototype.createChoiceElementForm = function () {
        this.choiceElementForm = this.formBuilder.group({
            checkBox: ['', Validators.required],
        }, {
            validator: this.specificValueInsideRange('checkBox')
        });
    };
    AssistChoiceElementComponent.prototype.showOrHideFreeText = function (elementId, selectedValue) {
        if (selectedValue === 'freetext') {
            $$3('#div_' + elementId + '_other').show();
        }
        else {
            $$3('#div_' + elementId + '_other').hide();
            $$3('#txt_other_' + elementId).val('');
        }
    };
    AssistChoiceElementComponent.prototype.updateFreeText = function (element, elementId, selectedCondition) {
        var choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = (element.value === 'Other') ? 'freetext' : element.value;
        choiceElement.selectedText = element.value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.value;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    };
    AssistChoiceElementComponent.prototype.specificValueInsideRange = function (checkBoxKey) {
        var _this = this;
        return function (group) {
            var choiceControl = group.controls[checkBoxKey];
            if ((choiceControl.value === 'undefined' || choiceControl.value === '' || _this.choiceValue === undefined || _this.choiceValue === '')) {
                return choiceControl.setErrors({ notEquivalent: true });
            }
            else {
                return choiceControl.setErrors(null);
            }
        };
    };
    return AssistChoiceElementComponent;
}());
AssistChoiceElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-choice-element',
                template: "<form [formGroup]=\"choiceElementForm\" novalidate>\n  <div class=\"form-group\">\n    <div class=\"col-sm-5 text-right\">\n      <label class=\"control-label\">\n        {{choiceDataElement.label}}\n      </label>\n      <ng-container *ngIf=\"choiceDataElement.hint !== '' && choiceDataElement.hint !== undefined\">\n        <i>\n          <span class=\"fa fa-info-circle text-primary\" data-toggle=\"tooltip\" data-placement=\"right\" title=\"{{choiceDataElement.hint}}\"></span>\n        </i>\n      </ng-container>\n      <ng-container *ngIf=\"choiceDataElement.diagrams != undefined \">\n        <acr-hint-diagram [DataElement]=\"choiceDataElement\" [imagePath]=\"imagePath\"></acr-hint-diagram>\n      </ng-container>\n      <span *ngIf=\"choiceElementForm.controls['checkBox'].invalid  && this.choiceDataElement.isRequired\" class=\"required-field\"\n        title=\"Required Field\">*</span>\n    </div>\n    <div class=\"col-sm-7 text-left content-padding\">\n      <ng-container *ngIf=\"choiceDataElement.choiceInfo.length <= 2\">\n        <ng-container *ngIf=\"imagePath != undefined\">\n          <ng-container *ngIf=\"choiceDataElement.imageMap == undefined\">\n            <ng-container *ngFor=\"let choice of choiceDataElement.choiceInfo\">\n              <div class=\"radio\" style=\"float:left; margin-right:15px;\">\n                <label>\n                  <input [(ngModel)]=\"choiceValue\" id=\"{{choice.value}}_{{choiceDataElement.id}}\" type=\"radio\" formControlName=\"checkBox\" value=\"{{choice.value}}\"\n                    (change)=\"choiceSelected(choiceDataElement.id, choiceDataElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, choice.value)\"> {{choice.label}}\n                </label>\n              </div>\n            </ng-container>\n            <ng-container *ngIf=\"choiceDataElement.allowFreetext\">\n              <div class=\"radio\" style=\"float:left; margin-right:15px;\">\n                <label>\n                  <input id=\"other_{{choiceDataElement.id}}\" type=\"radio\" formControlName=\"checkBox\" value=\"freetext\" (change)=\"choiceSelected(choiceDataElement.id, choiceDataElement.label, 'Other', 'freetext')\"> Other, please specify\u2026</label>\n              </div>\n              <div id='div_{{choiceDataElement.id}}_other'>\n                <input id=\"txt_other_{{choiceDataElement.id}}\" class=\"form-control\" type=\"text\" formControlName=\"checkBox\" value=\"other\"\n                  class=\"form-control\" (keyup)='updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)'\n                  placeholder=\"Please specify '{{choiceDataElement.label}}'\">\n              </div>\n            </ng-container>\n          </ng-container>\n          <ng-container *ngIf=\"choiceDataElement.imageMap != undefined\">\n            <div class=\"row\">\n              <div class=\"col-xs-6 col-sm-2\">\n                <ng-container *ngFor=\"let choice of choiceDataElement.choiceInfo\">\n                  <div class=\"radio\" style=\"float:left; margin-right:15px;\">\n                    <label>\n                      <input [(ngModel)]=\"choiceValue\" id=\"{{choice.value}}_{{choiceDataElement.id}}\" type=\"radio\" formControlName=\"checkBox\" value=\"{{choice.value}}\"\n                        (change)=\"choiceSelected(choiceDataElement.id, choiceDataElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, choice.value)\"> {{choice.label}}\n                    </label>\n                  </div>\n                </ng-container>\n                <ng-container *ngIf=\"choiceDataElement.allowFreetext\">\n                  <div class=\"radio\" style=\"float:left; margin-right:15px;\">\n                    <label>\n                      <input id=\"other_{{choiceDataElement.id}}\" type=\"radio\" formControlName=\"checkBox\" value=\"other\" (change)=\"choiceSelected(choiceDataElement.id, choiceDataElement.label, 'Other', 'freetext')\"> Other, please specify\u2026</label>\n                  </div>\n                  <div id='div_{{choiceDataElement.id}}_other'>\n                    <input id=\"txt_other_{{choiceDataElement.id}}\" class=\"form-control\" type=\"text\" formControlName=\"checkBox\" value=\"other\"\n                      class=\"form-control\" (keyup)='updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)'\n                      placeholder=\"Please specify '{{choiceDataElement.label}}'\">\n                  </div>\n                </ng-container>\n              </div>\n              <div class=\"col-xs-6 col-sm-2\">\n                <label class=\"control-label\">OR</label>\n              </div>\n              <acr-image-map [DataElement]=\"choiceDataElement\" [imagePath]=\"imagePath\"></acr-image-map>\n            </div>\n          </ng-container>\n        </ng-container>\n      </ng-container>\n      <ng-container *ngIf=\"choiceDataElement.choiceInfo.length > 2\">\n        <select [(ngModel)]=\"choiceValue\" id=\"{{choiceDataElement.id}}\" (change)=\"dropdownChoiceSelected($event.target, choiceDataElement.label)\"\n          formControlName=\"checkBox\" class=\"form-control\">\n          <option [value]=\"Select\" [selected]=\"true\">--Select--</option>\n          <option *ngFor=\"let choice of choiceDataElement.choiceInfo\" [value]=\"choice.value\" [selected]=\"choice.value === choiceDataElement.currentValue\">{{choice.label}}</option>\n          <option *ngIf=\"choiceDataElement.allowFreetext\" [value]=\"freetext\" [selected]='freetext'>Other, please specify\u2026</option>\n        </select>\n        <div id='div_{{choiceDataElement.id}}_other'>\n          <input id=\"txt_other_{{choiceDataElement.id}}\" class=\"form-control\" type=\"text\" formControlName=\"checkBox\" value=\"other\"\n            placeholder=\"Please specify '{{choiceDataElement.label}}'\" (keyup)='updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)'>\n        </div>\n        <ng-container *ngIf=\"choiceDataElement.imageMap != undefined  && imagePath != undefined\">\n          <div class=\"row padding-top-10\">\n            <div class=\"col-xs-6 col-sm-2\">\n              <label class=\"control-label\">OR</label>\n            </div>\n            <acr-image-map [DataElement]=\"choiceDataElement\" [imagePath]=\"imagePath\"></acr-image-map>\n          </div>\n        </ng-container>\n      </ng-container>\n    </div>\n  </div>\n</form>\n\n",
                styles: ["", ".required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}"]
            },] },
];
AssistChoiceElementComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
]; };
AssistChoiceElementComponent.propDecorators = {
    "choiceDataElement": [{ type: Input },],
    "imagePath": [{ type: Input },],
    "returnChoiceElement": [{ type: Output },],
    "choiceChange": [{ type: Output },],
};
var $$4 = require('jquery');
var AssistMultiChoiceElementComponent = /** @class */ (function () {
    function AssistMultiChoiceElementComponent(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnMultiChoice = new EventEmitter();
        this.multiElements = [];
        this.multiChoiceValues = [];
        this.multiChoiceComaprisonValues = [];
        this.choiceValue = [];
    }
    AssistMultiChoiceElementComponent.prototype.ngOnInit = function () {
        this.createMultiChoiceElementForm();
    };
    AssistMultiChoiceElementComponent.prototype.ngAfterViewInit = function () {
        console.log(this.multiChoiceElement.currentValue);
        if (this.multiChoiceElement.currentValue !== undefined) {
            for (var choice in this.multiChoiceElement.choiceInfo) {
                if (Array.isArray(this.multiChoiceElement.currentValue)) {
                    try {
                        for (var _a = __values(this.multiChoiceElement.currentValue), _b = _a.next(); !_b.done; _b = _a.next()) {
                            var currValue = _b.value;
                            if (currValue === this.multiChoiceElement.choiceInfo[choice].value && this.multiChoiceElement.choiceInfo[choice].value !== undefined) {
                                console.log('Values Matched' + currValue);
                                this.choiceValue = this.multiChoiceElement.currentValue;
                                var customEvent = document.createEvent('Event');
                                $$4('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue[choice]).prop('checked', true);
                                customEvent.initEvent('change', true, true);
                                this.selctValue = currValue;
                                this.selectedMultiChoice(this.multiChoiceElement.id, this.multiChoiceElement.label, currValue, this.multiChoiceElement.choiceInfo[choice].label);
                                break;
                            }
                        }
                    }
                    catch (e_39_1) { e_39 = { error: e_39_1 }; }
                    finally {
                        try {
                            if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                        }
                        finally { if (e_39) throw e_39.error; }
                    }
                }
                else {
                    if (this.multiChoiceElement.currentValue === this.multiChoiceElement.choiceInfo[choice].value && this.multiChoiceElement.choiceInfo[choice].value !== undefined) {
                        this.choiceValue = this.multiChoiceElement.currentValue;
                        var customEvent = document.createEvent('Event');
                        $$4('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue).prop('checked', true);
                        customEvent.initEvent('change', true, true);
                        this.selectedMultiChoice(this.multiChoiceElement.id, this.multiChoiceElement.label, this.multiChoiceElement.currentValue, this.multiChoiceElement.choiceInfo[choice].label);
                    }
                }
                if (this.selctValue === this.multiChoiceElement.choiceInfo[choice].value) {
                    this.checked = this.multiChoiceElement.choiceInfo[choice].value;
                }
                else {
                    this.checked = undefined;
                }
            }
        }
        var e_39, _c;
    };
    AssistMultiChoiceElementComponent.prototype.selectedMultiChoice = function (elementId, selectedCondition, choiceValue, choiceLabel) {
        var multiElement = new MultiChoiceElement();
        if ($$4('#' + elementId + '_' + choiceValue).is(':checked')) {
            this.multiChoiceValues.push(choiceLabel);
            this.multiChoiceComaprisonValues.push(choiceValue);
            this.checked = choiceValue;
            if (this.selctValue === choiceValue) {
                this.checked = choiceValue;
            }
            else {
                this.checked = undefined;
            }
        }
        else {
            var index = this.multiChoiceValues.indexOf(choiceLabel);
            this.checked = undefined;
            var comparisonIndex = this.multiChoiceComaprisonValues.indexOf(choiceValue);
            if (index > -1) {
                this.multiChoiceValues.splice(index, 1);
            }
            if (comparisonIndex > -1) {
                this.multiChoiceComaprisonValues.splice(comparisonIndex, 1);
            }
        }
        multiElement.elementId = elementId;
        multiElement.selectedValues = this.multiChoiceValues;
        multiElement.selectedComparisonValues = this.multiChoiceComaprisonValues;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = this.multiChoiceValues;
        this.returnMultiChoice.emit({ receivedElement: multiElement, selectedCondition: this.selectedCondition });
    };
    AssistMultiChoiceElementComponent.prototype.updateMultiChoice = function (elementId, selectedCondition, value, event) {
        var multiElement = new MultiChoiceElement();
        if (event.currentTarget.checked) {
            this.multiChoiceValues.push(value);
            this.multiChoiceComaprisonValues.push(event.currentTarget.value);
            this.checked = event.currentTarget.value;
            if (this.selctValue === event.currentTarget.value) {
                this.checked = event.currentTarget.value;
            }
            else {
                this.checked = undefined;
            }
        }
        else {
            var index = this.multiChoiceValues.indexOf(value);
            this.checked = undefined;
            var comparisonIndex = this.multiChoiceComaprisonValues.indexOf(event.currentTarget.value);
            if (index > -1) {
                this.multiChoiceValues.splice(index, 1);
            }
            if (comparisonIndex > -1) {
                this.multiChoiceComaprisonValues.splice(comparisonIndex, 1);
            }
        }
        multiElement.elementId = elementId;
        multiElement.selectedValues = this.multiChoiceValues;
        multiElement.selectedComparisonValues = this.multiChoiceComaprisonValues;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = this.multiChoiceValues;
        this.returnMultiChoice.emit({ receivedElement: multiElement, selectedCondition: this.selectedCondition });
    };
    AssistMultiChoiceElementComponent.prototype.createMultiChoiceElementForm = function () {
        this.multiChoiceElementForm = this.formBuilder.group({
            multiCheckBox: ['', Validators.required],
        }, {
            validator: this.specificValueInsideRange('multiCheckBox')
        });
    };
    AssistMultiChoiceElementComponent.prototype.specificValueInsideRange = function (checkBoxKey) {
        var _this = this;
        return function (group) {
            var choiceControl = group.controls[checkBoxKey];
            if (_this.multiChoiceElement.isRequired) {
                return choiceControl.setErrors({ notEquivalent: true });
            }
            else {
                return choiceControl.setErrors(null);
            }
        };
    };
    return AssistMultiChoiceElementComponent;
}());
AssistMultiChoiceElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-multi-choice-element',
                template: "<form [formGroup]=\"multiChoiceElementForm\" novalidate>\n  <div class=\"form-group\">\n    <div class=\"col-sm-5 text-right\">\n      <label class=\"control-label\">{{multiChoiceElement.label}}\n      </label>\n      <ng-container *ngIf=\"multiChoiceElement.hint !== '' && multiChoiceElement.hint !== undefined\">\n        <i class=\"fa fa-info-circle text-primary\" title=\"{{multiChoiceElement.hint}}\"></i>\n      </ng-container>\n      <ng-container *ngIf=\"multiChoiceElement.diagrams != undefined \">\n        <acr-hint-diagram [DataElement]=\"multiChoiceElement\" [imagePath]=\"imagePath\"></acr-hint-diagram>\n      </ng-container>\n      <span *ngIf=\"multiChoiceElementForm.controls['multiCheckBox'].invalid && !multiChoiceValues.length\" class=\"required-field\"\n        title=\"Required Field\">\n        *\n      </span>\n    </div>\n    <div class=\"col-sm-7\">\n      <div *ngFor=\"let choice of multiChoiceElement.choiceInfo\" class=\"checkbox\" title=\"{{choice.hint}}\">\n        <label>\n          <input type=\"checkbox\" [(ngModel)]=\"checked\" id=\"{{multiChoiceElement.id}}_{{choice.value}}\" [checked]=\"false\" formControlName=\"multiCheckBox\" value=\"{{choice.value}}\"\n            (change)=\"updateMultiChoice(multiChoiceElement.id, multiChoiceElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, $event)\"> {{choice.label}}\n        </label>\n      </div>\n    </div>\n  </div>\n</form>\n",
                styles: ["", ".required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}"]
            },] },
];
AssistMultiChoiceElementComponent.ctorParameters = function () { return [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
]; };
AssistMultiChoiceElementComponent.propDecorators = {
    "multiChoiceElement": [{ type: Input },],
    "imagePath": [{ type: Input },],
    "returnMultiChoice": [{ type: Output },],
};
var ImageMapComponent = /** @class */ (function () {
    function ImageMapComponent() {
        this.$ = require('jquery');
        this.DataElements = {};
        this.FormValues = {};
        this.imageExist = true;
        this.SelectionValue = '';
    }
    ImageMapComponent.prototype.ngOnInit = function () {
        if (this.DataElement === undefined) {
            return;
        }
        this.displayValue('');
    };
    ImageMapComponent.prototype.isInRectangle = function (mouseX, mouseY, Coordinates) {
        var COArray = Coordinates.split(',');
        if (COArray[0] < mouseX
            && (COArray[0] + COArray[2]) > mouseX
            && COArray[1] < mouseY
            && (COArray[1] + COArray[3]) > mouseY) {
            return true;
        }
        return false;
    };
    ImageMapComponent.prototype.isInCircle = function (mouseX, mouseY, Coordinates) {
        var COArray = Coordinates.split(',');
        if (Math.sqrt(Math.pow((mouseX - COArray[0]), 2) + Math.pow((mouseY - COArray[1]), 2)) < COArray[2]) {
            return true;
        }
        else {
            return false;
        }
    };
    ImageMapComponent.prototype.isInPolygon = function (x, y, Coordinates) {
        var COArray = Coordinates.split(',');
        var vs = [];
        for (var i = 0; i < COArray.length; i++) {
            var point = [];
            point.push(COArray[i]);
            point.push(COArray[i + 1]);
            i += 1;
            vs.push(point);
        }
        var inside = false;
        for (var i = 0, j = vs.length - 1; i < vs.length; j = i++) {
            var xi = vs[i][0], yi = vs[i][1];
            var xj = vs[j][0], yj = vs[j][1];
            var intersect = ((yi > y) !== (yj > y))
                && (x < (xj - xi) * (y - yi) / (yj - yi) + xi);
            if (intersect) {
                inside = !inside;
            }
        }
        return inside;
    };
    ImageMapComponent.prototype.imageClick = function (e, dataElement) {
        var O_height = dataElement.ImageProp.height;
        var O_width = dataElement.ImageProp.width;
        var $elem = this.$(e.target);
        var N_height = $elem.height();
        var N_width = $elem.width();
        var offset = $elem.offset();
        var offset_t = offset.top - this.$(window).scrollTop();
        var offset_l = offset.left - this.$(window).scrollLeft();
        var x = e.clientX - offset_l;
        var y = e.clientY - offset_t;
        try {
            for (var _a = __values(dataElement.ImageOptions), _b = _a.next(); !_b.done; _b = _a.next()) {
                var opt = _b.value;
                if (opt.Shape === 'rect') {
                    if (this.isInRectangle(x, y, opt.Coordinates)) {
                        this.FormValues[dataElement.ID] = opt.Value;
                        break;
                    }
                }
                else if (opt.Shape === 'circle') {
                    if (this.isInCircle(x, y, opt.Coordinates)) {
                        this.FormValues[dataElement.ID] = opt.Value;
                        break;
                    }
                }
                else if (opt.Shape === 'poly') {
                    if (this.isInPolygon(x, y, opt.Coordinates)) {
                        this.FormValues[dataElement.ID] = opt.Value;
                        break;
                    }
                }
            }
        }
        catch (e_40_1) { e_40 = { error: e_40_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_40) throw e_40.error; }
        }
        var e_40, _c;
    };
    ImageMapComponent.prototype.setValue = function (val) {
        try {
            for (var _a = __values(this.DataElement.choiceInfo), _b = _a.next(); !_b.done; _b = _a.next()) {
                var optValue = _b.value;
                if (this.DataElement.choiceInfo.length <= 5 && this.DataElement.choiceInfo.length > 0) {
                    if (optValue.value === val) {
                        this.$('#' + val + '_' + this.DataElement.id).prop('checked', true);
                        var customEvent = document.createEvent('Event');
                        customEvent.initEvent('change', true, true);
                        this.$('#' + val + '_' + this.DataElement.id)[0].dispatchEvent(customEvent);
                    }
                    else {
                        this.$('#' + optValue.value + '_' + this.DataElement.id).prop('checked', false);
                    }
                }
                else {
                    if (optValue.value === val) {
                        this.$('#' + this.DataElement.id).val(optValue.value);
                        var customEvent = document.createEvent('Event');
                        customEvent.initEvent('change', true, true);
                        this.$('#' + this.DataElement.id)[0].dispatchEvent(customEvent);
                        break;
                    }
                }
            }
        }
        catch (e_41_1) { e_41 = { error: e_41_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_41) throw e_41.error; }
        }
        this.DataElement.currentValue = val;
        var e_41, _c;
    };
    ImageMapComponent.prototype.displayValue = function (val) {
        if (val === '') {
            this.SelectionValue = 'Image Map Diagram';
        }
        else {
            this.SelectionValue = 'Selected Value : ' + val;
        }
    };
    return ImageMapComponent;
}());
ImageMapComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-image-map',
                template: "<div class=\"col-sm-8\">\n    <label class=\"control-label\" style=\"font-weight:400;\">Not sure? try out this image </label>\n  <button type=\"button\" class=\"btn btn-default\" data-toggle=\"modal\" attr.data-target=\"#{{'imgMap_Modal_'+DataElement.id}}\">\n    <span class=\"glyphicon glyphicon-picture\" aria-hidden=\"true\" data-toggle=\"tooltip\" data-placement=\"top\" title=\"Image Map\"></span>\n  </button>\n</div>\n<ng-container *ngIf=\"imagePath != undefined\">\n  <div class=\"modal inmodal fade\" id=\"{{'imgMap_Modal_'+DataElement.id}}\" tabindex=\"-1\" role=\"dialog\" aria-hidden=\"true\">\n    <div class=\"modal-dialog modal-lg\">\n      <div class=\"modal-content\">\n        <div class=\"modal-header\">\n          <button type=\"button\" class=\"close\" data-dismiss=\"modal\">\n            <span aria-hidden=\"true\">&times;</span>\n            <span class=\"sr-only\">Close</span>\n          </button>\n          <h4 class=\"modal-title\"> {{SelectionValue}}</h4>\n        </div>\n        <div class=\"modal-body\">\n          <div class=\"row\">\n            <div class=\"col-md-12\">\n              <ng-container *ngIf=\"imageExist == true\">\n                <img class=\"ImgOption danger\" alt=\"No Image Available!!!\" data-dismiss=\"modal\" attr.id=\"{{'imgMap_Img_'+DataElement.id}}\"\n                  (click)=\"imageClick($event,DataElement);\" attr.data-elementID=\"{{DataElement.id}}\" attr.usemap=\"#{{'imgMap_'+DataElement.id}}\"\n                  src=\"{{imagePath}}/{{DataElement.imageMap.location}}\">\n                <map name=\"{{'imgMap_'+DataElement.id}}\">\n                  <ng-container *ngFor=\"let imgOpt of DataElement.imageMap.map.areas\">\n                    <area attr.shape=\"{{imgOpt.shape}}\" attr.imgID=\"{{'imgMap_Img_'+DataElement.id}}\" attr.coords=\"{{imgOpt.coords}}\" attr.alt=\"{{imgOpt.choiceValue}}\"\n                      (mouseover)='displayValue(imgOpt.choiceValue);' (mouseout)='displayValue(\"\");' (click)=\"setValue(imgOpt.choiceValue);\"\n                      data-dismiss=\"modal\">\n                  </ng-container>\n                </map>\n              </ng-container>\n              <ng-container *ngIf=\"imageExist == false\">\n                <div class=\"\">\n                  No Image Map Available...\n                </div>\n              </ng-container>\n            </div>\n          </div>\n        </div>\n        <div class=\"modal-footer\">\n          <button type=\"button\" class=\"btn btn-primary\" data-dismiss=\"modal\">Close</button>\n        </div>\n      </div>\n    </div>\n  </div>\n</ng-container>\n",
                styles: ["", ".required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}"]
            },] },
];
ImageMapComponent.propDecorators = {
    "DataElement": [{ type: Input },],
    "DataElements": [{ type: Input },],
    "FormValues": [{ type: Input },],
    "imagePath": [{ type: Input },],
};
var ComputedDataElement = /** @class */ (function (_super) {
    __extends(ComputedDataElement, _super);
    function ComputedDataElement() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return ComputedDataElement;
}(BaseDataElement));
var ComputedDataElementCreationService = /** @class */ (function (_super) {
    __extends(ComputedDataElementCreationService, _super);
    function ComputedDataElementCreationService(diagramService, arrayCheckerService, computedValueCreationService, decisionPointsCreationService) {
        var _this = _super.call(this, diagramService) || this;
        _this.arrayCheckerService = arrayCheckerService;
        _this.computedValueCreationService = computedValueCreationService;
        _this.decisionPointsCreationService = decisionPointsCreationService;
        _this.elementType = 'ComputedDataElement';
        return _this;
    }
    ComputedDataElementCreationService.prototype.createElement = function (data) {
        var dataElement = new ComputedDataElement();
        _super.prototype.populateBasicData.call(this, data, dataElement);
        dataElement.computeValue = this.computedValueCreationService.createComputedValue(data);
        if (data.DecisionPoint) {
            dataElement.decisionPoints = this.decisionPointsCreationService.createDecisionPoints(data.DecisionPoint);
        }
        return dataElement;
    };
    return ComputedDataElementCreationService;
}(DataElementCreationBaseService));
ComputedDataElementCreationService.decorators = [
    { type: Injectable },
];
ComputedDataElementCreationService.ctorParameters = function () { return [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
    { type: ComputedValueCreationService, },
    { type: DecisionPointsCreationService, },
]; };
var $$5 = require('jquery');
var AssistReportTextComponent = /** @class */ (function () {
    function AssistReportTextComponent() {
        this.allReportTexts = [];
        this.sections = [];
        setInterval(function () {
        }, 1000);
    }
    AssistReportTextComponent.prototype.ngOnChanges = function (changes) {
        this.mainReportTexts = new MainReportText();
        this.onSelect(this.selectedSectionId);
    };
    AssistReportTextComponent.prototype.onSelect = function (sectionId) {
        this.selectedSectionId = sectionId;
        this.sections = [];
        this.selectedSection = null;
        for (var section in this.reportText.allReportText) {
            if (this.reportText.allReportText[section].reportText !== '') {
                this.sections.push(section);
            }
        }
        if (sectionId === 'undefined' || sectionId === undefined || sectionId === 'All') {
            this.allTextReport = [];
            for (var section in this.reportText.allReportText) {
                if (this.reportText.allReportText[section].reportText !== '') {
                    var textReport = new AllTextReport();
                    textReport.heading = section;
                    textReport.content = this.removeEmptyLine(this.reportText.allReportText[section].reportText);
                    this.allTextReport.push(textReport);
                }
            }
            this.selectedSectionId = 'All';
        }
        for (var section in this.reportText.allReportText) {
            if (this.reportText.allReportText[section].sectionId === sectionId) {
                this.selectedSection = this.reportText.allReportText[section].reportText;
                this.selectedSection = this.reportText.reportTextMainContent + ((this.selectedSection !== undefined && this.selectedSection !== '') ? this.removeEmptyLine(this.selectedSection) : '');
                break;
            }
        }
        this.mainReportTexts = new MainReportText();
        this.allReportTexts = [];
        for (var section in this.reportText.allReportText) {
            var allreportText = new AllReportText();
            allreportText.reportText = this.removeEmptyLine(this.reportText.allReportText[section].reportText);
            allreportText.sectionId = this.reportText.allReportText[section].sectionId;
            this.allReportTexts.push(allreportText);
        }
        this.mainReportTexts.allReportText = this.allReportTexts;
        this.mainReportTexts.reportTextMainContent = this.reportText.reportTextMainContent;
    };
    AssistReportTextComponent.prototype.removeEmptyLine = function (inputText) {
        if (inputText.trim().length !== 0) {
            var lines = inputText.split('\n');
            var uniquelines_1 = [];
            lines.forEach(function (line, i) {
                if (line.trim().length !== 0) {
                    uniquelines_1.push(line);
                }
            });
            return uniquelines_1.join('\n');
        }
    };
    return AssistReportTextComponent;
}());
AssistReportTextComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-report-text',
                template: "<ng-container *ngFor=\"let textReport of allTextReport; let lastitem = last\">\n  <dt class=\"text-capitalize\">{{textReport.heading}}</dt>\n  <dd>\n    <p class=\"white-space-line\" [innerHTML]=\"textReport.content\"></p>\n  </dd>\n  <hr *ngIf=\"!lastitem\">\n</ng-container>\n",
                styles: ["", ".required-field{color:red}.carousel-control>.fa{font-size:40px;position:absolute;top:50%;z-index:5;display:inline-block;margin-top:-20px}.carousel-control.left{background-repeat:repeat-x}.carousel-control.left,.carousel-control.right{background-image:none}.carousel-control.right{right:0;left:auto;background-image:-webkit-gradient(linear,left top,right top,color-stop(0,rgba(0,0,0,.0001)),to(rgba(0,0,0,.5)));background-image:linear-gradient(to right,rgba(0,0,0,.0001) 0,rgba(0,0,0,.5) 100%);background-repeat:repeat-x}.div-simulator-form-height{height:calc(100vh - 100px);overflow-y:scroll;overflow-x:hidden}.padding-r-10{padding-right:10px}hr{margin-top:10px;margin-bottom:10px}.white-space-line{white-space:pre-line;word-wrap:break-word}p{margin:0 0 10px}.form-control{border-radius:0;-webkit-box-shadow:none;box-shadow:none;border-color:#d2d6de}h4.modal-title.float-left{float:left}.margin-b-0{margin-bottom:0}@media (min-width:768px){label.control-label{padding-left:20px}}"]
            },] },
];
AssistReportTextComponent.ctorParameters = function () { return []; };
AssistReportTextComponent.propDecorators = {
    "reportText": [{ type: Input },],
};
var components = [AcrAssistSimulatorComponent, AssistDataElementComponent, HintDiagramComponent, SlideComponent, CarouselComponent,
    AssistNumericElementComponent, AssistChoiceElementComponent, AssistMultiChoiceElementComponent,
    ImageMapComponent, AssistReportTextComponent];
var AcrAssistSimulatorModule = /** @class */ (function () {
    function AcrAssistSimulatorModule() {
    }
    return AcrAssistSimulatorModule;
}());
AcrAssistSimulatorModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    CoreModule,
                    FormsModule,
                    ReactiveFormsModule
                ],
                declarations: components,
                providers: [TemplateManagerService,
                    DiagramService,
                    CarouselConfig,
                    ArrayCheckerService,
                    ConditionsCreationService,
                    DecisionPointsCreationService,
                    ComputedValueCreationService,
                    SimulatorEngineService,
                    { provide: CreationServiceInjectorToken, useClass: ChoiceDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: MultipleChoiceDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: NumericDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: IntegerDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: GlobalValueCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: ComputedDataElementCreationService, multi: true }
                ],
                exports: components
            },] },
];
var Dictionary = /** @class */ (function () {
    function Dictionary() {
        this.items = {};
        this.count = 0;
    }
    Dictionary.prototype.ContainsKey = function (key) {
        return this.items.hasOwnProperty(key);
    };
    Dictionary.prototype.Count = function () {
        return this.count;
    };
    Dictionary.prototype.Add = function (key, value) {
        if (!this.items.hasOwnProperty(key)) {
            this.count++;
        }
        this.items[key] = value;
    };
    Dictionary.prototype.Remove = function (key) {
        var val = this.items[key];
        delete this.items[key];
        this.count--;
        return val;
    };
    Dictionary.prototype.Item = function (key) {
        return this.items[key];
    };
    Dictionary.prototype.Keys = function () {
        var keySet = [];
        for (var prop in this.items) {
            if (this.items.hasOwnProperty(prop)) {
                keySet.push(prop);
            }
        }
        return keySet;
    };
    Dictionary.prototype.Values = function () {
        var values = [];
        for (var prop in this.items) {
            if (this.items.hasOwnProperty(prop)) {
                values.push(this.items[prop]);
            }
        }
        return values;
    };
    return Dictionary;
}());
var GlobalsService = /** @class */ (function () {
    function GlobalsService(http) {
        this.http = http;
        this.defaultModule = 'assets/XMLFIles/hello_assist/Hello_Assist.xml';
        this.XMLList = new Dictionary();
    }
    GlobalsService.prototype.getDefaultModulePath = function () {
        return this.http.get(this.defaultModule).map(function (res) { return res.text(); });
    };
    return GlobalsService;
}());
GlobalsService.decorators = [
    { type: Injectable },
];
GlobalsService.ctorParameters = function () { return [
    { type: Http, },
]; };
var $$6 = require('jquery');
var ViewUploadLoaderComponent = /** @class */ (function () {
    function ViewUploadLoaderComponent(globalsService) {
        this.onFileSelected = new EventEmitter();
        this.globalsService = globalsService;
    }
    ViewUploadLoaderComponent.prototype.onFileContentRead = function (fileDetails) {
        this.selectedXML = fileDetails;
        if (this.globalsService.XMLList.ContainsKey(fileDetails.fileLabel)) {
            this.globalsService.XMLList.Remove(fileDetails.fileLabel);
        }
        this.globalsService.XMLList.Add(fileDetails.fileLabel, fileDetails);
        this.onFileSelected.emit(fileDetails);
    };
    ViewUploadLoaderComponent.prototype.onFileClick = function (fileDetails) {
        this.selectedXML = fileDetails;
        this.onFileSelected.emit(fileDetails);
        $$6('#xmlOnlyMsg').hide();
    };
    return ViewUploadLoaderComponent;
}());
ViewUploadLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-view-upload-loader',
                template: "<ul class=\"sidebar-menu\" data-widget=\"tree\">\n  <li class=\"header\">Want to try your assist module?</li>\n  <li class=\"text-center\">\n    <acr-file-upload-loader (onFileContentRead)=\"onFileContentRead($event)\"></acr-file-upload-loader>\n  </li>\n  <li [ngClass]=\"{'active':(selectedXML != 'undefined' && selectedXML.fileLabel == file.fileLabel)}\" *ngFor=\"let file of globalsService.XMLList.Values().reverse()\"\n     class=\"treeview\">\n    <a href=\"#\" (click)=\"onFileClick(file)\">\n      <i class=\"fa fa-book\"></i>\n      <span>{{file.fileLabel}}</span>\n    </a>\n  </li>\n</ul>\n",
                styles: [""]
            },] },
];
ViewUploadLoaderComponent.ctorParameters = function () { return [
    { type: GlobalsService, },
]; };
ViewUploadLoaderComponent.propDecorators = {
    "onFileSelected": [{ type: Output },],
};
var FileDetails = /** @class */ (function () {
    function FileDetails(fileLabel, fileName, fileContents) {
        this.fileLabel = fileLabel;
        this.fileName = fileName;
        this.fileContents = fileContents;
    }
    return FileDetails;
}());
var $$7 = require('jquery');
var FileUploadLoaderComponent = /** @class */ (function () {
    function FileUploadLoaderComponent(configService) {
        this.configService = configService;
        this.onFileContentRead = new EventEmitter();
        this.fileReader = new FileReader();
    }
    FileUploadLoaderComponent.prototype.ngOnInit = function () {
        this.hideMessage();
        this.showDefaultModule();
    };
    FileUploadLoaderComponent.prototype.changeListener = function ($event) {
        var fileName;
        fileName = $event.target.value;
        if (fileName.includes('.xml') || fileName.includes('.Xml') || fileName.includes('.XML') ||
            fileName.includes('.zip') || fileName.includes('.Zip') || fileName.includes('.ZIP')) {
            this.hideMessage();
            this.readThis($event.target);
        }
        else {
            if (fileName !== '' && fileName !== undefined) {
                $$7('#xmlOnlyMsg').show();
            }
        }
    };
    FileUploadLoaderComponent.prototype.hideMessage = function () {
        $$7('#xmlOnlyMsg').hide();
    };
    FileUploadLoaderComponent.prototype.readThis = function (inputValue) {
        var _this = this;
        this.readFile = inputValue.files[0];
        var self = this;
        var extensionStartPosition = self.readFile.name.lastIndexOf('.');
        this.fileReader.onloadend = function (e) {
            self.onFileContentRead.emit(new FileDetails(self.readFile.name.substring(0, extensionStartPosition), self.readFile.name, _this.fileReader.result));
        };
        this.fileReader.readAsText(this.readFile);
    };
    FileUploadLoaderComponent.prototype.showDefaultModule = function () {
        var _this = this;
        this.configService.getDefaultModulePath()
            .subscribe(function (data) {
            var self = _this;
            self.onFileContentRead.emit(new FileDetails('Hello Assist', 'Hello_Assist.xml', data));
        });
    };
    return FileUploadLoaderComponent;
}());
FileUploadLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-file-upload-loader',
                template: "<input id=\"xmlFileUpload\" class=\"hidden\" type=\"file\" accept=\".xml\" (change)=\"changeListener($event)\" (click)=\"hideMessage()\">\n<label for=\"xmlFileUpload\" class=\"btn bg-olive margin\" style=\"margin:10px;\" title=\"Choose a Module\">Choose a Module</label>\n<br>\n<div id=\"xmlOnlyMsg\" class=\"xml-only-msg\"> Only XML files are supported !!!</div>\n",
                styles: [""]
            },] },
];
FileUploadLoaderComponent.ctorParameters = function () { return [
    { type: GlobalsService, },
]; };
FileUploadLoaderComponent.propDecorators = {
    "onFileContentRead": [{ type: Output },],
};
var components$1 = [FileUploadLoaderComponent, ViewUploadLoaderComponent];
var SimulatorLoaderModule = /** @class */ (function () {
    function SimulatorLoaderModule() {
    }
    return SimulatorLoaderModule;
}());
SimulatorLoaderModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [components$1],
                providers: [GlobalsService],
                exports: [components$1]
            },] },
];

export { AcrAssistSimulatorModule, SimulatorLoaderModule, AcrAssistSimulatorComponent as ɵc, AssistChoiceElementComponent as ɵo, AssistDataElementComponent as ɵl, AssistMultiChoiceElementComponent as ɵp, AssistNumericElementComponent as ɵn, HintDiagramComponent as ɵm, ImageMapComponent as ɵq, AssistReportTextComponent as ɵr, CreationServiceInjectorToken as ɵe, ArrayCheckerService as ɵg, ChoiceDataElementCreationService as ɵs, ComputedDataElementCreationService as ɵx, ComputedValueCreationService as ɵk, ConditionsCreationService as ɵj, DataElementCreationBaseService as ɵh, DecisionPointsCreationService as ɵi, DiagramService as ɵf, GlobalValueCreationService as ɵw, IntegerDataElementCreationService as ɵv, MultipleChoiceDataElementCreationService as ɵt, NumericDataElementCreationService as ɵu, TemplateManagerService as ɵd, CoreModule as ɵa, SimulatorEngineService as ɵb, FileUploadLoaderComponent as ɵy, GlobalsService as ɵz, ViewUploadLoaderComponent as ɵba };
//# sourceMappingURL=acr-assist-simulator-module.js.map
